{-
Copyright (C) 2014 Matthew Pickering <matthewtpickering@gmail.com>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-}
{- |

This module exposes functions which attempt to approximate unicode characters as ASCII.

Information taken from the <https://pypi.python.org/pypi/Unidecode Unidecode python package> which is based upon
the <http://search.cpan.org/~sburke/Text-Unidecode-1.01/lib/Text/Unidecode.pm Text::Unidecode Perl Module> by Sean M. Burke.

-}
module Text.TeXMath.Unicode.ToASCII (getASCII) where

import qualified Data.IntMap as M
import Data.Char (ord)
import Data.Maybe (fromMaybe)

-- | Approximates a single unicode character as an ASCII string
--  (each character is between 0x00 and 0x7F).
getASCII :: Char -> String
getASCII u = fromMaybe "" (M.lookup (ord u) table)

table :: M.IntMap String
table = M.fromList
  [ ( 9, "\\t")
  , ( 10, "\\n")
  , ( 32, " ")
  , ( 33, "!")
  , ( 34, "\"")
  , ( 35, "#")
  , ( 36, "$")
  , ( 37, "%")
  , ( 38, "&")
  , ( 39, "'")
  , ( 40, "(")
  , ( 41, ")")
  , ( 42, "*")
  , ( 43, "+")
  , ( 44, ",")
  , ( 45, "-")
  , ( 46, ".")
  , ( 47, "/")
  , ( 48, "0")
  , ( 49, "1")
  , ( 50, "2")
  , ( 51, "3")
  , ( 52, "4")
  , ( 53, "5")
  , ( 54, "6")
  , ( 55, "7")
  , ( 56, "8")
  , ( 57, "9")
  , ( 58, ":")
  , ( 59, ";")
  , ( 60, "<")
  , ( 61, "=")
  , ( 62, ">")
  , ( 63, "?")
  , ( 64, "@")
  , ( 65, "A")
  , ( 66, "B")
  , ( 67, "C")
  , ( 68, "D")
  , ( 69, "E")
  , ( 70, "F")
  , ( 71, "G")
  , ( 72, "H")
  , ( 73, "I")
  , ( 74, "J")
  , ( 75, "K")
  , ( 76, "L")
  , ( 77, "M")
  , ( 78, "N")
  , ( 79, "O")
  , ( 80, "P")
  , ( 81, "Q")
  , ( 82, "R")
  , ( 83, "S")
  , ( 84, "T")
  , ( 85, "U")
  , ( 86, "V")
  , ( 87, "W")
  , ( 88, "X")
  , ( 89, "Y")
  , ( 90, "Z")
  , ( 91, "[")
  , ( 92, "\\")
  , ( 93, "]")
  , ( 94, "^")
  , ( 95, "_")
  , ( 96, "`")
  , ( 97, "a")
  , ( 98, "b")
  , ( 99, "c")
  , ( 100, "d")
  , ( 101, "e")
  , ( 102, "f")
  , ( 103, "g")
  , ( 104, "h")
  , ( 105, "i")
  , ( 106, "j")
  , ( 107, "k")
  , ( 108, "l")
  , ( 109, "m")
  , ( 110, "n")
  , ( 111, "o")
  , ( 112, "p")
  , ( 113, "q")
  , ( 114, "r")
  , ( 115, "s")
  , ( 116, "t")
  , ( 117, "u")
  , ( 118, "v")
  , ( 119, "w")
  , ( 120, "x")
  , ( 121, "y")
  , ( 122, "z")
  , ( 123, "{")
  , ( 124, "|")
  , ( 125, "}")
  , ( 126, "~")
  , ( 160, " ")
  , ( 161, "!")
  , ( 162, "C/")
  , ( 163, "PS")
  , ( 164, "$?")
  , ( 165, "Y=")
  , ( 166, "|")
  , ( 167, "SS")
  , ( 168, "\"")
  , ( 169, "(c)")
  , ( 170, "a")
  , ( 171, "<<")
  , ( 172, "!")
  , ( 174, "(r)")
  , ( 175, "-")
  , ( 176, "deg")
  , ( 177, "+-")
  , ( 178, "2")
  , ( 179, "3")
  , ( 180, "'")
  , ( 181, "u")
  , ( 182, "P")
  , ( 183, "*")
  , ( 184, ",")
  , ( 185, "1")
  , ( 186, "o")
  , ( 187, ">>")
  , ( 188, "1/4")
  , ( 189, "1/2")
  , ( 190, "3/4")
  , ( 191, "?")
  , ( 192, "A")
  , ( 193, "A")
  , ( 194, "A")
  , ( 195, "A")
  , ( 196, "A")
  , ( 197, "A")
  , ( 198, "AE")
  , ( 199, "C")
  , ( 200, "E")
  , ( 201, "E")
  , ( 202, "E")
  , ( 203, "E")
  , ( 204, "I")
  , ( 205, "I")
  , ( 206, "I")
  , ( 207, "I")
  , ( 208, "D")
  , ( 209, "N")
  , ( 210, "O")
  , ( 211, "O")
  , ( 212, "O")
  , ( 213, "O")
  , ( 214, "O")
  , ( 215, "x")
  , ( 216, "O")
  , ( 217, "U")
  , ( 218, "U")
  , ( 219, "U")
  , ( 220, "U")
  , ( 221, "Y")
  , ( 222, "Th")
  , ( 223, "ss")
  , ( 224, "a")
  , ( 225, "a")
  , ( 226, "a")
  , ( 227, "a")
  , ( 228, "a")
  , ( 229, "a")
  , ( 230, "ae")
  , ( 231, "c")
  , ( 232, "e")
  , ( 233, "e")
  , ( 234, "e")
  , ( 235, "e")
  , ( 236, "i")
  , ( 237, "i")
  , ( 238, "i")
  , ( 239, "i")
  , ( 240, "d")
  , ( 241, "n")
  , ( 242, "o")
  , ( 243, "o")
  , ( 244, "o")
  , ( 245, "o")
  , ( 246, "o")
  , ( 247, "/")
  , ( 248, "o")
  , ( 249, "u")
  , ( 250, "u")
  , ( 251, "u")
  , ( 252, "u")
  , ( 253, "y")
  , ( 254, "th")
  , ( 255, "y")
  , ( 256, "A")
  , ( 257, "a")
  , ( 258, "A")
  , ( 259, "a")
  , ( 260, "A")
  , ( 261, "a")
  , ( 262, "C")
  , ( 263, "c")
  , ( 264, "C")
  , ( 265, "c")
  , ( 266, "C")
  , ( 267, "c")
  , ( 268, "C")
  , ( 269, "c")
  , ( 270, "D")
  , ( 271, "d")
  , ( 272, "D")
  , ( 273, "d")
  , ( 274, "E")
  , ( 275, "e")
  , ( 276, "E")
  , ( 277, "e")
  , ( 278, "E")
  , ( 279, "e")
  , ( 280, "E")
  , ( 281, "e")
  , ( 282, "E")
  , ( 283, "e")
  , ( 284, "G")
  , ( 285, "g")
  , ( 286, "G")
  , ( 287, "g")
  , ( 288, "G")
  , ( 289, "g")
  , ( 290, "G")
  , ( 291, "g")
  , ( 292, "H")
  , ( 293, "h")
  , ( 294, "H")
  , ( 295, "h")
  , ( 296, "I")
  , ( 297, "i")
  , ( 298, "I")
  , ( 299, "i")
  , ( 300, "I")
  , ( 301, "i")
  , ( 302, "I")
  , ( 303, "i")
  , ( 304, "I")
  , ( 305, "i")
  , ( 306, "IJ")
  , ( 307, "ij")
  , ( 308, "J")
  , ( 309, "j")
  , ( 310, "K")
  , ( 311, "k")
  , ( 312, "k")
  , ( 313, "L")
  , ( 314, "l")
  , ( 315, "L")
  , ( 316, "l")
  , ( 317, "L")
  , ( 318, "l")
  , ( 319, "L")
  , ( 320, "l")
  , ( 321, "L")
  , ( 322, "l")
  , ( 323, "N")
  , ( 324, "n")
  , ( 325, "N")
  , ( 326, "n")
  , ( 327, "N")
  , ( 328, "n")
  , ( 329, "'n")
  , ( 330, "ng")
  , ( 331, "NG")
  , ( 332, "O")
  , ( 333, "o")
  , ( 334, "O")
  , ( 335, "o")
  , ( 336, "O")
  , ( 337, "o")
  , ( 338, "OE")
  , ( 339, "oe")
  , ( 340, "R")
  , ( 341, "r")
  , ( 342, "R")
  , ( 343, "r")
  , ( 344, "R")
  , ( 345, "r")
  , ( 346, "S")
  , ( 347, "s")
  , ( 348, "S")
  , ( 349, "s")
  , ( 350, "S")
  , ( 351, "s")
  , ( 352, "S")
  , ( 353, "s")
  , ( 354, "T")
  , ( 355, "t")
  , ( 356, "T")
  , ( 357, "t")
  , ( 358, "T")
  , ( 359, "t")
  , ( 360, "U")
  , ( 361, "u")
  , ( 362, "U")
  , ( 363, "u")
  , ( 364, "U")
  , ( 365, "u")
  , ( 366, "U")
  , ( 367, "u")
  , ( 368, "U")
  , ( 369, "u")
  , ( 370, "U")
  , ( 371, "u")
  , ( 372, "W")
  , ( 373, "w")
  , ( 374, "Y")
  , ( 375, "y")
  , ( 376, "Y")
  , ( 377, "Z")
  , ( 378, "z")
  , ( 379, "Z")
  , ( 380, "z")
  , ( 381, "Z")
  , ( 382, "z")
  , ( 383, "s")
  , ( 384, "b")
  , ( 385, "B")
  , ( 386, "B")
  , ( 387, "b")
  , ( 388, "6")
  , ( 389, "6")
  , ( 390, "O")
  , ( 391, "C")
  , ( 392, "c")
  , ( 393, "D")
  , ( 394, "D")
  , ( 395, "D")
  , ( 396, "d")
  , ( 397, "d")
  , ( 398, "3")
  , ( 399, "@")
  , ( 400, "E")
  , ( 401, "F")
  , ( 402, "f")
  , ( 403, "G")
  , ( 404, "G")
  , ( 405, "hv")
  , ( 406, "I")
  , ( 407, "I")
  , ( 408, "K")
  , ( 409, "k")
  , ( 410, "l")
  , ( 411, "l")
  , ( 412, "W")
  , ( 413, "N")
  , ( 414, "n")
  , ( 415, "O")
  , ( 416, "O")
  , ( 417, "o")
  , ( 418, "OI")
  , ( 419, "oi")
  , ( 420, "P")
  , ( 421, "p")
  , ( 422, "YR")
  , ( 423, "2")
  , ( 424, "2")
  , ( 425, "SH")
  , ( 426, "sh")
  , ( 427, "t")
  , ( 428, "T")
  , ( 429, "t")
  , ( 430, "T")
  , ( 431, "U")
  , ( 432, "u")
  , ( 433, "Y")
  , ( 434, "V")
  , ( 435, "Y")
  , ( 436, "y")
  , ( 437, "Z")
  , ( 438, "z")
  , ( 439, "ZH")
  , ( 440, "ZH")
  , ( 441, "zh")
  , ( 442, "zh")
  , ( 443, "2")
  , ( 444, "5")
  , ( 445, "5")
  , ( 446, "ts")
  , ( 447, "w")
  , ( 448, "|")
  , ( 449, "||")
  , ( 450, "|=")
  , ( 451, "!")
  , ( 452, "DZ")
  , ( 453, "Dz")
  , ( 454, "dz")
  , ( 455, "LJ")
  , ( 456, "Lj")
  , ( 457, "lj")
  , ( 458, "NJ")
  , ( 459, "Nj")
  , ( 460, "nj")
  , ( 461, "A")
  , ( 462, "a")
  , ( 463, "I")
  , ( 464, "i")
  , ( 465, "O")
  , ( 466, "o")
  , ( 467, "U")
  , ( 468, "u")
  , ( 469, "U")
  , ( 470, "u")
  , ( 471, "U")
  , ( 472, "u")
  , ( 473, "U")
  , ( 474, "u")
  , ( 475, "U")
  , ( 476, "u")
  , ( 477, "@")
  , ( 478, "A")
  , ( 479, "a")
  , ( 480, "A")
  , ( 481, "a")
  , ( 482, "AE")
  , ( 483, "ae")
  , ( 484, "G")
  , ( 485, "g")
  , ( 486, "G")
  , ( 487, "g")
  , ( 488, "K")
  , ( 489, "k")
  , ( 490, "O")
  , ( 491, "o")
  , ( 492, "O")
  , ( 493, "o")
  , ( 494, "ZH")
  , ( 495, "zh")
  , ( 496, "j")
  , ( 497, "DZ")
  , ( 498, "Dz")
  , ( 499, "dz")
  , ( 500, "G")
  , ( 501, "g")
  , ( 502, "HV")
  , ( 503, "W")
  , ( 504, "N")
  , ( 505, "n")
  , ( 506, "A")
  , ( 507, "a")
  , ( 508, "AE")
  , ( 509, "ae")
  , ( 510, "O")
  , ( 511, "o")
  , ( 512, "A")
  , ( 513, "a")
  , ( 514, "A")
  , ( 515, "a")
  , ( 516, "E")
  , ( 517, "e")
  , ( 518, "E")
  , ( 519, "e")
  , ( 520, "I")
  , ( 521, "i")
  , ( 522, "I")
  , ( 523, "i")
  , ( 524, "O")
  , ( 525, "o")
  , ( 526, "O")
  , ( 527, "o")
  , ( 528, "R")
  , ( 529, "r")
  , ( 530, "R")
  , ( 531, "r")
  , ( 532, "U")
  , ( 533, "u")
  , ( 534, "U")
  , ( 535, "u")
  , ( 536, "S")
  , ( 537, "s")
  , ( 538, "T")
  , ( 539, "t")
  , ( 540, "Y")
  , ( 541, "y")
  , ( 542, "H")
  , ( 543, "h")
  , ( 544, "N")
  , ( 545, "d")
  , ( 546, "OU")
  , ( 547, "ou")
  , ( 548, "Z")
  , ( 549, "z")
  , ( 550, "A")
  , ( 551, "a")
  , ( 552, "E")
  , ( 553, "e")
  , ( 554, "O")
  , ( 555, "o")
  , ( 556, "O")
  , ( 557, "o")
  , ( 558, "O")
  , ( 559, "o")
  , ( 560, "O")
  , ( 561, "o")
  , ( 562, "Y")
  , ( 563, "y")
  , ( 564, "l")
  , ( 565, "n")
  , ( 566, "t")
  , ( 567, "j")
  , ( 568, "db")
  , ( 569, "qp")
  , ( 570, "A")
  , ( 571, "C")
  , ( 572, "c")
  , ( 573, "L")
  , ( 574, "T")
  , ( 575, "s")
  , ( 576, "z")
  , ( 577, "[?]")
  , ( 578, "[?]")
  , ( 579, "B")
  , ( 580, "U")
  , ( 581, "^")
  , ( 582, "E")
  , ( 583, "e")
  , ( 584, "J")
  , ( 585, "j")
  , ( 586, "q")
  , ( 587, "q")
  , ( 588, "R")
  , ( 589, "r")
  , ( 590, "Y")
  , ( 591, "y")
  , ( 592, "a")
  , ( 593, "a")
  , ( 594, "a")
  , ( 595, "b")
  , ( 596, "o")
  , ( 597, "c")
  , ( 598, "d")
  , ( 599, "d")
  , ( 600, "e")
  , ( 601, "@")
  , ( 602, "@")
  , ( 603, "e")
  , ( 604, "e")
  , ( 605, "e")
  , ( 606, "e")
  , ( 607, "j")
  , ( 608, "g")
  , ( 609, "g")
  , ( 610, "g")
  , ( 611, "g")
  , ( 612, "u")
  , ( 613, "Y")
  , ( 614, "h")
  , ( 615, "h")
  , ( 616, "i")
  , ( 617, "i")
  , ( 618, "I")
  , ( 619, "l")
  , ( 620, "l")
  , ( 621, "l")
  , ( 622, "lZ")
  , ( 623, "W")
  , ( 624, "W")
  , ( 625, "m")
  , ( 626, "n")
  , ( 627, "n")
  , ( 628, "n")
  , ( 629, "o")
  , ( 630, "OE")
  , ( 631, "O")
  , ( 632, "F")
  , ( 633, "r")
  , ( 634, "r")
  , ( 635, "r")
  , ( 636, "r")
  , ( 637, "r")
  , ( 638, "r")
  , ( 639, "r")
  , ( 640, "R")
  , ( 641, "R")
  , ( 642, "s")
  , ( 643, "S")
  , ( 644, "j")
  , ( 645, "S")
  , ( 646, "S")
  , ( 647, "t")
  , ( 648, "t")
  , ( 649, "u")
  , ( 650, "U")
  , ( 651, "v")
  , ( 652, "^")
  , ( 653, "w")
  , ( 654, "y")
  , ( 655, "Y")
  , ( 656, "z")
  , ( 657, "z")
  , ( 658, "Z")
  , ( 659, "Z")
  , ( 660, "?")
  , ( 661, "?")
  , ( 662, "?")
  , ( 663, "C")
  , ( 664, "@")
  , ( 665, "B")
  , ( 666, "E")
  , ( 667, "G")
  , ( 668, "H")
  , ( 669, "j")
  , ( 670, "k")
  , ( 671, "L")
  , ( 672, "q")
  , ( 673, "?")
  , ( 674, "?")
  , ( 675, "dz")
  , ( 676, "dZ")
  , ( 677, "dz")
  , ( 678, "ts")
  , ( 679, "tS")
  , ( 680, "tC")
  , ( 681, "fN")
  , ( 682, "ls")
  , ( 683, "lz")
  , ( 684, "WW")
  , ( 685, "]]")
  , ( 686, "h")
  , ( 687, "h")
  , ( 688, "k")
  , ( 689, "h")
  , ( 690, "j")
  , ( 691, "r")
  , ( 692, "r")
  , ( 693, "r")
  , ( 694, "r")
  , ( 695, "w")
  , ( 696, "y")
  , ( 697, "'")
  , ( 698, "\"")
  , ( 699, "`")
  , ( 700, "'")
  , ( 701, "`")
  , ( 702, "`")
  , ( 703, "'")
  , ( 704, "?")
  , ( 705, "?")
  , ( 706, "<")
  , ( 707, ">")
  , ( 708, "^")
  , ( 709, "V")
  , ( 710, "^")
  , ( 711, "V")
  , ( 712, "'")
  , ( 713, "-")
  , ( 714, "/")
  , ( 715, "\\")
  , ( 716, ",")
  , ( 717, "_")
  , ( 718, "\\")
  , ( 719, "/")
  , ( 720, ":")
  , ( 721, ".")
  , ( 722, "`")
  , ( 723, "'")
  , ( 724, "^")
  , ( 725, "V")
  , ( 726, "+")
  , ( 727, "-")
  , ( 728, "V")
  , ( 729, ".")
  , ( 730, "@")
  , ( 731, ",")
  , ( 732, "~")
  , ( 733, "\"")
  , ( 734, "R")
  , ( 735, "X")
  , ( 736, "G")
  , ( 737, "l")
  , ( 738, "s")
  , ( 739, "x")
  , ( 740, "?")
  , ( 748, "V")
  , ( 749, "=")
  , ( 750, "\"")
  , ( 751, "[?]")
  , ( 752, "[?]")
  , ( 753, "[?]")
  , ( 754, "[?]")
  , ( 755, "[?]")
  , ( 756, "[?]")
  , ( 757, "[?]")
  , ( 758, "[?]")
  , ( 759, "[?]")
  , ( 760, "[?]")
  , ( 761, "[?]")
  , ( 762, "[?]")
  , ( 763, "[?]")
  , ( 764, "[?]")
  , ( 765, "[?]")
  , ( 766, "[?]")
  , ( 847, "[?]")
  , ( 848, "[?]")
  , ( 849, "[?]")
  , ( 850, "[?]")
  , ( 851, "[?]")
  , ( 852, "[?]")
  , ( 853, "[?]")
  , ( 854, "[?]")
  , ( 855, "[?]")
  , ( 856, "[?]")
  , ( 857, "[?]")
  , ( 858, "[?]")
  , ( 859, "[?]")
  , ( 860, "[?]")
  , ( 861, "[?]")
  , ( 862, "[?]")
  , ( 863, "[?]")
  , ( 867, "a")
  , ( 868, "e")
  , ( 869, "i")
  , ( 870, "o")
  , ( 871, "u")
  , ( 872, "c")
  , ( 873, "d")
  , ( 874, "h")
  , ( 875, "m")
  , ( 876, "r")
  , ( 877, "t")
  , ( 878, "v")
  , ( 879, "x")
  , ( 880, "[?]")
  , ( 881, "[?]")
  , ( 882, "[?]")
  , ( 883, "[?]")
  , ( 884, "'")
  , ( 885, ",")
  , ( 886, "[?]")
  , ( 887, "[?]")
  , ( 888, "[?]")
  , ( 889, "[?]")
  , ( 891, "[?]")
  , ( 892, "[?]")
  , ( 893, "[?]")
  , ( 894, "?")
  , ( 895, "[?]")
  , ( 896, "[?]")
  , ( 897, "[?]")
  , ( 898, "[?]")
  , ( 899, "[?]")
  , ( 902, "A")
  , ( 903, ";")
  , ( 904, "E")
  , ( 905, "E")
  , ( 906, "I")
  , ( 907, "[?]")
  , ( 908, "O")
  , ( 909, "[?]")
  , ( 910, "U")
  , ( 911, "O")
  , ( 912, "I")
  , ( 913, "A")
  , ( 914, "B")
  , ( 915, "G")
  , ( 916, "D")
  , ( 917, "E")
  , ( 918, "Z")
  , ( 919, "E")
  , ( 920, "Th")
  , ( 921, "I")
  , ( 922, "K")
  , ( 923, "L")
  , ( 924, "M")
  , ( 925, "N")
  , ( 926, "Ks")
  , ( 927, "O")
  , ( 928, "P")
  , ( 929, "R")
  , ( 930, "[?]")
  , ( 931, "S")
  , ( 932, "T")
  , ( 933, "U")
  , ( 934, "Ph")
  , ( 935, "Kh")
  , ( 936, "Ps")
  , ( 937, "O")
  , ( 938, "I")
  , ( 939, "U")
  , ( 940, "a")
  , ( 941, "e")
  , ( 942, "e")
  , ( 943, "i")
  , ( 944, "u")
  , ( 945, "a")
  , ( 946, "b")
  , ( 947, "g")
  , ( 948, "d")
  , ( 949, "e")
  , ( 950, "z")
  , ( 951, "e")
  , ( 952, "th")
  , ( 953, "i")
  , ( 954, "k")
  , ( 955, "l")
  , ( 956, "m")
  , ( 957, "n")
  , ( 958, "x")
  , ( 959, "o")
  , ( 960, "p")
  , ( 961, "r")
  , ( 962, "s")
  , ( 963, "s")
  , ( 964, "t")
  , ( 965, "u")
  , ( 966, "ph")
  , ( 967, "kh")
  , ( 968, "ps")
  , ( 969, "o")
  , ( 970, "i")
  , ( 971, "u")
  , ( 972, "o")
  , ( 973, "u")
  , ( 974, "o")
  , ( 975, "[?]")
  , ( 976, "b")
  , ( 977, "th")
  , ( 978, "U")
  , ( 979, "U")
  , ( 980, "U")
  , ( 981, "ph")
  , ( 982, "p")
  , ( 983, "&")
  , ( 984, "[?]")
  , ( 985, "[?]")
  , ( 986, "St")
  , ( 987, "st")
  , ( 988, "W")
  , ( 989, "w")
  , ( 990, "Q")
  , ( 991, "q")
  , ( 992, "Sp")
  , ( 993, "sp")
  , ( 994, "Sh")
  , ( 995, "sh")
  , ( 996, "F")
  , ( 997, "f")
  , ( 998, "Kh")
  , ( 999, "kh")
  , ( 1000, "H")
  , ( 1001, "h")
  , ( 1002, "G")
  , ( 1003, "g")
  , ( 1004, "CH")
  , ( 1005, "ch")
  , ( 1006, "Ti")
  , ( 1007, "ti")
  , ( 1008, "k")
  , ( 1009, "r")
  , ( 1010, "c")
  , ( 1011, "j")
  , ( 1012, "[?]")
  , ( 1013, "[?]")
  , ( 1014, "[?]")
  , ( 1015, "[?]")
  , ( 1016, "[?]")
  , ( 1017, "[?]")
  , ( 1018, "[?]")
  , ( 1019, "[?]")
  , ( 1020, "[?]")
  , ( 1021, "[?]")
  , ( 1022, "[?]")
  , ( 1024, "Ie")
  , ( 1025, "Io")
  , ( 1026, "Dj")
  , ( 1027, "Gj")
  , ( 1028, "Ie")
  , ( 1029, "Dz")
  , ( 1030, "I")
  , ( 1031, "Yi")
  , ( 1032, "J")
  , ( 1033, "Lj")
  , ( 1034, "Nj")
  , ( 1035, "Tsh")
  , ( 1036, "Kj")
  , ( 1037, "I")
  , ( 1038, "U")
  , ( 1039, "Dzh")
  , ( 1040, "A")
  , ( 1041, "B")
  , ( 1042, "V")
  , ( 1043, "G")
  , ( 1044, "D")
  , ( 1045, "E")
  , ( 1046, "Zh")
  , ( 1047, "Z")
  , ( 1048, "I")
  , ( 1049, "I")
  , ( 1050, "K")
  , ( 1051, "L")
  , ( 1052, "M")
  , ( 1053, "N")
  , ( 1054, "O")
  , ( 1055, "P")
  , ( 1056, "R")
  , ( 1057, "S")
  , ( 1058, "T")
  , ( 1059, "U")
  , ( 1060, "F")
  , ( 1061, "Kh")
  , ( 1062, "Ts")
  , ( 1063, "Ch")
  , ( 1064, "Sh")
  , ( 1065, "Shch")
  , ( 1066, "'")
  , ( 1067, "Y")
  , ( 1068, "'")
  , ( 1069, "E")
  , ( 1070, "Iu")
  , ( 1071, "Ia")
  , ( 1072, "a")
  , ( 1073, "b")
  , ( 1074, "v")
  , ( 1075, "g")
  , ( 1076, "d")
  , ( 1077, "e")
  , ( 1078, "zh")
  , ( 1079, "z")
  , ( 1080, "i")
  , ( 1081, "i")
  , ( 1082, "k")
  , ( 1083, "l")
  , ( 1084, "m")
  , ( 1085, "n")
  , ( 1086, "o")
  , ( 1087, "p")
  , ( 1088, "r")
  , ( 1089, "s")
  , ( 1090, "t")
  , ( 1091, "u")
  , ( 1092, "f")
  , ( 1093, "kh")
  , ( 1094, "ts")
  , ( 1095, "ch")
  , ( 1096, "sh")
  , ( 1097, "shch")
  , ( 1098, "'")
  , ( 1099, "y")
  , ( 1100, "'")
  , ( 1101, "e")
  , ( 1102, "iu")
  , ( 1103, "ia")
  , ( 1104, "ie")
  , ( 1105, "io")
  , ( 1106, "dj")
  , ( 1107, "gj")
  , ( 1108, "ie")
  , ( 1109, "dz")
  , ( 1110, "i")
  , ( 1111, "yi")
  , ( 1112, "j")
  , ( 1113, "lj")
  , ( 1114, "nj")
  , ( 1115, "tsh")
  , ( 1116, "kj")
  , ( 1117, "i")
  , ( 1118, "u")
  , ( 1119, "dzh")
  , ( 1120, "O")
  , ( 1121, "o")
  , ( 1122, "E")
  , ( 1123, "e")
  , ( 1124, "Ie")
  , ( 1125, "ie")
  , ( 1126, "E")
  , ( 1127, "e")
  , ( 1128, "Ie")
  , ( 1129, "ie")
  , ( 1130, "O")
  , ( 1131, "o")
  , ( 1132, "Io")
  , ( 1133, "io")
  , ( 1134, "Ks")
  , ( 1135, "ks")
  , ( 1136, "Ps")
  , ( 1137, "ps")
  , ( 1138, "F")
  , ( 1139, "f")
  , ( 1140, "Y")
  , ( 1141, "y")
  , ( 1142, "Y")
  , ( 1143, "y")
  , ( 1144, "u")
  , ( 1145, "u")
  , ( 1146, "O")
  , ( 1147, "o")
  , ( 1148, "O")
  , ( 1149, "o")
  , ( 1150, "Ot")
  , ( 1151, "ot")
  , ( 1152, "Q")
  , ( 1153, "q")
  , ( 1154, "*1000*")
  , ( 1159, "[?]")
  , ( 1160, "*100.000*")
  , ( 1161, "*1.000.000*")
  , ( 1162, "[?]")
  , ( 1163, "[?]")
  , ( 1164, "\"")
  , ( 1165, "\"")
  , ( 1166, "R'")
  , ( 1167, "r'")
  , ( 1168, "G'")
  , ( 1169, "g'")
  , ( 1170, "G'")
  , ( 1171, "g'")
  , ( 1172, "G'")
  , ( 1173, "g'")
  , ( 1174, "Zh'")
  , ( 1175, "zh'")
  , ( 1176, "Z'")
  , ( 1177, "z'")
  , ( 1178, "K'")
  , ( 1179, "k'")
  , ( 1180, "K'")
  , ( 1181, "k'")
  , ( 1182, "K'")
  , ( 1183, "k'")
  , ( 1184, "K'")
  , ( 1185, "k'")
  , ( 1186, "N'")
  , ( 1187, "n'")
  , ( 1188, "Ng")
  , ( 1189, "ng")
  , ( 1190, "P'")
  , ( 1191, "p'")
  , ( 1192, "Kh")
  , ( 1193, "kh")
  , ( 1194, "S'")
  , ( 1195, "s'")
  , ( 1196, "T'")
  , ( 1197, "t'")
  , ( 1198, "U")
  , ( 1199, "u")
  , ( 1200, "U'")
  , ( 1201, "u'")
  , ( 1202, "Kh'")
  , ( 1203, "kh'")
  , ( 1204, "Tts")
  , ( 1205, "tts")
  , ( 1206, "Ch'")
  , ( 1207, "ch'")
  , ( 1208, "Ch'")
  , ( 1209, "ch'")
  , ( 1210, "H")
  , ( 1211, "h")
  , ( 1212, "Ch")
  , ( 1213, "ch")
  , ( 1214, "Ch'")
  , ( 1215, "ch'")
  , ( 1216, "`")
  , ( 1217, "Zh")
  , ( 1218, "zh")
  , ( 1219, "K'")
  , ( 1220, "k'")
  , ( 1221, "[?]")
  , ( 1222, "[?]")
  , ( 1223, "N'")
  , ( 1224, "n'")
  , ( 1225, "[?]")
  , ( 1226, "[?]")
  , ( 1227, "Ch")
  , ( 1228, "ch")
  , ( 1229, "[?]")
  , ( 1230, "[?]")
  , ( 1231, "[?]")
  , ( 1232, "a")
  , ( 1233, "a")
  , ( 1234, "A")
  , ( 1235, "a")
  , ( 1236, "Ae")
  , ( 1237, "ae")
  , ( 1238, "Ie")
  , ( 1239, "ie")
  , ( 1240, "@")
  , ( 1241, "@")
  , ( 1242, "@")
  , ( 1243, "@")
  , ( 1244, "Zh")
  , ( 1245, "zh")
  , ( 1246, "Z")
  , ( 1247, "z")
  , ( 1248, "Dz")
  , ( 1249, "dz")
  , ( 1250, "I")
  , ( 1251, "i")
  , ( 1252, "I")
  , ( 1253, "i")
  , ( 1254, "O")
  , ( 1255, "o")
  , ( 1256, "O")
  , ( 1257, "o")
  , ( 1258, "O")
  , ( 1259, "o")
  , ( 1260, "E")
  , ( 1261, "e")
  , ( 1262, "U")
  , ( 1263, "u")
  , ( 1264, "U")
  , ( 1265, "u")
  , ( 1266, "U")
  , ( 1267, "u")
  , ( 1268, "Ch")
  , ( 1269, "ch")
  , ( 1270, "[?]")
  , ( 1271, "[?]")
  , ( 1272, "Y")
  , ( 1273, "y")
  , ( 1274, "[?]")
  , ( 1275, "[?]")
  , ( 1276, "[?]")
  , ( 1277, "[?]")
  , ( 1278, "[?]")
  , ( 1280, "[?]")
  , ( 1281, "[?]")
  , ( 1282, "[?]")
  , ( 1283, "[?]")
  , ( 1284, "[?]")
  , ( 1285, "[?]")
  , ( 1286, "[?]")
  , ( 1287, "[?]")
  , ( 1288, "[?]")
  , ( 1289, "[?]")
  , ( 1290, "[?]")
  , ( 1291, "[?]")
  , ( 1292, "[?]")
  , ( 1293, "[?]")
  , ( 1294, "[?]")
  , ( 1295, "[?]")
  , ( 1296, "[?]")
  , ( 1297, "[?]")
  , ( 1298, "[?]")
  , ( 1299, "[?]")
  , ( 1300, "[?]")
  , ( 1301, "[?]")
  , ( 1302, "[?]")
  , ( 1303, "[?]")
  , ( 1304, "[?]")
  , ( 1305, "[?]")
  , ( 1306, "[?]")
  , ( 1307, "[?]")
  , ( 1308, "[?]")
  , ( 1309, "[?]")
  , ( 1310, "[?]")
  , ( 1311, "[?]")
  , ( 1312, "[?]")
  , ( 1313, "[?]")
  , ( 1314, "[?]")
  , ( 1315, "[?]")
  , ( 1316, "[?]")
  , ( 1317, "[?]")
  , ( 1318, "[?]")
  , ( 1319, "[?]")
  , ( 1320, "[?]")
  , ( 1321, "[?]")
  , ( 1322, "[?]")
  , ( 1323, "[?]")
  , ( 1324, "[?]")
  , ( 1325, "[?]")
  , ( 1326, "[?]")
  , ( 1327, "[?]")
  , ( 1328, "[?]")
  , ( 1329, "A")
  , ( 1330, "B")
  , ( 1331, "G")
  , ( 1332, "D")
  , ( 1333, "E")
  , ( 1334, "Z")
  , ( 1335, "E")
  , ( 1336, "E")
  , ( 1337, "T`")
  , ( 1338, "Zh")
  , ( 1339, "I")
  , ( 1340, "L")
  , ( 1341, "Kh")
  , ( 1342, "Ts")
  , ( 1343, "K")
  , ( 1344, "H")
  , ( 1345, "Dz")
  , ( 1346, "Gh")
  , ( 1347, "Ch")
  , ( 1348, "M")
  , ( 1349, "Y")
  , ( 1350, "N")
  , ( 1351, "Sh")
  , ( 1352, "O")
  , ( 1353, "Ch`")
  , ( 1354, "P")
  , ( 1355, "J")
  , ( 1356, "Rh")
  , ( 1357, "S")
  , ( 1358, "V")
  , ( 1359, "T")
  , ( 1360, "R")
  , ( 1361, "Ts`")
  , ( 1362, "W")
  , ( 1363, "P`")
  , ( 1364, "K`")
  , ( 1365, "O")
  , ( 1366, "F")
  , ( 1367, "[?]")
  , ( 1368, "[?]")
  , ( 1369, "<")
  , ( 1370, "'")
  , ( 1371, "/")
  , ( 1372, "!")
  , ( 1373, ",")
  , ( 1374, "?")
  , ( 1375, ".")
  , ( 1376, "[?]")
  , ( 1377, "a")
  , ( 1378, "b")
  , ( 1379, "g")
  , ( 1380, "d")
  , ( 1381, "e")
  , ( 1382, "z")
  , ( 1383, "e")
  , ( 1384, "e")
  , ( 1385, "t`")
  , ( 1386, "zh")
  , ( 1387, "i")
  , ( 1388, "l")
  , ( 1389, "kh")
  , ( 1390, "ts")
  , ( 1391, "k")
  , ( 1392, "h")
  , ( 1393, "dz")
  , ( 1394, "gh")
  , ( 1395, "ch")
  , ( 1396, "m")
  , ( 1397, "y")
  , ( 1398, "n")
  , ( 1399, "sh")
  , ( 1400, "o")
  , ( 1401, "ch`")
  , ( 1402, "p")
  , ( 1403, "j")
  , ( 1404, "rh")
  , ( 1405, "s")
  , ( 1406, "v")
  , ( 1407, "t")
  , ( 1408, "r")
  , ( 1409, "ts`")
  , ( 1410, "w")
  , ( 1411, "p`")
  , ( 1412, "k`")
  , ( 1413, "o")
  , ( 1414, "f")
  , ( 1415, "ew")
  , ( 1416, "[?]")
  , ( 1417, ":")
  , ( 1418, "-")
  , ( 1419, "[?]")
  , ( 1420, "[?]")
  , ( 1421, "[?]")
  , ( 1422, "[?]")
  , ( 1423, "[?]")
  , ( 1424, "[?]")
  , ( 1442, "[?]")
  , ( 1456, "@")
  , ( 1457, "e")
  , ( 1458, "a")
  , ( 1459, "o")
  , ( 1460, "i")
  , ( 1461, "e")
  , ( 1462, "e")
  , ( 1463, "a")
  , ( 1464, "a")
  , ( 1465, "o")
  , ( 1466, "[?]")
  , ( 1467, "u")
  , ( 1468, "'")
  , ( 1472, "|")
  , ( 1475, ":")
  , ( 1477, "[?]")
  , ( 1478, "[?]")
  , ( 1479, "[?]")
  , ( 1480, "[?]")
  , ( 1481, "[?]")
  , ( 1482, "[?]")
  , ( 1483, "[?]")
  , ( 1484, "[?]")
  , ( 1485, "[?]")
  , ( 1486, "[?]")
  , ( 1487, "[?]")
  , ( 1489, "b")
  , ( 1490, "g")
  , ( 1491, "d")
  , ( 1492, "h")
  , ( 1493, "v")
  , ( 1494, "z")
  , ( 1495, "kh")
  , ( 1496, "t")
  , ( 1497, "y")
  , ( 1498, "k")
  , ( 1499, "k")
  , ( 1500, "l")
  , ( 1501, "m")
  , ( 1502, "m")
  , ( 1503, "n")
  , ( 1504, "n")
  , ( 1505, "s")
  , ( 1506, "`")
  , ( 1507, "p")
  , ( 1508, "p")
  , ( 1509, "ts")
  , ( 1510, "ts")
  , ( 1511, "q")
  , ( 1512, "r")
  , ( 1513, "sh")
  , ( 1514, "t")
  , ( 1515, "[?]")
  , ( 1516, "[?]")
  , ( 1517, "[?]")
  , ( 1518, "[?]")
  , ( 1519, "[?]")
  , ( 1520, "V")
  , ( 1521, "oy")
  , ( 1522, "i")
  , ( 1523, "'")
  , ( 1524, "\"")
  , ( 1525, "[?]")
  , ( 1526, "[?]")
  , ( 1527, "[?]")
  , ( 1528, "[?]")
  , ( 1529, "[?]")
  , ( 1530, "[?]")
  , ( 1531, "[?]")
  , ( 1532, "[?]")
  , ( 1533, "[?]")
  , ( 1534, "[?]")
  , ( 1536, "[?]")
  , ( 1537, "[?]")
  , ( 1538, "[?]")
  , ( 1539, "[?]")
  , ( 1540, "[?]")
  , ( 1541, "[?]")
  , ( 1542, "[?]")
  , ( 1543, "[?]")
  , ( 1544, "[?]")
  , ( 1545, "[?]")
  , ( 1546, "[?]")
  , ( 1547, "[?]")
  , ( 1548, ",")
  , ( 1549, "[?]")
  , ( 1550, "[?]")
  , ( 1551, "[?]")
  , ( 1552, "[?]")
  , ( 1553, "[?]")
  , ( 1554, "[?]")
  , ( 1555, "[?]")
  , ( 1556, "[?]")
  , ( 1557, "[?]")
  , ( 1558, "[?]")
  , ( 1559, "[?]")
  , ( 1560, "[?]")
  , ( 1561, "[?]")
  , ( 1562, "[?]")
  , ( 1563, ";")
  , ( 1564, "[?]")
  , ( 1565, "[?]")
  , ( 1566, "[?]")
  , ( 1567, "?")
  , ( 1568, "[?]")
  , ( 1570, "a")
  , ( 1571, "'")
  , ( 1572, "w'")
  , ( 1574, "y'")
  , ( 1576, "b")
  , ( 1577, "@")
  , ( 1578, "t")
  , ( 1579, "th")
  , ( 1580, "j")
  , ( 1581, "H")
  , ( 1582, "kh")
  , ( 1583, "d")
  , ( 1584, "dh")
  , ( 1585, "r")
  , ( 1586, "z")
  , ( 1587, "s")
  , ( 1588, "sh")
  , ( 1589, "S")
  , ( 1590, "D")
  , ( 1591, "T")
  , ( 1592, "Z")
  , ( 1593, "`")
  , ( 1594, "G")
  , ( 1595, "[?]")
  , ( 1596, "[?]")
  , ( 1597, "[?]")
  , ( 1598, "[?]")
  , ( 1599, "[?]")
  , ( 1601, "f")
  , ( 1602, "q")
  , ( 1603, "k")
  , ( 1604, "l")
  , ( 1605, "m")
  , ( 1606, "n")
  , ( 1607, "h")
  , ( 1608, "w")
  , ( 1609, "~")
  , ( 1610, "y")
  , ( 1611, "an")
  , ( 1612, "un")
  , ( 1613, "in")
  , ( 1614, "a")
  , ( 1615, "u")
  , ( 1616, "i")
  , ( 1617, "W")
  , ( 1620, "'")
  , ( 1621, "'")
  , ( 1622, "[?]")
  , ( 1623, "[?]")
  , ( 1624, "[?]")
  , ( 1625, "[?]")
  , ( 1626, "[?]")
  , ( 1627, "[?]")
  , ( 1628, "[?]")
  , ( 1629, "[?]")
  , ( 1630, "[?]")
  , ( 1631, "[?]")
  , ( 1632, "0")
  , ( 1633, "1")
  , ( 1634, "2")
  , ( 1635, "3")
  , ( 1636, "4")
  , ( 1637, "5")
  , ( 1638, "6")
  , ( 1639, "7")
  , ( 1640, "8")
  , ( 1641, "9")
  , ( 1642, "%")
  , ( 1643, ".")
  , ( 1644, ",")
  , ( 1645, "*")
  , ( 1646, "[?]")
  , ( 1647, "[?]")
  , ( 1649, "'")
  , ( 1650, "'")
  , ( 1651, "'")
  , ( 1653, "'")
  , ( 1654, "'w")
  , ( 1655, "'u")
  , ( 1656, "'y")
  , ( 1657, "tt")
  , ( 1658, "tth")
  , ( 1659, "b")
  , ( 1660, "t")
  , ( 1661, "T")
  , ( 1662, "p")
  , ( 1663, "th")
  , ( 1664, "bh")
  , ( 1665, "'h")
  , ( 1666, "H")
  , ( 1667, "ny")
  , ( 1668, "dy")
  , ( 1669, "H")
  , ( 1670, "ch")
  , ( 1671, "cch")
  , ( 1672, "dd")
  , ( 1673, "D")
  , ( 1674, "D")
  , ( 1675, "Dt")
  , ( 1676, "dh")
  , ( 1677, "ddh")
  , ( 1678, "d")
  , ( 1679, "D")
  , ( 1680, "D")
  , ( 1681, "rr")
  , ( 1682, "R")
  , ( 1683, "R")
  , ( 1684, "R")
  , ( 1685, "R")
  , ( 1686, "R")
  , ( 1687, "R")
  , ( 1688, "j")
  , ( 1689, "R")
  , ( 1690, "S")
  , ( 1691, "S")
  , ( 1692, "S")
  , ( 1693, "S")
  , ( 1694, "S")
  , ( 1695, "T")
  , ( 1696, "GH")
  , ( 1697, "F")
  , ( 1698, "F")
  , ( 1699, "F")
  , ( 1700, "v")
  , ( 1701, "f")
  , ( 1702, "ph")
  , ( 1703, "Q")
  , ( 1704, "Q")
  , ( 1705, "kh")
  , ( 1706, "k")
  , ( 1707, "K")
  , ( 1708, "K")
  , ( 1709, "ng")
  , ( 1710, "K")
  , ( 1711, "g")
  , ( 1712, "G")
  , ( 1713, "N")
  , ( 1714, "G")
  , ( 1715, "G")
  , ( 1716, "G")
  , ( 1717, "L")
  , ( 1718, "L")
  , ( 1719, "L")
  , ( 1720, "L")
  , ( 1721, "N")
  , ( 1722, "N")
  , ( 1723, "N")
  , ( 1724, "N")
  , ( 1725, "N")
  , ( 1726, "h")
  , ( 1727, "Ch")
  , ( 1728, "hy")
  , ( 1729, "h")
  , ( 1730, "H")
  , ( 1731, "@")
  , ( 1732, "W")
  , ( 1733, "oe")
  , ( 1734, "oe")
  , ( 1735, "u")
  , ( 1736, "yu")
  , ( 1737, "yu")
  , ( 1738, "W")
  , ( 1739, "v")
  , ( 1740, "y")
  , ( 1741, "Y")
  , ( 1742, "Y")
  , ( 1743, "W")
  , ( 1746, "y")
  , ( 1747, "y'")
  , ( 1748, ".")
  , ( 1749, "ae")
  , ( 1757, "@")
  , ( 1758, "#")
  , ( 1769, "^")
  , ( 1774, "[?]")
  , ( 1775, "[?]")
  , ( 1776, "0")
  , ( 1777, "1")
  , ( 1778, "2")
  , ( 1779, "3")
  , ( 1780, "4")
  , ( 1781, "5")
  , ( 1782, "6")
  , ( 1783, "7")
  , ( 1784, "8")
  , ( 1785, "9")
  , ( 1786, "Sh")
  , ( 1787, "D")
  , ( 1788, "Gh")
  , ( 1789, "&")
  , ( 1790, "+m")
  , ( 1792, "//")
  , ( 1793, "/")
  , ( 1794, ",")
  , ( 1795, "!")
  , ( 1796, "!")
  , ( 1797, "-")
  , ( 1798, ",")
  , ( 1799, ",")
  , ( 1800, ";")
  , ( 1801, "?")
  , ( 1802, "~")
  , ( 1803, "{")
  , ( 1804, "}")
  , ( 1805, "*")
  , ( 1806, "[?]")
  , ( 1808, "'")
  , ( 1810, "b")
  , ( 1811, "g")
  , ( 1812, "g")
  , ( 1813, "d")
  , ( 1814, "d")
  , ( 1815, "h")
  , ( 1816, "w")
  , ( 1817, "z")
  , ( 1818, "H")
  , ( 1819, "t")
  , ( 1820, "t")
  , ( 1821, "y")
  , ( 1822, "yh")
  , ( 1823, "k")
  , ( 1824, "l")
  , ( 1825, "m")
  , ( 1826, "n")
  , ( 1827, "s")
  , ( 1828, "s")
  , ( 1829, "`")
  , ( 1830, "p")
  , ( 1831, "p")
  , ( 1832, "S")
  , ( 1833, "q")
  , ( 1834, "r")
  , ( 1835, "sh")
  , ( 1836, "t")
  , ( 1837, "[?]")
  , ( 1838, "[?]")
  , ( 1839, "[?]")
  , ( 1840, "a")
  , ( 1841, "a")
  , ( 1842, "a")
  , ( 1843, "A")
  , ( 1844, "A")
  , ( 1845, "A")
  , ( 1846, "e")
  , ( 1847, "e")
  , ( 1848, "e")
  , ( 1849, "E")
  , ( 1850, "i")
  , ( 1851, "i")
  , ( 1852, "u")
  , ( 1853, "u")
  , ( 1854, "u")
  , ( 1855, "o")
  , ( 1857, "`")
  , ( 1858, "'")
  , ( 1861, "X")
  , ( 1862, "Q")
  , ( 1863, "@")
  , ( 1864, "@")
  , ( 1865, "|")
  , ( 1866, "+")
  , ( 1867, "[?]")
  , ( 1868, "[?]")
  , ( 1869, "[?]")
  , ( 1870, "[?]")
  , ( 1871, "[?]")
  , ( 1872, "[?]")
  , ( 1873, "[?]")
  , ( 1874, "[?]")
  , ( 1875, "[?]")
  , ( 1876, "[?]")
  , ( 1877, "[?]")
  , ( 1878, "[?]")
  , ( 1879, "[?]")
  , ( 1880, "[?]")
  , ( 1881, "[?]")
  , ( 1882, "[?]")
  , ( 1883, "[?]")
  , ( 1884, "[?]")
  , ( 1885, "[?]")
  , ( 1886, "[?]")
  , ( 1887, "[?]")
  , ( 1888, "[?]")
  , ( 1889, "[?]")
  , ( 1890, "[?]")
  , ( 1891, "[?]")
  , ( 1892, "[?]")
  , ( 1893, "[?]")
  , ( 1894, "[?]")
  , ( 1895, "[?]")
  , ( 1896, "[?]")
  , ( 1897, "[?]")
  , ( 1898, "[?]")
  , ( 1899, "[?]")
  , ( 1900, "[?]")
  , ( 1901, "[?]")
  , ( 1902, "[?]")
  , ( 1903, "[?]")
  , ( 1904, "[?]")
  , ( 1905, "[?]")
  , ( 1906, "[?]")
  , ( 1907, "[?]")
  , ( 1908, "[?]")
  , ( 1909, "[?]")
  , ( 1910, "[?]")
  , ( 1911, "[?]")
  , ( 1912, "[?]")
  , ( 1913, "[?]")
  , ( 1914, "[?]")
  , ( 1915, "[?]")
  , ( 1916, "[?]")
  , ( 1917, "[?]")
  , ( 1918, "[?]")
  , ( 1919, "[?]")
  , ( 1920, "h")
  , ( 1921, "sh")
  , ( 1922, "n")
  , ( 1923, "r")
  , ( 1924, "b")
  , ( 1925, "L")
  , ( 1926, "k")
  , ( 1927, "'")
  , ( 1928, "v")
  , ( 1929, "m")
  , ( 1930, "f")
  , ( 1931, "dh")
  , ( 1932, "th")
  , ( 1933, "l")
  , ( 1934, "g")
  , ( 1935, "ny")
  , ( 1936, "s")
  , ( 1937, "d")
  , ( 1938, "z")
  , ( 1939, "t")
  , ( 1940, "y")
  , ( 1941, "p")
  , ( 1942, "j")
  , ( 1943, "ch")
  , ( 1944, "tt")
  , ( 1945, "hh")
  , ( 1946, "kh")
  , ( 1947, "th")
  , ( 1948, "z")
  , ( 1949, "sh")
  , ( 1950, "s")
  , ( 1951, "d")
  , ( 1952, "t")
  , ( 1953, "z")
  , ( 1954, "`")
  , ( 1955, "gh")
  , ( 1956, "q")
  , ( 1957, "w")
  , ( 1958, "a")
  , ( 1959, "aa")
  , ( 1960, "i")
  , ( 1961, "ee")
  , ( 1962, "u")
  , ( 1963, "oo")
  , ( 1964, "e")
  , ( 1965, "ey")
  , ( 1966, "o")
  , ( 1967, "oa")
  , ( 1969, "[?]")
  , ( 1970, "[?]")
  , ( 1971, "[?]")
  , ( 1972, "[?]")
  , ( 1973, "[?]")
  , ( 1974, "[?]")
  , ( 1975, "[?]")
  , ( 1976, "[?]")
  , ( 1977, "[?]")
  , ( 1978, "[?]")
  , ( 1979, "[?]")
  , ( 1980, "[?]")
  , ( 1981, "[?]")
  , ( 1982, "[?]")
  , ( 1983, "[?]")
  , ( 1984, "[?]")
  , ( 1985, "[?]")
  , ( 1986, "[?]")
  , ( 1987, "[?]")
  , ( 1988, "[?]")
  , ( 1989, "[?]")
  , ( 1990, "[?]")
  , ( 1991, "[?]")
  , ( 1992, "[?]")
  , ( 1993, "[?]")
  , ( 1994, "[?]")
  , ( 1995, "[?]")
  , ( 1996, "[?]")
  , ( 1997, "[?]")
  , ( 1998, "[?]")
  , ( 1999, "[?]")
  , ( 2000, "[?]")
  , ( 2001, "[?]")
  , ( 2002, "[?]")
  , ( 2003, "[?]")
  , ( 2004, "[?]")
  , ( 2005, "[?]")
  , ( 2006, "[?]")
  , ( 2007, "[?]")
  , ( 2008, "[?]")
  , ( 2009, "[?]")
  , ( 2010, "[?]")
  , ( 2011, "[?]")
  , ( 2012, "[?]")
  , ( 2013, "[?]")
  , ( 2014, "[?]")
  , ( 2015, "[?]")
  , ( 2016, "[?]")
  , ( 2017, "[?]")
  , ( 2018, "[?]")
  , ( 2019, "[?]")
  , ( 2020, "[?]")
  , ( 2021, "[?]")
  , ( 2022, "[?]")
  , ( 2023, "[?]")
  , ( 2024, "[?]")
  , ( 2025, "[?]")
  , ( 2026, "[?]")
  , ( 2027, "[?]")
  , ( 2028, "[?]")
  , ( 2029, "[?]")
  , ( 2030, "[?]")
  , ( 2031, "[?]")
  , ( 2032, "[?]")
  , ( 2033, "[?]")
  , ( 2034, "[?]")
  , ( 2035, "[?]")
  , ( 2036, "[?]")
  , ( 2037, "[?]")
  , ( 2038, "[?]")
  , ( 2039, "[?]")
  , ( 2040, "[?]")
  , ( 2041, "[?]")
  , ( 2042, "[?]")
  , ( 2043, "[?]")
  , ( 2044, "[?]")
  , ( 2045, "[?]")
  , ( 2046, "[?]")
  , ( 2304, "[?]")
  , ( 2305, "N")
  , ( 2306, "N")
  , ( 2307, "H")
  , ( 2308, "[?]")
  , ( 2309, "a")
  , ( 2310, "aa")
  , ( 2311, "i")
  , ( 2312, "ii")
  , ( 2313, "u")
  , ( 2314, "uu")
  , ( 2315, "R")
  , ( 2316, "L")
  , ( 2317, "eN")
  , ( 2318, "e")
  , ( 2319, "e")
  , ( 2320, "ai")
  , ( 2321, "oN")
  , ( 2322, "o")
  , ( 2323, "o")
  , ( 2324, "au")
  , ( 2325, "k")
  , ( 2326, "kh")
  , ( 2327, "g")
  , ( 2328, "gh")
  , ( 2329, "ng")
  , ( 2330, "c")
  , ( 2331, "ch")
  , ( 2332, "j")
  , ( 2333, "jh")
  , ( 2334, "ny")
  , ( 2335, "tt")
  , ( 2336, "tth")
  , ( 2337, "dd")
  , ( 2338, "ddh")
  , ( 2339, "nn")
  , ( 2340, "t")
  , ( 2341, "th")
  , ( 2342, "d")
  , ( 2343, "dh")
  , ( 2344, "n")
  , ( 2345, "nnn")
  , ( 2346, "p")
  , ( 2347, "ph")
  , ( 2348, "b")
  , ( 2349, "bh")
  , ( 2350, "m")
  , ( 2351, "y")
  , ( 2352, "r")
  , ( 2353, "rr")
  , ( 2354, "l")
  , ( 2355, "l")
  , ( 2356, "lll")
  , ( 2357, "v")
  , ( 2358, "sh")
  , ( 2359, "ss")
  , ( 2360, "s")
  , ( 2361, "h")
  , ( 2362, "[?]")
  , ( 2363, "[?]")
  , ( 2364, "'")
  , ( 2365, "'")
  , ( 2366, "aa")
  , ( 2367, "i")
  , ( 2368, "ii")
  , ( 2369, "u")
  , ( 2370, "uu")
  , ( 2371, "R")
  , ( 2372, "RR")
  , ( 2373, "eN")
  , ( 2374, "e")
  , ( 2375, "e")
  , ( 2376, "ai")
  , ( 2377, "oN")
  , ( 2378, "o")
  , ( 2379, "o")
  , ( 2380, "au")
  , ( 2382, "[?]")
  , ( 2383, "[?]")
  , ( 2384, "AUM")
  , ( 2385, "'")
  , ( 2386, "'")
  , ( 2387, "`")
  , ( 2388, "'")
  , ( 2389, "[?]")
  , ( 2390, "[?]")
  , ( 2391, "[?]")
  , ( 2392, "q")
  , ( 2393, "khh")
  , ( 2394, "ghh")
  , ( 2395, "z")
  , ( 2396, "dddh")
  , ( 2397, "rh")
  , ( 2398, "f")
  , ( 2399, "yy")
  , ( 2400, "RR")
  , ( 2401, "LL")
  , ( 2402, "L")
  , ( 2403, "LL")
  , ( 2404, " / ")
  , ( 2405, " // ")
  , ( 2406, "0")
  , ( 2407, "1")
  , ( 2408, "2")
  , ( 2409, "3")
  , ( 2410, "4")
  , ( 2411, "5")
  , ( 2412, "6")
  , ( 2413, "7")
  , ( 2414, "8")
  , ( 2415, "9")
  , ( 2416, ".")
  , ( 2417, "[?]")
  , ( 2418, "[?]")
  , ( 2419, "[?]")
  , ( 2420, "[?]")
  , ( 2421, "[?]")
  , ( 2422, "[?]")
  , ( 2423, "[?]")
  , ( 2424, "[?]")
  , ( 2425, "[?]")
  , ( 2426, "[?]")
  , ( 2427, "[?]")
  , ( 2428, "[?]")
  , ( 2429, "[?]")
  , ( 2430, "[?]")
  , ( 2431, "[?]")
  , ( 2432, "[?]")
  , ( 2433, "N")
  , ( 2434, "N")
  , ( 2435, "H")
  , ( 2436, "[?]")
  , ( 2437, "a")
  , ( 2438, "aa")
  , ( 2439, "i")
  , ( 2440, "ii")
  , ( 2441, "u")
  , ( 2442, "uu")
  , ( 2443, "R")
  , ( 2444, "RR")
  , ( 2445, "[?]")
  , ( 2446, "[?]")
  , ( 2447, "e")
  , ( 2448, "ai")
  , ( 2449, "[?]")
  , ( 2450, "[?]")
  , ( 2451, "o")
  , ( 2452, "au")
  , ( 2453, "k")
  , ( 2454, "kh")
  , ( 2455, "g")
  , ( 2456, "gh")
  , ( 2457, "ng")
  , ( 2458, "c")
  , ( 2459, "ch")
  , ( 2460, "j")
  , ( 2461, "jh")
  , ( 2462, "ny")
  , ( 2463, "tt")
  , ( 2464, "tth")
  , ( 2465, "dd")
  , ( 2466, "ddh")
  , ( 2467, "nn")
  , ( 2468, "t")
  , ( 2469, "th")
  , ( 2470, "d")
  , ( 2471, "dh")
  , ( 2472, "n")
  , ( 2473, "[?]")
  , ( 2474, "p")
  , ( 2475, "ph")
  , ( 2476, "b")
  , ( 2477, "bh")
  , ( 2478, "m")
  , ( 2479, "y")
  , ( 2480, "r")
  , ( 2481, "[?]")
  , ( 2482, "l")
  , ( 2483, "[?]")
  , ( 2484, "[?]")
  , ( 2485, "[?]")
  , ( 2486, "sh")
  , ( 2487, "ss")
  , ( 2488, "s")
  , ( 2489, "h")
  , ( 2490, "[?]")
  , ( 2491, "[?]")
  , ( 2492, "'")
  , ( 2493, "[?]")
  , ( 2494, "aa")
  , ( 2495, "i")
  , ( 2496, "ii")
  , ( 2497, "u")
  , ( 2498, "uu")
  , ( 2499, "R")
  , ( 2500, "RR")
  , ( 2501, "[?]")
  , ( 2502, "[?]")
  , ( 2503, "e")
  , ( 2504, "ai")
  , ( 2505, "[?]")
  , ( 2506, "[?]")
  , ( 2507, "o")
  , ( 2508, "au")
  , ( 2510, "[?]")
  , ( 2511, "[?]")
  , ( 2512, "[?]")
  , ( 2513, "[?]")
  , ( 2514, "[?]")
  , ( 2515, "[?]")
  , ( 2516, "[?]")
  , ( 2517, "[?]")
  , ( 2518, "[?]")
  , ( 2519, "+")
  , ( 2520, "[?]")
  , ( 2521, "[?]")
  , ( 2522, "[?]")
  , ( 2523, "[?]")
  , ( 2524, "rr")
  , ( 2525, "rh")
  , ( 2526, "[?]")
  , ( 2527, "yy")
  , ( 2528, "RR")
  , ( 2529, "LL")
  , ( 2530, "L")
  , ( 2531, "LL")
  , ( 2532, "[?]")
  , ( 2533, "[?]")
  , ( 2534, "0")
  , ( 2535, "1")
  , ( 2536, "2")
  , ( 2537, "3")
  , ( 2538, "4")
  , ( 2539, "5")
  , ( 2540, "6")
  , ( 2541, "7")
  , ( 2542, "8")
  , ( 2543, "9")
  , ( 2544, "r'")
  , ( 2545, "r`")
  , ( 2546, "Rs")
  , ( 2547, "Rs")
  , ( 2548, "1/")
  , ( 2549, "2/")
  , ( 2550, "3/")
  , ( 2551, "4/")
  , ( 2552, " 1 - 1/")
  , ( 2553, "/16")
  , ( 2555, "[?]")
  , ( 2556, "[?]")
  , ( 2557, "[?]")
  , ( 2558, "[?]")
  , ( 2560, "[?]")
  , ( 2561, "[?]")
  , ( 2562, "N")
  , ( 2563, "[?]")
  , ( 2564, "[?]")
  , ( 2565, "a")
  , ( 2566, "aa")
  , ( 2567, "i")
  , ( 2568, "ii")
  , ( 2569, "u")
  , ( 2570, "uu")
  , ( 2571, "[?]")
  , ( 2572, "[?]")
  , ( 2573, "[?]")
  , ( 2574, "[?]")
  , ( 2575, "ee")
  , ( 2576, "ai")
  , ( 2577, "[?]")
  , ( 2578, "[?]")
  , ( 2579, "oo")
  , ( 2580, "au")
  , ( 2581, "k")
  , ( 2582, "kh")
  , ( 2583, "g")
  , ( 2584, "gh")
  , ( 2585, "ng")
  , ( 2586, "c")
  , ( 2587, "ch")
  , ( 2588, "j")
  , ( 2589, "jh")
  , ( 2590, "ny")
  , ( 2591, "tt")
  , ( 2592, "tth")
  , ( 2593, "dd")
  , ( 2594, "ddh")
  , ( 2595, "nn")
  , ( 2596, "t")
  , ( 2597, "th")
  , ( 2598, "d")
  , ( 2599, "dh")
  , ( 2600, "n")
  , ( 2601, "[?]")
  , ( 2602, "p")
  , ( 2603, "ph")
  , ( 2604, "b")
  , ( 2605, "bb")
  , ( 2606, "m")
  , ( 2607, "y")
  , ( 2608, "r")
  , ( 2609, "[?]")
  , ( 2610, "l")
  , ( 2611, "ll")
  , ( 2612, "[?]")
  , ( 2613, "v")
  , ( 2614, "sh")
  , ( 2615, "[?]")
  , ( 2616, "s")
  , ( 2617, "h")
  , ( 2618, "[?]")
  , ( 2619, "[?]")
  , ( 2620, "'")
  , ( 2621, "[?]")
  , ( 2622, "aa")
  , ( 2623, "i")
  , ( 2624, "ii")
  , ( 2625, "u")
  , ( 2626, "uu")
  , ( 2627, "[?]")
  , ( 2628, "[?]")
  , ( 2629, "[?]")
  , ( 2630, "[?]")
  , ( 2631, "ee")
  , ( 2632, "ai")
  , ( 2633, "[?]")
  , ( 2634, "[?]")
  , ( 2635, "oo")
  , ( 2636, "au")
  , ( 2638, "[?]")
  , ( 2639, "[?]")
  , ( 2640, "[?]")
  , ( 2641, "[?]")
  , ( 2642, "[?]")
  , ( 2643, "[?]")
  , ( 2644, "[?]")
  , ( 2645, "[?]")
  , ( 2646, "[?]")
  , ( 2647, "[?]")
  , ( 2648, "[?]")
  , ( 2649, "khh")
  , ( 2650, "ghh")
  , ( 2651, "z")
  , ( 2652, "rr")
  , ( 2653, "[?]")
  , ( 2654, "f")
  , ( 2655, "[?]")
  , ( 2656, "[?]")
  , ( 2657, "[?]")
  , ( 2658, "[?]")
  , ( 2659, "[?]")
  , ( 2660, "[?]")
  , ( 2661, "[?]")
  , ( 2662, "0")
  , ( 2663, "1")
  , ( 2664, "2")
  , ( 2665, "3")
  , ( 2666, "4")
  , ( 2667, "5")
  , ( 2668, "6")
  , ( 2669, "7")
  , ( 2670, "8")
  , ( 2671, "9")
  , ( 2672, "N")
  , ( 2673, "H")
  , ( 2676, "G.E.O.")
  , ( 2677, "[?]")
  , ( 2678, "[?]")
  , ( 2679, "[?]")
  , ( 2680, "[?]")
  , ( 2681, "[?]")
  , ( 2682, "[?]")
  , ( 2683, "[?]")
  , ( 2684, "[?]")
  , ( 2685, "[?]")
  , ( 2686, "[?]")
  , ( 2687, "[?]")
  , ( 2688, "[?]")
  , ( 2689, "N")
  , ( 2690, "N")
  , ( 2691, "H")
  , ( 2692, "[?]")
  , ( 2693, "a")
  , ( 2694, "aa")
  , ( 2695, "i")
  , ( 2696, "ii")
  , ( 2697, "u")
  , ( 2698, "uu")
  , ( 2699, "R")
  , ( 2700, "[?]")
  , ( 2701, "eN")
  , ( 2702, "[?]")
  , ( 2703, "e")
  , ( 2704, "ai")
  , ( 2705, "oN")
  , ( 2706, "[?]")
  , ( 2707, "o")
  , ( 2708, "au")
  , ( 2709, "k")
  , ( 2710, "kh")
  , ( 2711, "g")
  , ( 2712, "gh")
  , ( 2713, "ng")
  , ( 2714, "c")
  , ( 2715, "ch")
  , ( 2716, "j")
  , ( 2717, "jh")
  , ( 2718, "ny")
  , ( 2719, "tt")
  , ( 2720, "tth")
  , ( 2721, "dd")
  , ( 2722, "ddh")
  , ( 2723, "nn")
  , ( 2724, "t")
  , ( 2725, "th")
  , ( 2726, "d")
  , ( 2727, "dh")
  , ( 2728, "n")
  , ( 2729, "[?]")
  , ( 2730, "p")
  , ( 2731, "ph")
  , ( 2732, "b")
  , ( 2733, "bh")
  , ( 2734, "m")
  , ( 2735, "ya")
  , ( 2736, "r")
  , ( 2737, "[?]")
  , ( 2738, "l")
  , ( 2739, "ll")
  , ( 2740, "[?]")
  , ( 2741, "v")
  , ( 2742, "sh")
  , ( 2743, "ss")
  , ( 2744, "s")
  , ( 2745, "h")
  , ( 2746, "[?]")
  , ( 2747, "[?]")
  , ( 2748, "'")
  , ( 2749, "'")
  , ( 2750, "aa")
  , ( 2751, "i")
  , ( 2752, "ii")
  , ( 2753, "u")
  , ( 2754, "uu")
  , ( 2755, "R")
  , ( 2756, "RR")
  , ( 2757, "eN")
  , ( 2758, "[?]")
  , ( 2759, "e")
  , ( 2760, "ai")
  , ( 2761, "oN")
  , ( 2762, "[?]")
  , ( 2763, "o")
  , ( 2764, "au")
  , ( 2766, "[?]")
  , ( 2767, "[?]")
  , ( 2768, "AUM")
  , ( 2769, "[?]")
  , ( 2770, "[?]")
  , ( 2771, "[?]")
  , ( 2772, "[?]")
  , ( 2773, "[?]")
  , ( 2774, "[?]")
  , ( 2775, "[?]")
  , ( 2776, "[?]")
  , ( 2777, "[?]")
  , ( 2778, "[?]")
  , ( 2779, "[?]")
  , ( 2780, "[?]")
  , ( 2781, "[?]")
  , ( 2782, "[?]")
  , ( 2783, "[?]")
  , ( 2784, "RR")
  , ( 2785, "[?]")
  , ( 2786, "[?]")
  , ( 2787, "[?]")
  , ( 2788, "[?]")
  , ( 2789, "[?]")
  , ( 2790, "0")
  , ( 2791, "1")
  , ( 2792, "2")
  , ( 2793, "3")
  , ( 2794, "4")
  , ( 2795, "5")
  , ( 2796, "6")
  , ( 2797, "7")
  , ( 2798, "8")
  , ( 2799, "9")
  , ( 2800, "[?]")
  , ( 2801, "[?]")
  , ( 2802, "[?]")
  , ( 2803, "[?]")
  , ( 2804, "[?]")
  , ( 2805, "[?]")
  , ( 2806, "[?]")
  , ( 2807, "[?]")
  , ( 2808, "[?]")
  , ( 2809, "[?]")
  , ( 2810, "[?]")
  , ( 2811, "[?]")
  , ( 2812, "[?]")
  , ( 2813, "[?]")
  , ( 2814, "[?]")
  , ( 2816, "[?]")
  , ( 2817, "N")
  , ( 2818, "N")
  , ( 2819, "H")
  , ( 2820, "[?]")
  , ( 2821, "a")
  , ( 2822, "aa")
  , ( 2823, "i")
  , ( 2824, "ii")
  , ( 2825, "u")
  , ( 2826, "uu")
  , ( 2827, "R")
  , ( 2828, "L")
  , ( 2829, "[?]")
  , ( 2830, "[?]")
  , ( 2831, "e")
  , ( 2832, "ai")
  , ( 2833, "[?]")
  , ( 2834, "[?]")
  , ( 2835, "o")
  , ( 2836, "au")
  , ( 2837, "k")
  , ( 2838, "kh")
  , ( 2839, "g")
  , ( 2840, "gh")
  , ( 2841, "ng")
  , ( 2842, "c")
  , ( 2843, "ch")
  , ( 2844, "j")
  , ( 2845, "jh")
  , ( 2846, "ny")
  , ( 2847, "tt")
  , ( 2848, "tth")
  , ( 2849, "dd")
  , ( 2850, "ddh")
  , ( 2851, "nn")
  , ( 2852, "t")
  , ( 2853, "th")
  , ( 2854, "d")
  , ( 2855, "dh")
  , ( 2856, "n")
  , ( 2857, "[?]")
  , ( 2858, "p")
  , ( 2859, "ph")
  , ( 2860, "b")
  , ( 2861, "bh")
  , ( 2862, "m")
  , ( 2863, "y")
  , ( 2864, "r")
  , ( 2865, "[?]")
  , ( 2866, "l")
  , ( 2867, "ll")
  , ( 2868, "[?]")
  , ( 2870, "sh")
  , ( 2871, "ss")
  , ( 2872, "s")
  , ( 2873, "h")
  , ( 2874, "[?]")
  , ( 2875, "[?]")
  , ( 2876, "'")
  , ( 2877, "'")
  , ( 2878, "aa")
  , ( 2879, "i")
  , ( 2880, "ii")
  , ( 2881, "u")
  , ( 2882, "uu")
  , ( 2883, "R")
  , ( 2884, "[?]")
  , ( 2885, "[?]")
  , ( 2886, "[?]")
  , ( 2887, "e")
  , ( 2888, "ai")
  , ( 2889, "[?]")
  , ( 2890, "[?]")
  , ( 2891, "o")
  , ( 2892, "au")
  , ( 2894, "[?]")
  , ( 2895, "[?]")
  , ( 2896, "[?]")
  , ( 2897, "[?]")
  , ( 2898, "[?]")
  , ( 2899, "[?]")
  , ( 2900, "[?]")
  , ( 2901, "[?]")
  , ( 2902, "+")
  , ( 2903, "+")
  , ( 2904, "[?]")
  , ( 2905, "[?]")
  , ( 2906, "[?]")
  , ( 2907, "[?]")
  , ( 2908, "rr")
  , ( 2909, "rh")
  , ( 2910, "[?]")
  , ( 2911, "yy")
  , ( 2912, "RR")
  , ( 2913, "LL")
  , ( 2914, "[?]")
  , ( 2915, "[?]")
  , ( 2916, "[?]")
  , ( 2917, "[?]")
  , ( 2918, "0")
  , ( 2919, "1")
  , ( 2920, "2")
  , ( 2921, "3")
  , ( 2922, "4")
  , ( 2923, "5")
  , ( 2924, "6")
  , ( 2925, "7")
  , ( 2926, "8")
  , ( 2927, "9")
  , ( 2929, "[?]")
  , ( 2930, "[?]")
  , ( 2931, "[?]")
  , ( 2932, "[?]")
  , ( 2933, "[?]")
  , ( 2934, "[?]")
  , ( 2935, "[?]")
  , ( 2936, "[?]")
  , ( 2937, "[?]")
  , ( 2938, "[?]")
  , ( 2939, "[?]")
  , ( 2940, "[?]")
  , ( 2941, "[?]")
  , ( 2942, "[?]")
  , ( 2943, "[?]")
  , ( 2944, "[?]")
  , ( 2945, "[?]")
  , ( 2946, "N")
  , ( 2947, "H")
  , ( 2948, "[?]")
  , ( 2949, "a")
  , ( 2950, "aa")
  , ( 2951, "i")
  , ( 2952, "ii")
  , ( 2953, "u")
  , ( 2954, "uu")
  , ( 2955, "[?]")
  , ( 2956, "[?]")
  , ( 2957, "[?]")
  , ( 2958, "e")
  , ( 2959, "ee")
  , ( 2960, "ai")
  , ( 2961, "[?]")
  , ( 2962, "o")
  , ( 2963, "oo")
  , ( 2964, "au")
  , ( 2965, "k")
  , ( 2966, "[?]")
  , ( 2967, "[?]")
  , ( 2968, "[?]")
  , ( 2969, "ng")
  , ( 2970, "c")
  , ( 2971, "[?]")
  , ( 2972, "j")
  , ( 2973, "[?]")
  , ( 2974, "ny")
  , ( 2975, "tt")
  , ( 2976, "[?]")
  , ( 2977, "[?]")
  , ( 2978, "[?]")
  , ( 2979, "nn")
  , ( 2980, "t")
  , ( 2981, "[?]")
  , ( 2982, "[?]")
  , ( 2983, "[?]")
  , ( 2984, "n")
  , ( 2985, "nnn")
  , ( 2986, "p")
  , ( 2987, "[?]")
  , ( 2988, "[?]")
  , ( 2989, "[?]")
  , ( 2990, "m")
  , ( 2991, "y")
  , ( 2992, "r")
  , ( 2993, "rr")
  , ( 2994, "l")
  , ( 2995, "ll")
  , ( 2996, "lll")
  , ( 2997, "v")
  , ( 2998, "[?]")
  , ( 2999, "ss")
  , ( 3000, "s")
  , ( 3001, "h")
  , ( 3002, "[?]")
  , ( 3003, "[?]")
  , ( 3004, "[?]")
  , ( 3005, "[?]")
  , ( 3006, "aa")
  , ( 3007, "i")
  , ( 3008, "ii")
  , ( 3009, "u")
  , ( 3010, "uu")
  , ( 3011, "[?]")
  , ( 3012, "[?]")
  , ( 3013, "[?]")
  , ( 3014, "e")
  , ( 3015, "ee")
  , ( 3016, "ai")
  , ( 3017, "[?]")
  , ( 3018, "o")
  , ( 3019, "oo")
  , ( 3020, "au")
  , ( 3022, "[?]")
  , ( 3023, "[?]")
  , ( 3024, "[?]")
  , ( 3025, "[?]")
  , ( 3026, "[?]")
  , ( 3027, "[?]")
  , ( 3028, "[?]")
  , ( 3029, "[?]")
  , ( 3030, "[?]")
  , ( 3031, "+")
  , ( 3032, "[?]")
  , ( 3033, "[?]")
  , ( 3034, "[?]")
  , ( 3035, "[?]")
  , ( 3036, "[?]")
  , ( 3037, "[?]")
  , ( 3038, "[?]")
  , ( 3039, "[?]")
  , ( 3040, "[?]")
  , ( 3041, "[?]")
  , ( 3042, "[?]")
  , ( 3043, "[?]")
  , ( 3044, "[?]")
  , ( 3045, "[?]")
  , ( 3046, "0")
  , ( 3047, "1")
  , ( 3048, "2")
  , ( 3049, "3")
  , ( 3050, "4")
  , ( 3051, "5")
  , ( 3052, "6")
  , ( 3053, "7")
  , ( 3054, "8")
  , ( 3055, "9")
  , ( 3056, "+10+")
  , ( 3057, "+100+")
  , ( 3058, "+1000+")
  , ( 3059, "[?]")
  , ( 3060, "[?]")
  , ( 3061, "[?]")
  , ( 3062, "[?]")
  , ( 3063, "[?]")
  , ( 3064, "[?]")
  , ( 3065, "[?]")
  , ( 3066, "[?]")
  , ( 3067, "[?]")
  , ( 3068, "[?]")
  , ( 3069, "[?]")
  , ( 3070, "[?]")
  , ( 3072, "[?]")
  , ( 3073, "N")
  , ( 3074, "N")
  , ( 3075, "H")
  , ( 3076, "[?]")
  , ( 3077, "a")
  , ( 3078, "aa")
  , ( 3079, "i")
  , ( 3080, "ii")
  , ( 3081, "u")
  , ( 3082, "uu")
  , ( 3083, "R")
  , ( 3084, "L")
  , ( 3085, "[?]")
  , ( 3086, "e")
  , ( 3087, "ee")
  , ( 3088, "ai")
  , ( 3089, "[?]")
  , ( 3090, "o")
  , ( 3091, "oo")
  , ( 3092, "au")
  , ( 3093, "k")
  , ( 3094, "kh")
  , ( 3095, "g")
  , ( 3096, "gh")
  , ( 3097, "ng")
  , ( 3098, "c")
  , ( 3099, "ch")
  , ( 3100, "j")
  , ( 3101, "jh")
  , ( 3102, "ny")
  , ( 3103, "tt")
  , ( 3104, "tth")
  , ( 3105, "dd")
  , ( 3106, "ddh")
  , ( 3107, "nn")
  , ( 3108, "t")
  , ( 3109, "th")
  , ( 3110, "d")
  , ( 3111, "dh")
  , ( 3112, "n")
  , ( 3113, "[?]")
  , ( 3114, "p")
  , ( 3115, "ph")
  , ( 3116, "b")
  , ( 3117, "bh")
  , ( 3118, "m")
  , ( 3119, "y")
  , ( 3120, "r")
  , ( 3121, "rr")
  , ( 3122, "l")
  , ( 3123, "ll")
  , ( 3124, "[?]")
  , ( 3125, "v")
  , ( 3126, "sh")
  , ( 3127, "ss")
  , ( 3128, "s")
  , ( 3129, "h")
  , ( 3130, "[?]")
  , ( 3131, "[?]")
  , ( 3132, "[?]")
  , ( 3133, "[?]")
  , ( 3134, "aa")
  , ( 3135, "i")
  , ( 3136, "ii")
  , ( 3137, "u")
  , ( 3138, "uu")
  , ( 3139, "R")
  , ( 3140, "RR")
  , ( 3141, "[?]")
  , ( 3142, "e")
  , ( 3143, "ee")
  , ( 3144, "ai")
  , ( 3145, "[?]")
  , ( 3146, "o")
  , ( 3147, "oo")
  , ( 3148, "au")
  , ( 3150, "[?]")
  , ( 3151, "[?]")
  , ( 3152, "[?]")
  , ( 3153, "[?]")
  , ( 3154, "[?]")
  , ( 3155, "[?]")
  , ( 3156, "[?]")
  , ( 3157, "+")
  , ( 3158, "+")
  , ( 3159, "[?]")
  , ( 3160, "[?]")
  , ( 3161, "[?]")
  , ( 3162, "[?]")
  , ( 3163, "[?]")
  , ( 3164, "[?]")
  , ( 3165, "[?]")
  , ( 3166, "[?]")
  , ( 3167, "[?]")
  , ( 3168, "RR")
  , ( 3169, "LL")
  , ( 3170, "[?]")
  , ( 3171, "[?]")
  , ( 3172, "[?]")
  , ( 3173, "[?]")
  , ( 3174, "0")
  , ( 3175, "1")
  , ( 3176, "2")
  , ( 3177, "3")
  , ( 3178, "4")
  , ( 3179, "5")
  , ( 3180, "6")
  , ( 3181, "7")
  , ( 3182, "8")
  , ( 3183, "9")
  , ( 3184, "[?]")
  , ( 3185, "[?]")
  , ( 3186, "[?]")
  , ( 3187, "[?]")
  , ( 3188, "[?]")
  , ( 3189, "[?]")
  , ( 3190, "[?]")
  , ( 3191, "[?]")
  , ( 3192, "[?]")
  , ( 3193, "[?]")
  , ( 3194, "[?]")
  , ( 3195, "[?]")
  , ( 3196, "[?]")
  , ( 3197, "[?]")
  , ( 3198, "[?]")
  , ( 3199, "[?]")
  , ( 3200, "[?]")
  , ( 3201, "[?]")
  , ( 3202, "N")
  , ( 3203, "H")
  , ( 3204, "[?]")
  , ( 3205, "a")
  , ( 3206, "aa")
  , ( 3207, "i")
  , ( 3208, "ii")
  , ( 3209, "u")
  , ( 3210, "uu")
  , ( 3211, "R")
  , ( 3212, "L")
  , ( 3213, "[?]")
  , ( 3214, "e")
  , ( 3215, "ee")
  , ( 3216, "ai")
  , ( 3217, "[?]")
  , ( 3218, "o")
  , ( 3219, "oo")
  , ( 3220, "au")
  , ( 3221, "k")
  , ( 3222, "kh")
  , ( 3223, "g")
  , ( 3224, "gh")
  , ( 3225, "ng")
  , ( 3226, "c")
  , ( 3227, "ch")
  , ( 3228, "j")
  , ( 3229, "jh")
  , ( 3230, "ny")
  , ( 3231, "tt")
  , ( 3232, "tth")
  , ( 3233, "dd")
  , ( 3234, "ddh")
  , ( 3235, "nn")
  , ( 3236, "t")
  , ( 3237, "th")
  , ( 3238, "d")
  , ( 3239, "dh")
  , ( 3240, "n")
  , ( 3241, "[?]")
  , ( 3242, "p")
  , ( 3243, "ph")
  , ( 3244, "b")
  , ( 3245, "bh")
  , ( 3246, "m")
  , ( 3247, "y")
  , ( 3248, "r")
  , ( 3249, "rr")
  , ( 3250, "l")
  , ( 3251, "ll")
  , ( 3252, "[?]")
  , ( 3253, "v")
  , ( 3254, "sh")
  , ( 3255, "ss")
  , ( 3256, "s")
  , ( 3257, "h")
  , ( 3258, "[?]")
  , ( 3259, "[?]")
  , ( 3260, "[?]")
  , ( 3261, "[?]")
  , ( 3262, "aa")
  , ( 3263, "i")
  , ( 3264, "ii")
  , ( 3265, "u")
  , ( 3266, "uu")
  , ( 3267, "R")
  , ( 3268, "RR")
  , ( 3269, "[?]")
  , ( 3270, "e")
  , ( 3271, "ee")
  , ( 3272, "ai")
  , ( 3273, "[?]")
  , ( 3274, "o")
  , ( 3275, "oo")
  , ( 3276, "au")
  , ( 3278, "[?]")
  , ( 3279, "[?]")
  , ( 3280, "[?]")
  , ( 3281, "[?]")
  , ( 3282, "[?]")
  , ( 3283, "[?]")
  , ( 3284, "[?]")
  , ( 3285, "+")
  , ( 3286, "+")
  , ( 3287, "[?]")
  , ( 3288, "[?]")
  , ( 3289, "[?]")
  , ( 3290, "[?]")
  , ( 3291, "[?]")
  , ( 3292, "[?]")
  , ( 3293, "[?]")
  , ( 3294, "lll")
  , ( 3295, "[?]")
  , ( 3296, "RR")
  , ( 3297, "LL")
  , ( 3298, "[?]")
  , ( 3299, "[?]")
  , ( 3300, "[?]")
  , ( 3301, "[?]")
  , ( 3302, "0")
  , ( 3303, "1")
  , ( 3304, "2")
  , ( 3305, "3")
  , ( 3306, "4")
  , ( 3307, "5")
  , ( 3308, "6")
  , ( 3309, "7")
  , ( 3310, "8")
  , ( 3311, "9")
  , ( 3312, "[?]")
  , ( 3313, "[?]")
  , ( 3314, "[?]")
  , ( 3315, "[?]")
  , ( 3316, "[?]")
  , ( 3317, "[?]")
  , ( 3318, "[?]")
  , ( 3319, "[?]")
  , ( 3320, "[?]")
  , ( 3321, "[?]")
  , ( 3322, "[?]")
  , ( 3323, "[?]")
  , ( 3324, "[?]")
  , ( 3325, "[?]")
  , ( 3326, "[?]")
  , ( 3328, "[?]")
  , ( 3329, "[?]")
  , ( 3330, "N")
  , ( 3331, "H")
  , ( 3332, "[?]")
  , ( 3333, "a")
  , ( 3334, "aa")
  , ( 3335, "i")
  , ( 3336, "ii")
  , ( 3337, "u")
  , ( 3338, "uu")
  , ( 3339, "R")
  , ( 3340, "L")
  , ( 3341, "[?]")
  , ( 3342, "e")
  , ( 3343, "ee")
  , ( 3344, "ai")
  , ( 3345, "[?]")
  , ( 3346, "o")
  , ( 3347, "oo")
  , ( 3348, "au")
  , ( 3349, "k")
  , ( 3350, "kh")
  , ( 3351, "g")
  , ( 3352, "gh")
  , ( 3353, "ng")
  , ( 3354, "c")
  , ( 3355, "ch")
  , ( 3356, "j")
  , ( 3357, "jh")
  , ( 3358, "ny")
  , ( 3359, "tt")
  , ( 3360, "tth")
  , ( 3361, "dd")
  , ( 3362, "ddh")
  , ( 3363, "nn")
  , ( 3364, "t")
  , ( 3365, "th")
  , ( 3366, "d")
  , ( 3367, "dh")
  , ( 3368, "n")
  , ( 3369, "[?]")
  , ( 3370, "p")
  , ( 3371, "ph")
  , ( 3372, "b")
  , ( 3373, "bh")
  , ( 3374, "m")
  , ( 3375, "y")
  , ( 3376, "r")
  , ( 3377, "rr")
  , ( 3378, "l")
  , ( 3379, "ll")
  , ( 3380, "lll")
  , ( 3381, "v")
  , ( 3382, "sh")
  , ( 3383, "ss")
  , ( 3384, "s")
  , ( 3385, "h")
  , ( 3386, "[?]")
  , ( 3387, "[?]")
  , ( 3388, "[?]")
  , ( 3389, "[?]")
  , ( 3390, "aa")
  , ( 3391, "i")
  , ( 3392, "ii")
  , ( 3393, "u")
  , ( 3394, "uu")
  , ( 3395, "R")
  , ( 3396, "[?]")
  , ( 3397, "[?]")
  , ( 3398, "e")
  , ( 3399, "ee")
  , ( 3400, "ai")
  , ( 3402, "o")
  , ( 3403, "oo")
  , ( 3404, "au")
  , ( 3406, "[?]")
  , ( 3407, "[?]")
  , ( 3408, "[?]")
  , ( 3409, "[?]")
  , ( 3410, "[?]")
  , ( 3411, "[?]")
  , ( 3412, "[?]")
  , ( 3413, "[?]")
  , ( 3414, "[?]")
  , ( 3415, "+")
  , ( 3416, "[?]")
  , ( 3417, "[?]")
  , ( 3418, "[?]")
  , ( 3419, "[?]")
  , ( 3420, "[?]")
  , ( 3421, "[?]")
  , ( 3422, "[?]")
  , ( 3423, "[?]")
  , ( 3424, "RR")
  , ( 3425, "LL")
  , ( 3426, "[?]")
  , ( 3427, "[?]")
  , ( 3428, "[?]")
  , ( 3429, "[?]")
  , ( 3430, "0")
  , ( 3431, "1")
  , ( 3432, "2")
  , ( 3433, "3")
  , ( 3434, "4")
  , ( 3435, "5")
  , ( 3436, "6")
  , ( 3437, "7")
  , ( 3438, "8")
  , ( 3439, "9")
  , ( 3440, "[?]")
  , ( 3441, "[?]")
  , ( 3442, "[?]")
  , ( 3443, "[?]")
  , ( 3444, "[?]")
  , ( 3445, "[?]")
  , ( 3446, "[?]")
  , ( 3447, "[?]")
  , ( 3448, "[?]")
  , ( 3449, "[?]")
  , ( 3450, "[?]")
  , ( 3451, "[?]")
  , ( 3452, "[?]")
  , ( 3453, "[?]")
  , ( 3454, "[?]")
  , ( 3455, "[?]")
  , ( 3456, "[?]")
  , ( 3457, "[?]")
  , ( 3458, "N")
  , ( 3459, "H")
  , ( 3460, "[?]")
  , ( 3461, "a")
  , ( 3462, "aa")
  , ( 3463, "ae")
  , ( 3464, "aae")
  , ( 3465, "i")
  , ( 3466, "ii")
  , ( 3467, "u")
  , ( 3468, "uu")
  , ( 3469, "R")
  , ( 3470, "RR")
  , ( 3471, "L")
  , ( 3472, "LL")
  , ( 3473, "e")
  , ( 3474, "ee")
  , ( 3475, "ai")
  , ( 3476, "o")
  , ( 3477, "oo")
  , ( 3478, "au")
  , ( 3479, "[?]")
  , ( 3480, "[?]")
  , ( 3481, "[?]")
  , ( 3482, "k")
  , ( 3483, "kh")
  , ( 3484, "g")
  , ( 3485, "gh")
  , ( 3486, "ng")
  , ( 3487, "nng")
  , ( 3488, "c")
  , ( 3489, "ch")
  , ( 3490, "j")
  , ( 3491, "jh")
  , ( 3492, "ny")
  , ( 3493, "jny")
  , ( 3494, "nyj")
  , ( 3495, "tt")
  , ( 3496, "tth")
  , ( 3497, "dd")
  , ( 3498, "ddh")
  , ( 3499, "nn")
  , ( 3500, "nndd")
  , ( 3501, "t")
  , ( 3502, "th")
  , ( 3503, "d")
  , ( 3504, "dh")
  , ( 3505, "n")
  , ( 3506, "[?]")
  , ( 3507, "nd")
  , ( 3508, "p")
  , ( 3509, "ph")
  , ( 3510, "b")
  , ( 3511, "bh")
  , ( 3512, "m")
  , ( 3513, "mb")
  , ( 3514, "y")
  , ( 3515, "r")
  , ( 3516, "[?]")
  , ( 3517, "l")
  , ( 3518, "[?]")
  , ( 3519, "[?]")
  , ( 3520, "v")
  , ( 3521, "sh")
  , ( 3522, "ss")
  , ( 3523, "s")
  , ( 3524, "h")
  , ( 3525, "ll")
  , ( 3526, "f")
  , ( 3527, "[?]")
  , ( 3528, "[?]")
  , ( 3529, "[?]")
  , ( 3531, "[?]")
  , ( 3532, "[?]")
  , ( 3533, "[?]")
  , ( 3534, "[?]")
  , ( 3535, "aa")
  , ( 3536, "ae")
  , ( 3537, "aae")
  , ( 3538, "i")
  , ( 3539, "ii")
  , ( 3540, "u")
  , ( 3541, "[?]")
  , ( 3542, "uu")
  , ( 3543, "[?]")
  , ( 3544, "R")
  , ( 3545, "e")
  , ( 3546, "ee")
  , ( 3547, "ai")
  , ( 3548, "o")
  , ( 3549, "oo")
  , ( 3550, "au")
  , ( 3551, "L")
  , ( 3552, "[?]")
  , ( 3553, "[?]")
  , ( 3554, "[?]")
  , ( 3555, "[?]")
  , ( 3556, "[?]")
  , ( 3557, "[?]")
  , ( 3558, "[?]")
  , ( 3559, "[?]")
  , ( 3560, "[?]")
  , ( 3561, "[?]")
  , ( 3562, "[?]")
  , ( 3563, "[?]")
  , ( 3564, "[?]")
  , ( 3565, "[?]")
  , ( 3566, "[?]")
  , ( 3567, "[?]")
  , ( 3568, "[?]")
  , ( 3569, "[?]")
  , ( 3570, "RR")
  , ( 3571, "LL")
  , ( 3572, " . ")
  , ( 3573, "[?]")
  , ( 3574, "[?]")
  , ( 3575, "[?]")
  , ( 3576, "[?]")
  , ( 3577, "[?]")
  , ( 3578, "[?]")
  , ( 3579, "[?]")
  , ( 3580, "[?]")
  , ( 3581, "[?]")
  , ( 3582, "[?]")
  , ( 3584, "[?]")
  , ( 3585, "k")
  , ( 3586, "kh")
  , ( 3587, "kh")
  , ( 3588, "kh")
  , ( 3589, "kh")
  , ( 3590, "kh")
  , ( 3591, "ng")
  , ( 3592, "cch")
  , ( 3593, "ch")
  , ( 3594, "ch")
  , ( 3595, "ch")
  , ( 3596, "ch")
  , ( 3597, "y")
  , ( 3598, "d")
  , ( 3599, "t")
  , ( 3600, "th")
  , ( 3601, "th")
  , ( 3602, "th")
  , ( 3603, "n")
  , ( 3604, "d")
  , ( 3605, "t")
  , ( 3606, "th")
  , ( 3607, "th")
  , ( 3608, "th")
  , ( 3609, "n")
  , ( 3610, "b")
  , ( 3611, "p")
  , ( 3612, "ph")
  , ( 3613, "f")
  , ( 3614, "ph")
  , ( 3615, "f")
  , ( 3616, "ph")
  , ( 3617, "m")
  , ( 3618, "y")
  , ( 3619, "r")
  , ( 3620, "R")
  , ( 3621, "l")
  , ( 3622, "L")
  , ( 3623, "w")
  , ( 3624, "s")
  , ( 3625, "s")
  , ( 3626, "s")
  , ( 3627, "h")
  , ( 3628, "l")
  , ( 3629, "`")
  , ( 3630, "h")
  , ( 3631, "~")
  , ( 3632, "a")
  , ( 3633, "a")
  , ( 3634, "aa")
  , ( 3635, "am")
  , ( 3636, "i")
  , ( 3637, "ii")
  , ( 3638, "ue")
  , ( 3639, "uue")
  , ( 3640, "u")
  , ( 3641, "uu")
  , ( 3642, "'")
  , ( 3643, "[?]")
  , ( 3644, "[?]")
  , ( 3645, "[?]")
  , ( 3646, "[?]")
  , ( 3647, "Bh.")
  , ( 3648, "e")
  , ( 3649, "ae")
  , ( 3650, "o")
  , ( 3651, "ai")
  , ( 3652, "ai")
  , ( 3653, "ao")
  , ( 3654, "+")
  , ( 3661, "M")
  , ( 3663, " * ")
  , ( 3664, "0")
  , ( 3665, "1")
  , ( 3666, "2")
  , ( 3667, "3")
  , ( 3668, "4")
  , ( 3669, "5")
  , ( 3670, "6")
  , ( 3671, "7")
  , ( 3672, "8")
  , ( 3673, "9")
  , ( 3674, " // ")
  , ( 3675, " /// ")
  , ( 3676, "[?]")
  , ( 3677, "[?]")
  , ( 3678, "[?]")
  , ( 3679, "[?]")
  , ( 3680, "[?]")
  , ( 3681, "[?]")
  , ( 3682, "[?]")
  , ( 3683, "[?]")
  , ( 3684, "[?]")
  , ( 3685, "[?]")
  , ( 3686, "[?]")
  , ( 3687, "[?]")
  , ( 3688, "[?]")
  , ( 3689, "[?]")
  , ( 3690, "[?]")
  , ( 3691, "[?]")
  , ( 3692, "[?]")
  , ( 3693, "[?]")
  , ( 3694, "[?]")
  , ( 3695, "[?]")
  , ( 3696, "[?]")
  , ( 3697, "[?]")
  , ( 3698, "[?]")
  , ( 3699, "[?]")
  , ( 3700, "[?]")
  , ( 3701, "[?]")
  , ( 3702, "[?]")
  , ( 3703, "[?]")
  , ( 3704, "[?]")
  , ( 3705, "[?]")
  , ( 3706, "[?]")
  , ( 3707, "[?]")
  , ( 3708, "[?]")
  , ( 3709, "[?]")
  , ( 3710, "[?]")
  , ( 3711, "[?]")
  , ( 3712, "[?]")
  , ( 3713, "k")
  , ( 3714, "kh")
  , ( 3715, "[?]")
  , ( 3716, "kh")
  , ( 3717, "[?]")
  , ( 3718, "[?]")
  , ( 3719, "ng")
  , ( 3720, "ch")
  , ( 3721, "[?]")
  , ( 3722, "s")
  , ( 3723, "[?]")
  , ( 3724, "[?]")
  , ( 3725, "ny")
  , ( 3726, "[?]")
  , ( 3727, "[?]")
  , ( 3728, "[?]")
  , ( 3729, "[?]")
  , ( 3730, "[?]")
  , ( 3731, "[?]")
  , ( 3732, "d")
  , ( 3733, "h")
  , ( 3734, "th")
  , ( 3735, "th")
  , ( 3736, "[?]")
  , ( 3737, "n")
  , ( 3738, "b")
  , ( 3739, "p")
  , ( 3740, "ph")
  , ( 3741, "f")
  , ( 3742, "ph")
  , ( 3743, "f")
  , ( 3744, "[?]")
  , ( 3745, "m")
  , ( 3746, "y")
  , ( 3747, "r")
  , ( 3748, "[?]")
  , ( 3749, "l")
  , ( 3750, "[?]")
  , ( 3751, "w")
  , ( 3752, "[?]")
  , ( 3753, "[?]")
  , ( 3754, "s")
  , ( 3755, "h")
  , ( 3756, "[?]")
  , ( 3757, "`")
  , ( 3759, "~")
  , ( 3760, "a")
  , ( 3762, "aa")
  , ( 3763, "am")
  , ( 3764, "i")
  , ( 3765, "ii")
  , ( 3766, "y")
  , ( 3767, "yy")
  , ( 3768, "u")
  , ( 3769, "uu")
  , ( 3770, "[?]")
  , ( 3771, "o")
  , ( 3772, "l")
  , ( 3773, "ny")
  , ( 3774, "[?]")
  , ( 3775, "[?]")
  , ( 3776, "e")
  , ( 3777, "ei")
  , ( 3778, "o")
  , ( 3779, "ay")
  , ( 3780, "ai")
  , ( 3781, "[?]")
  , ( 3782, "+")
  , ( 3783, "[?]")
  , ( 3789, "M")
  , ( 3790, "[?]")
  , ( 3791, "[?]")
  , ( 3792, "0")
  , ( 3793, "1")
  , ( 3794, "2")
  , ( 3795, "3")
  , ( 3796, "4")
  , ( 3797, "5")
  , ( 3798, "6")
  , ( 3799, "7")
  , ( 3800, "8")
  , ( 3801, "9")
  , ( 3802, "[?]")
  , ( 3803, "[?]")
  , ( 3804, "hn")
  , ( 3805, "hm")
  , ( 3806, "[?]")
  , ( 3807, "[?]")
  , ( 3808, "[?]")
  , ( 3809, "[?]")
  , ( 3810, "[?]")
  , ( 3811, "[?]")
  , ( 3812, "[?]")
  , ( 3813, "[?]")
  , ( 3814, "[?]")
  , ( 3815, "[?]")
  , ( 3816, "[?]")
  , ( 3817, "[?]")
  , ( 3818, "[?]")
  , ( 3819, "[?]")
  , ( 3820, "[?]")
  , ( 3821, "[?]")
  , ( 3822, "[?]")
  , ( 3823, "[?]")
  , ( 3824, "[?]")
  , ( 3825, "[?]")
  , ( 3826, "[?]")
  , ( 3827, "[?]")
  , ( 3828, "[?]")
  , ( 3829, "[?]")
  , ( 3830, "[?]")
  , ( 3831, "[?]")
  , ( 3832, "[?]")
  , ( 3833, "[?]")
  , ( 3834, "[?]")
  , ( 3835, "[?]")
  , ( 3836, "[?]")
  , ( 3837, "[?]")
  , ( 3838, "[?]")
  , ( 3840, "AUM")
  , ( 3848, " // ")
  , ( 3849, " * ")
  , ( 3851, "-")
  , ( 3852, " / ")
  , ( 3853, " / ")
  , ( 3854, " // ")
  , ( 3855, " -/ ")
  , ( 3856, " +/ ")
  , ( 3857, " X/ ")
  , ( 3858, " /XX/ ")
  , ( 3859, " /X/ ")
  , ( 3860, ", ")
  , ( 3872, "0")
  , ( 3873, "1")
  , ( 3874, "2")
  , ( 3875, "3")
  , ( 3876, "4")
  , ( 3877, "5")
  , ( 3878, "6")
  , ( 3879, "7")
  , ( 3880, "8")
  , ( 3881, "9")
  , ( 3882, ".5")
  , ( 3883, "1.5")
  , ( 3884, "2.5")
  , ( 3885, "3.5")
  , ( 3886, "4.5")
  , ( 3887, "5.5")
  , ( 3888, "6.5")
  , ( 3889, "7.5")
  , ( 3890, "8.5")
  , ( 3891, "-.5")
  , ( 3892, "+")
  , ( 3893, "*")
  , ( 3894, "^")
  , ( 3895, "_")
  , ( 3897, "~")
  , ( 3898, "[?]")
  , ( 3899, "]")
  , ( 3900, "[[")
  , ( 3901, "]]")
  , ( 3904, "k")
  , ( 3905, "kh")
  , ( 3906, "g")
  , ( 3907, "gh")
  , ( 3908, "ng")
  , ( 3909, "c")
  , ( 3910, "ch")
  , ( 3911, "j")
  , ( 3912, "[?]")
  , ( 3913, "ny")
  , ( 3914, "tt")
  , ( 3915, "tth")
  , ( 3916, "dd")
  , ( 3917, "ddh")
  , ( 3918, "nn")
  , ( 3919, "t")
  , ( 3920, "th")
  , ( 3921, "d")
  , ( 3922, "dh")
  , ( 3923, "n")
  , ( 3924, "p")
  , ( 3925, "ph")
  , ( 3926, "b")
  , ( 3927, "bh")
  , ( 3928, "m")
  , ( 3929, "ts")
  , ( 3930, "tsh")
  , ( 3931, "dz")
  , ( 3932, "dzh")
  , ( 3933, "w")
  , ( 3934, "zh")
  , ( 3935, "z")
  , ( 3936, "'")
  , ( 3937, "y")
  , ( 3938, "r")
  , ( 3939, "l")
  , ( 3940, "sh")
  , ( 3941, "ssh")
  , ( 3942, "s")
  , ( 3943, "h")
  , ( 3944, "a")
  , ( 3945, "kss")
  , ( 3946, "r")
  , ( 3947, "[?]")
  , ( 3948, "[?]")
  , ( 3949, "[?]")
  , ( 3950, "[?]")
  , ( 3951, "[?]")
  , ( 3952, "[?]")
  , ( 3953, "aa")
  , ( 3954, "i")
  , ( 3955, "ii")
  , ( 3956, "u")
  , ( 3957, "uu")
  , ( 3958, "R")
  , ( 3959, "RR")
  , ( 3960, "L")
  , ( 3961, "LL")
  , ( 3962, "e")
  , ( 3963, "ee")
  , ( 3964, "o")
  , ( 3965, "oo")
  , ( 3966, "M")
  , ( 3967, "H")
  , ( 3968, "i")
  , ( 3969, "ii")
  , ( 3980, "[?]")
  , ( 3981, "[?]")
  , ( 3982, "[?]")
  , ( 3983, "[?]")
  , ( 3984, "k")
  , ( 3985, "kh")
  , ( 3986, "g")
  , ( 3987, "gh")
  , ( 3988, "ng")
  , ( 3989, "c")
  , ( 3990, "ch")
  , ( 3991, "j")
  , ( 3992, "[?]")
  , ( 3993, "ny")
  , ( 3994, "tt")
  , ( 3995, "tth")
  , ( 3996, "dd")
  , ( 3997, "ddh")
  , ( 3998, "nn")
  , ( 3999, "t")
  , ( 4000, "th")
  , ( 4001, "d")
  , ( 4002, "dh")
  , ( 4003, "n")
  , ( 4004, "p")
  , ( 4005, "ph")
  , ( 4006, "b")
  , ( 4007, "bh")
  , ( 4008, "m")
  , ( 4009, "ts")
  , ( 4010, "tsh")
  , ( 4011, "dz")
  , ( 4012, "dzh")
  , ( 4013, "w")
  , ( 4014, "zh")
  , ( 4015, "z")
  , ( 4016, "'")
  , ( 4017, "y")
  , ( 4018, "r")
  , ( 4019, "l")
  , ( 4020, "sh")
  , ( 4021, "ss")
  , ( 4022, "s")
  , ( 4023, "h")
  , ( 4024, "a")
  , ( 4025, "kss")
  , ( 4026, "w")
  , ( 4027, "y")
  , ( 4028, "r")
  , ( 4029, "[?]")
  , ( 4030, "X")
  , ( 4031, " :X: ")
  , ( 4032, " /O/ ")
  , ( 4033, " /o/ ")
  , ( 4034, " \\o\\ ")
  , ( 4035, " (O) ")
  , ( 4045, "[?]")
  , ( 4046, "[?]")
  , ( 4048, "[?]")
  , ( 4049, "[?]")
  , ( 4050, "[?]")
  , ( 4051, "[?]")
  , ( 4052, "[?]")
  , ( 4053, "[?]")
  , ( 4054, "[?]")
  , ( 4055, "[?]")
  , ( 4056, "[?]")
  , ( 4057, "[?]")
  , ( 4058, "[?]")
  , ( 4059, "[?]")
  , ( 4060, "[?]")
  , ( 4061, "[?]")
  , ( 4062, "[?]")
  , ( 4063, "[?]")
  , ( 4064, "[?]")
  , ( 4065, "[?]")
  , ( 4066, "[?]")
  , ( 4067, "[?]")
  , ( 4068, "[?]")
  , ( 4069, "[?]")
  , ( 4070, "[?]")
  , ( 4071, "[?]")
  , ( 4072, "[?]")
  , ( 4073, "[?]")
  , ( 4074, "[?]")
  , ( 4075, "[?]")
  , ( 4076, "[?]")
  , ( 4077, "[?]")
  , ( 4078, "[?]")
  , ( 4079, "[?]")
  , ( 4080, "[?]")
  , ( 4081, "[?]")
  , ( 4082, "[?]")
  , ( 4083, "[?]")
  , ( 4084, "[?]")
  , ( 4085, "[?]")
  , ( 4086, "[?]")
  , ( 4087, "[?]")
  , ( 4088, "[?]")
  , ( 4089, "[?]")
  , ( 4090, "[?]")
  , ( 4091, "[?]")
  , ( 4092, "[?]")
  , ( 4093, "[?]")
  , ( 4094, "[?]")
  , ( 4096, "k")
  , ( 4097, "kh")
  , ( 4098, "g")
  , ( 4099, "gh")
  , ( 4100, "ng")
  , ( 4101, "c")
  , ( 4102, "ch")
  , ( 4103, "j")
  , ( 4104, "jh")
  , ( 4105, "ny")
  , ( 4106, "nny")
  , ( 4107, "tt")
  , ( 4108, "tth")
  , ( 4109, "dd")
  , ( 4110, "ddh")
  , ( 4111, "nn")
  , ( 4112, "tt")
  , ( 4113, "th")
  , ( 4114, "d")
  , ( 4115, "dh")
  , ( 4116, "n")
  , ( 4117, "p")
  , ( 4118, "ph")
  , ( 4119, "b")
  , ( 4120, "bh")
  , ( 4121, "m")
  , ( 4122, "y")
  , ( 4123, "r")
  , ( 4124, "l")
  , ( 4125, "w")
  , ( 4126, "s")
  , ( 4127, "h")
  , ( 4128, "ll")
  , ( 4129, "a")
  , ( 4130, "[?]")
  , ( 4131, "i")
  , ( 4132, "ii")
  , ( 4133, "u")
  , ( 4134, "uu")
  , ( 4135, "e")
  , ( 4136, "[?]")
  , ( 4137, "o")
  , ( 4138, "au")
  , ( 4139, "[?]")
  , ( 4140, "aa")
  , ( 4141, "i")
  , ( 4142, "ii")
  , ( 4143, "u")
  , ( 4144, "uu")
  , ( 4145, "e")
  , ( 4146, "ai")
  , ( 4147, "[?]")
  , ( 4148, "[?]")
  , ( 4149, "[?]")
  , ( 4150, "N")
  , ( 4151, "'")
  , ( 4152, ":")
  , ( 4154, "[?]")
  , ( 4155, "[?]")
  , ( 4156, "[?]")
  , ( 4157, "[?]")
  , ( 4158, "[?]")
  , ( 4159, "[?]")
  , ( 4160, "0")
  , ( 4161, "1")
  , ( 4162, "2")
  , ( 4163, "3")
  , ( 4164, "4")
  , ( 4165, "5")
  , ( 4166, "6")
  , ( 4167, "7")
  , ( 4168, "8")
  , ( 4169, "9")
  , ( 4170, " / ")
  , ( 4171, " // ")
  , ( 4172, "n*")
  , ( 4173, "r*")
  , ( 4174, "l*")
  , ( 4175, "e*")
  , ( 4176, "sh")
  , ( 4177, "ss")
  , ( 4178, "R")
  , ( 4179, "RR")
  , ( 4180, "L")
  , ( 4181, "LL")
  , ( 4182, "R")
  , ( 4183, "RR")
  , ( 4184, "L")
  , ( 4185, "LL")
  , ( 4186, "[?]")
  , ( 4187, "[?]")
  , ( 4188, "[?]")
  , ( 4189, "[?]")
  , ( 4190, "[?]")
  , ( 4191, "[?]")
  , ( 4192, "[?]")
  , ( 4193, "[?]")
  , ( 4194, "[?]")
  , ( 4195, "[?]")
  , ( 4196, "[?]")
  , ( 4197, "[?]")
  , ( 4198, "[?]")
  , ( 4199, "[?]")
  , ( 4200, "[?]")
  , ( 4201, "[?]")
  , ( 4202, "[?]")
  , ( 4203, "[?]")
  , ( 4204, "[?]")
  , ( 4205, "[?]")
  , ( 4206, "[?]")
  , ( 4207, "[?]")
  , ( 4208, "[?]")
  , ( 4209, "[?]")
  , ( 4210, "[?]")
  , ( 4211, "[?]")
  , ( 4212, "[?]")
  , ( 4213, "[?]")
  , ( 4214, "[?]")
  , ( 4215, "[?]")
  , ( 4216, "[?]")
  , ( 4217, "[?]")
  , ( 4218, "[?]")
  , ( 4219, "[?]")
  , ( 4220, "[?]")
  , ( 4221, "[?]")
  , ( 4222, "[?]")
  , ( 4223, "[?]")
  , ( 4224, "[?]")
  , ( 4225, "[?]")
  , ( 4226, "[?]")
  , ( 4227, "[?]")
  , ( 4228, "[?]")
  , ( 4229, "[?]")
  , ( 4230, "[?]")
  , ( 4231, "[?]")
  , ( 4232, "[?]")
  , ( 4233, "[?]")
  , ( 4234, "[?]")
  , ( 4235, "[?]")
  , ( 4236, "[?]")
  , ( 4237, "[?]")
  , ( 4238, "[?]")
  , ( 4239, "[?]")
  , ( 4240, "[?]")
  , ( 4241, "[?]")
  , ( 4242, "[?]")
  , ( 4243, "[?]")
  , ( 4244, "[?]")
  , ( 4245, "[?]")
  , ( 4246, "[?]")
  , ( 4247, "[?]")
  , ( 4248, "[?]")
  , ( 4249, "[?]")
  , ( 4250, "[?]")
  , ( 4251, "[?]")
  , ( 4252, "[?]")
  , ( 4253, "[?]")
  , ( 4254, "[?]")
  , ( 4255, "[?]")
  , ( 4256, "A")
  , ( 4257, "B")
  , ( 4258, "G")
  , ( 4259, "D")
  , ( 4260, "E")
  , ( 4261, "V")
  , ( 4262, "Z")
  , ( 4263, "T`")
  , ( 4264, "I")
  , ( 4265, "K")
  , ( 4266, "L")
  , ( 4267, "M")
  , ( 4268, "N")
  , ( 4269, "O")
  , ( 4270, "P")
  , ( 4271, "Zh")
  , ( 4272, "R")
  , ( 4273, "S")
  , ( 4274, "T")
  , ( 4275, "U")
  , ( 4276, "P`")
  , ( 4277, "K`")
  , ( 4278, "G'")
  , ( 4279, "Q")
  , ( 4280, "Sh")
  , ( 4281, "Ch`")
  , ( 4282, "C`")
  , ( 4283, "Z'")
  , ( 4284, "C")
  , ( 4285, "Ch")
  , ( 4286, "X")
  , ( 4287, "J")
  , ( 4288, "H")
  , ( 4289, "E")
  , ( 4290, "Y")
  , ( 4291, "W")
  , ( 4292, "Xh")
  , ( 4293, "OE")
  , ( 4294, "[?]")
  , ( 4295, "[?]")
  , ( 4296, "[?]")
  , ( 4297, "[?]")
  , ( 4298, "[?]")
  , ( 4299, "[?]")
  , ( 4300, "[?]")
  , ( 4301, "[?]")
  , ( 4302, "[?]")
  , ( 4303, "[?]")
  , ( 4304, "a")
  , ( 4305, "b")
  , ( 4306, "g")
  , ( 4307, "d")
  , ( 4308, "e")
  , ( 4309, "v")
  , ( 4310, "z")
  , ( 4311, "t`")
  , ( 4312, "i")
  , ( 4313, "k")
  , ( 4314, "l")
  , ( 4315, "m")
  , ( 4316, "n")
  , ( 4317, "o")
  , ( 4318, "p")
  , ( 4319, "zh")
  , ( 4320, "r")
  , ( 4321, "s")
  , ( 4322, "t")
  , ( 4323, "u")
  , ( 4324, "p`")
  , ( 4325, "k`")
  , ( 4326, "g'")
  , ( 4327, "q")
  , ( 4328, "sh")
  , ( 4329, "ch`")
  , ( 4330, "c`")
  , ( 4331, "z'")
  , ( 4332, "c")
  , ( 4333, "ch")
  , ( 4334, "x")
  , ( 4335, "j")
  , ( 4336, "h")
  , ( 4337, "e")
  , ( 4338, "y")
  , ( 4339, "w")
  , ( 4340, "xh")
  , ( 4341, "oe")
  , ( 4342, "f")
  , ( 4343, "[?]")
  , ( 4344, "[?]")
  , ( 4345, "[?]")
  , ( 4346, "[?]")
  , ( 4347, " // ")
  , ( 4348, "[?]")
  , ( 4349, "[?]")
  , ( 4350, "[?]")
  , ( 4352, "g")
  , ( 4353, "gg")
  , ( 4354, "n")
  , ( 4355, "d")
  , ( 4356, "dd")
  , ( 4357, "r")
  , ( 4358, "m")
  , ( 4359, "b")
  , ( 4360, "bb")
  , ( 4361, "s")
  , ( 4362, "ss")
  , ( 4364, "j")
  , ( 4365, "jj")
  , ( 4366, "c")
  , ( 4367, "k")
  , ( 4368, "t")
  , ( 4369, "p")
  , ( 4370, "h")
  , ( 4371, "ng")
  , ( 4372, "nn")
  , ( 4373, "nd")
  , ( 4374, "nb")
  , ( 4375, "dg")
  , ( 4376, "rn")
  , ( 4377, "rr")
  , ( 4378, "rh")
  , ( 4379, "rN")
  , ( 4380, "mb")
  , ( 4381, "mN")
  , ( 4382, "bg")
  , ( 4383, "bn")
  , ( 4385, "bs")
  , ( 4386, "bsg")
  , ( 4387, "bst")
  , ( 4388, "bsb")
  , ( 4389, "bss")
  , ( 4390, "bsj")
  , ( 4391, "bj")
  , ( 4392, "bc")
  , ( 4393, "bt")
  , ( 4394, "bp")
  , ( 4395, "bN")
  , ( 4396, "bbN")
  , ( 4397, "sg")
  , ( 4398, "sn")
  , ( 4399, "sd")
  , ( 4400, "sr")
  , ( 4401, "sm")
  , ( 4402, "sb")
  , ( 4403, "sbg")
  , ( 4404, "sss")
  , ( 4405, "s")
  , ( 4406, "sj")
  , ( 4407, "sc")
  , ( 4408, "sk")
  , ( 4409, "st")
  , ( 4410, "sp")
  , ( 4411, "sh")
  , ( 4416, "Z")
  , ( 4417, "g")
  , ( 4418, "d")
  , ( 4419, "m")
  , ( 4420, "b")
  , ( 4421, "s")
  , ( 4422, "Z")
  , ( 4424, "j")
  , ( 4425, "c")
  , ( 4426, "t")
  , ( 4427, "p")
  , ( 4428, "N")
  , ( 4429, "j")
  , ( 4434, "ck")
  , ( 4435, "ch")
  , ( 4438, "pb")
  , ( 4439, "pN")
  , ( 4440, "hh")
  , ( 4441, "Q")
  , ( 4442, "[?]")
  , ( 4443, "[?]")
  , ( 4444, "[?]")
  , ( 4445, "[?]")
  , ( 4446, "[?]")
  , ( 4449, "a")
  , ( 4450, "ae")
  , ( 4451, "ya")
  , ( 4452, "yae")
  , ( 4453, "eo")
  , ( 4454, "e")
  , ( 4455, "yeo")
  , ( 4456, "ye")
  , ( 4457, "o")
  , ( 4458, "wa")
  , ( 4459, "wae")
  , ( 4460, "oe")
  , ( 4461, "yo")
  , ( 4462, "u")
  , ( 4463, "weo")
  , ( 4464, "we")
  , ( 4465, "wi")
  , ( 4466, "yu")
  , ( 4467, "eu")
  , ( 4468, "yi")
  , ( 4469, "i")
  , ( 4470, "a-o")
  , ( 4471, "a-u")
  , ( 4472, "ya-o")
  , ( 4473, "ya-yo")
  , ( 4474, "eo-o")
  , ( 4475, "eo-u")
  , ( 4476, "eo-eu")
  , ( 4477, "yeo-o")
  , ( 4478, "yeo-u")
  , ( 4479, "o-eo")
  , ( 4480, "o-e")
  , ( 4481, "o-ye")
  , ( 4482, "o-o")
  , ( 4483, "o-u")
  , ( 4484, "yo-ya")
  , ( 4485, "yo-yae")
  , ( 4486, "yo-yeo")
  , ( 4487, "yo-o")
  , ( 4488, "yo-i")
  , ( 4489, "u-a")
  , ( 4490, "u-ae")
  , ( 4491, "u-eo-eu")
  , ( 4492, "u-ye")
  , ( 4493, "u-u")
  , ( 4494, "yu-a")
  , ( 4495, "yu-eo")
  , ( 4496, "yu-e")
  , ( 4497, "yu-yeo")
  , ( 4498, "yu-ye")
  , ( 4499, "yu-u")
  , ( 4500, "yu-i")
  , ( 4501, "eu-u")
  , ( 4502, "eu-eu")
  , ( 4503, "yi-u")
  , ( 4504, "i-a")
  , ( 4505, "i-ya")
  , ( 4506, "i-o")
  , ( 4507, "i-u")
  , ( 4508, "i-eu")
  , ( 4509, "i-U")
  , ( 4510, "U")
  , ( 4511, "U-eo")
  , ( 4512, "U-u")
  , ( 4513, "U-i")
  , ( 4514, "UU")
  , ( 4515, "[?]")
  , ( 4516, "[?]")
  , ( 4517, "[?]")
  , ( 4518, "[?]")
  , ( 4519, "[?]")
  , ( 4520, "g")
  , ( 4521, "gg")
  , ( 4522, "gs")
  , ( 4523, "n")
  , ( 4524, "nj")
  , ( 4525, "nh")
  , ( 4526, "d")
  , ( 4527, "l")
  , ( 4528, "lg")
  , ( 4529, "lm")
  , ( 4530, "lb")
  , ( 4531, "ls")
  , ( 4532, "lt")
  , ( 4533, "lp")
  , ( 4534, "lh")
  , ( 4535, "m")
  , ( 4536, "b")
  , ( 4537, "bs")
  , ( 4538, "s")
  , ( 4539, "ss")
  , ( 4540, "ng")
  , ( 4541, "j")
  , ( 4542, "c")
  , ( 4543, "k")
  , ( 4544, "t")
  , ( 4545, "p")
  , ( 4546, "h")
  , ( 4547, "gl")
  , ( 4548, "gsg")
  , ( 4549, "ng")
  , ( 4550, "nd")
  , ( 4551, "ns")
  , ( 4552, "nZ")
  , ( 4553, "nt")
  , ( 4554, "dg")
  , ( 4555, "tl")
  , ( 4556, "lgs")
  , ( 4557, "ln")
  , ( 4558, "ld")
  , ( 4559, "lth")
  , ( 4560, "ll")
  , ( 4561, "lmg")
  , ( 4562, "lms")
  , ( 4563, "lbs")
  , ( 4564, "lbh")
  , ( 4565, "rNp")
  , ( 4566, "lss")
  , ( 4567, "lZ")
  , ( 4568, "lk")
  , ( 4569, "lQ")
  , ( 4570, "mg")
  , ( 4571, "ml")
  , ( 4572, "mb")
  , ( 4573, "ms")
  , ( 4574, "mss")
  , ( 4575, "mZ")
  , ( 4576, "mc")
  , ( 4577, "mh")
  , ( 4578, "mN")
  , ( 4579, "bl")
  , ( 4580, "bp")
  , ( 4581, "ph")
  , ( 4582, "pN")
  , ( 4583, "sg")
  , ( 4584, "sd")
  , ( 4585, "sl")
  , ( 4586, "sb")
  , ( 4587, "Z")
  , ( 4588, "g")
  , ( 4589, "ss")
  , ( 4591, "kh")
  , ( 4592, "N")
  , ( 4593, "Ns")
  , ( 4594, "NZ")
  , ( 4595, "pb")
  , ( 4596, "pN")
  , ( 4597, "hn")
  , ( 4598, "hl")
  , ( 4599, "hm")
  , ( 4600, "hb")
  , ( 4601, "Q")
  , ( 4602, "[?]")
  , ( 4603, "[?]")
  , ( 4604, "[?]")
  , ( 4605, "[?]")
  , ( 4606, "[?]")
  , ( 4608, "ha")
  , ( 4609, "hu")
  , ( 4610, "hi")
  , ( 4611, "haa")
  , ( 4612, "hee")
  , ( 4613, "he")
  , ( 4614, "ho")
  , ( 4615, "[?]")
  , ( 4616, "la")
  , ( 4617, "lu")
  , ( 4618, "li")
  , ( 4619, "laa")
  , ( 4620, "lee")
  , ( 4621, "le")
  , ( 4622, "lo")
  , ( 4623, "lwa")
  , ( 4624, "hha")
  , ( 4625, "hhu")
  , ( 4626, "hhi")
  , ( 4627, "hhaa")
  , ( 4628, "hhee")
  , ( 4629, "hhe")
  , ( 4630, "hho")
  , ( 4631, "hhwa")
  , ( 4632, "ma")
  , ( 4633, "mu")
  , ( 4634, "mi")
  , ( 4635, "maa")
  , ( 4636, "mee")
  , ( 4637, "me")
  , ( 4638, "mo")
  , ( 4639, "mwa")
  , ( 4640, "sza")
  , ( 4641, "szu")
  , ( 4642, "szi")
  , ( 4643, "szaa")
  , ( 4644, "szee")
  , ( 4645, "sze")
  , ( 4646, "szo")
  , ( 4647, "szwa")
  , ( 4648, "ra")
  , ( 4649, "ru")
  , ( 4650, "ri")
  , ( 4651, "raa")
  , ( 4652, "ree")
  , ( 4653, "re")
  , ( 4654, "ro")
  , ( 4655, "rwa")
  , ( 4656, "sa")
  , ( 4657, "su")
  , ( 4658, "si")
  , ( 4659, "saa")
  , ( 4660, "see")
  , ( 4661, "se")
  , ( 4662, "so")
  , ( 4663, "swa")
  , ( 4664, "sha")
  , ( 4665, "shu")
  , ( 4666, "shi")
  , ( 4667, "shaa")
  , ( 4668, "shee")
  , ( 4669, "she")
  , ( 4670, "sho")
  , ( 4671, "shwa")
  , ( 4672, "qa")
  , ( 4673, "qu")
  , ( 4674, "qi")
  , ( 4675, "qaa")
  , ( 4676, "qee")
  , ( 4677, "qe")
  , ( 4678, "qo")
  , ( 4679, "[?]")
  , ( 4680, "qwa")
  , ( 4681, "[?]")
  , ( 4682, "qwi")
  , ( 4683, "qwaa")
  , ( 4684, "qwee")
  , ( 4685, "qwe")
  , ( 4686, "[?]")
  , ( 4687, "[?]")
  , ( 4688, "qha")
  , ( 4689, "qhu")
  , ( 4690, "qhi")
  , ( 4691, "qhaa")
  , ( 4692, "qhee")
  , ( 4693, "qhe")
  , ( 4694, "qho")
  , ( 4695, "[?]")
  , ( 4696, "qhwa")
  , ( 4697, "[?]")
  , ( 4698, "qhwi")
  , ( 4699, "qhwaa")
  , ( 4700, "qhwee")
  , ( 4701, "qhwe")
  , ( 4702, "[?]")
  , ( 4703, "[?]")
  , ( 4704, "ba")
  , ( 4705, "bu")
  , ( 4706, "bi")
  , ( 4707, "baa")
  , ( 4708, "bee")
  , ( 4709, "be")
  , ( 4710, "bo")
  , ( 4711, "bwa")
  , ( 4712, "va")
  , ( 4713, "vu")
  , ( 4714, "vi")
  , ( 4715, "vaa")
  , ( 4716, "vee")
  , ( 4717, "ve")
  , ( 4718, "vo")
  , ( 4719, "vwa")
  , ( 4720, "ta")
  , ( 4721, "tu")
  , ( 4722, "ti")
  , ( 4723, "taa")
  , ( 4724, "tee")
  , ( 4725, "te")
  , ( 4726, "to")
  , ( 4727, "twa")
  , ( 4728, "ca")
  , ( 4729, "cu")
  , ( 4730, "ci")
  , ( 4731, "caa")
  , ( 4732, "cee")
  , ( 4733, "ce")
  , ( 4734, "co")
  , ( 4735, "cwa")
  , ( 4736, "xa")
  , ( 4737, "xu")
  , ( 4738, "xi")
  , ( 4739, "xaa")
  , ( 4740, "xee")
  , ( 4741, "xe")
  , ( 4742, "xo")
  , ( 4743, "[?]")
  , ( 4744, "xwa")
  , ( 4745, "[?]")
  , ( 4746, "xwi")
  , ( 4747, "xwaa")
  , ( 4748, "xwee")
  , ( 4749, "xwe")
  , ( 4750, "[?]")
  , ( 4751, "[?]")
  , ( 4752, "na")
  , ( 4753, "nu")
  , ( 4754, "ni")
  , ( 4755, "naa")
  , ( 4756, "nee")
  , ( 4757, "ne")
  , ( 4758, "no")
  , ( 4759, "nwa")
  , ( 4760, "nya")
  , ( 4761, "nyu")
  , ( 4762, "nyi")
  , ( 4763, "nyaa")
  , ( 4764, "nyee")
  , ( 4765, "nye")
  , ( 4766, "nyo")
  , ( 4767, "nywa")
  , ( 4768, "'a")
  , ( 4769, "'u")
  , ( 4770, "[?]")
  , ( 4771, "'aa")
  , ( 4772, "'ee")
  , ( 4773, "'e")
  , ( 4774, "'o")
  , ( 4775, "'wa")
  , ( 4776, "ka")
  , ( 4777, "ku")
  , ( 4778, "ki")
  , ( 4779, "kaa")
  , ( 4780, "kee")
  , ( 4781, "ke")
  , ( 4782, "ko")
  , ( 4783, "[?]")
  , ( 4784, "kwa")
  , ( 4785, "[?]")
  , ( 4786, "kwi")
  , ( 4787, "kwaa")
  , ( 4788, "kwee")
  , ( 4789, "kwe")
  , ( 4790, "[?]")
  , ( 4791, "[?]")
  , ( 4792, "kxa")
  , ( 4793, "kxu")
  , ( 4794, "kxi")
  , ( 4795, "kxaa")
  , ( 4796, "kxee")
  , ( 4797, "kxe")
  , ( 4798, "kxo")
  , ( 4799, "[?]")
  , ( 4800, "kxwa")
  , ( 4801, "[?]")
  , ( 4802, "kxwi")
  , ( 4803, "kxwaa")
  , ( 4804, "kxwee")
  , ( 4805, "kxwe")
  , ( 4806, "[?]")
  , ( 4807, "[?]")
  , ( 4808, "wa")
  , ( 4809, "wu")
  , ( 4810, "wi")
  , ( 4811, "waa")
  , ( 4812, "wee")
  , ( 4813, "we")
  , ( 4814, "wo")
  , ( 4815, "[?]")
  , ( 4816, "`a")
  , ( 4817, "`u")
  , ( 4818, "`i")
  , ( 4819, "`aa")
  , ( 4820, "`ee")
  , ( 4821, "`e")
  , ( 4822, "`o")
  , ( 4823, "[?]")
  , ( 4824, "za")
  , ( 4825, "zu")
  , ( 4826, "zi")
  , ( 4827, "zaa")
  , ( 4828, "zee")
  , ( 4829, "ze")
  , ( 4830, "zo")
  , ( 4831, "zwa")
  , ( 4832, "zha")
  , ( 4833, "zhu")
  , ( 4834, "zhi")
  , ( 4835, "zhaa")
  , ( 4836, "zhee")
  , ( 4837, "zhe")
  , ( 4838, "zho")
  , ( 4839, "zhwa")
  , ( 4840, "ya")
  , ( 4841, "yu")
  , ( 4842, "yi")
  , ( 4843, "yaa")
  , ( 4844, "yee")
  , ( 4845, "ye")
  , ( 4846, "yo")
  , ( 4847, "[?]")
  , ( 4848, "da")
  , ( 4849, "du")
  , ( 4850, "di")
  , ( 4851, "daa")
  , ( 4852, "dee")
  , ( 4853, "de")
  , ( 4854, "do")
  , ( 4855, "dwa")
  , ( 4856, "dda")
  , ( 4857, "ddu")
  , ( 4858, "ddi")
  , ( 4859, "ddaa")
  , ( 4860, "ddee")
  , ( 4861, "dde")
  , ( 4862, "ddo")
  , ( 4863, "ddwa")
  , ( 4864, "ja")
  , ( 4865, "ju")
  , ( 4866, "ji")
  , ( 4867, "jaa")
  , ( 4868, "jee")
  , ( 4869, "je")
  , ( 4870, "jo")
  , ( 4871, "jwa")
  , ( 4872, "ga")
  , ( 4873, "gu")
  , ( 4874, "gi")
  , ( 4875, "gaa")
  , ( 4876, "gee")
  , ( 4877, "ge")
  , ( 4878, "go")
  , ( 4879, "[?]")
  , ( 4880, "gwa")
  , ( 4881, "[?]")
  , ( 4882, "gwi")
  , ( 4883, "gwaa")
  , ( 4884, "gwee")
  , ( 4885, "gwe")
  , ( 4886, "[?]")
  , ( 4887, "[?]")
  , ( 4888, "gga")
  , ( 4889, "ggu")
  , ( 4890, "ggi")
  , ( 4891, "ggaa")
  , ( 4892, "ggee")
  , ( 4893, "gge")
  , ( 4894, "ggo")
  , ( 4895, "[?]")
  , ( 4896, "tha")
  , ( 4897, "thu")
  , ( 4898, "thi")
  , ( 4899, "thaa")
  , ( 4900, "thee")
  , ( 4901, "the")
  , ( 4902, "tho")
  , ( 4903, "thwa")
  , ( 4904, "cha")
  , ( 4905, "chu")
  , ( 4906, "chi")
  , ( 4907, "chaa")
  , ( 4908, "chee")
  , ( 4909, "che")
  , ( 4910, "cho")
  , ( 4911, "chwa")
  , ( 4912, "pha")
  , ( 4913, "phu")
  , ( 4914, "phi")
  , ( 4915, "phaa")
  , ( 4916, "phee")
  , ( 4917, "phe")
  , ( 4918, "pho")
  , ( 4919, "phwa")
  , ( 4920, "tsa")
  , ( 4921, "tsu")
  , ( 4922, "tsi")
  , ( 4923, "tsaa")
  , ( 4924, "tsee")
  , ( 4925, "tse")
  , ( 4926, "tso")
  , ( 4927, "tswa")
  , ( 4928, "tza")
  , ( 4929, "tzu")
  , ( 4930, "tzi")
  , ( 4931, "tzaa")
  , ( 4932, "tzee")
  , ( 4933, "tze")
  , ( 4934, "tzo")
  , ( 4935, "[?]")
  , ( 4936, "fa")
  , ( 4937, "fu")
  , ( 4938, "fi")
  , ( 4939, "faa")
  , ( 4940, "fee")
  , ( 4941, "fe")
  , ( 4942, "fo")
  , ( 4943, "fwa")
  , ( 4944, "pa")
  , ( 4945, "pu")
  , ( 4946, "pi")
  , ( 4947, "paa")
  , ( 4948, "pee")
  , ( 4949, "pe")
  , ( 4950, "po")
  , ( 4951, "pwa")
  , ( 4952, "rya")
  , ( 4953, "mya")
  , ( 4954, "fya")
  , ( 4955, "[?]")
  , ( 4956, "[?]")
  , ( 4957, "[?]")
  , ( 4958, "[?]")
  , ( 4959, "[?]")
  , ( 4960, "[?]")
  , ( 4961, " ")
  , ( 4962, ".")
  , ( 4963, ",")
  , ( 4964, ";")
  , ( 4965, ":")
  , ( 4966, ":: ")
  , ( 4967, "?")
  , ( 4968, "//")
  , ( 4969, "1")
  , ( 4970, "2")
  , ( 4971, "3")
  , ( 4972, "4")
  , ( 4973, "5")
  , ( 4974, "6")
  , ( 4975, "7")
  , ( 4976, "8")
  , ( 4977, "9")
  , ( 4978, "10+")
  , ( 4979, "20+")
  , ( 4980, "30+")
  , ( 4981, "40+")
  , ( 4982, "50+")
  , ( 4983, "60+")
  , ( 4984, "70+")
  , ( 4985, "80+")
  , ( 4986, "90+")
  , ( 4987, "100+")
  , ( 4988, "10,000+")
  , ( 4989, "[?]")
  , ( 4990, "[?]")
  , ( 4991, "[?]")
  , ( 4992, "[?]")
  , ( 4993, "[?]")
  , ( 4994, "[?]")
  , ( 4995, "[?]")
  , ( 4996, "[?]")
  , ( 4997, "[?]")
  , ( 4998, "[?]")
  , ( 4999, "[?]")
  , ( 5000, "[?]")
  , ( 5001, "[?]")
  , ( 5002, "[?]")
  , ( 5003, "[?]")
  , ( 5004, "[?]")
  , ( 5005, "[?]")
  , ( 5006, "[?]")
  , ( 5007, "[?]")
  , ( 5008, "[?]")
  , ( 5009, "[?]")
  , ( 5010, "[?]")
  , ( 5011, "[?]")
  , ( 5012, "[?]")
  , ( 5013, "[?]")
  , ( 5014, "[?]")
  , ( 5015, "[?]")
  , ( 5016, "[?]")
  , ( 5017, "[?]")
  , ( 5018, "[?]")
  , ( 5019, "[?]")
  , ( 5020, "[?]")
  , ( 5021, "[?]")
  , ( 5022, "[?]")
  , ( 5023, "[?]")
  , ( 5024, "a")
  , ( 5025, "e")
  , ( 5026, "i")
  , ( 5027, "o")
  , ( 5028, "u")
  , ( 5029, "v")
  , ( 5030, "ga")
  , ( 5031, "ka")
  , ( 5032, "ge")
  , ( 5033, "gi")
  , ( 5034, "go")
  , ( 5035, "gu")
  , ( 5036, "gv")
  , ( 5037, "ha")
  , ( 5038, "he")
  , ( 5039, "hi")
  , ( 5040, "ho")
  , ( 5041, "hu")
  , ( 5042, "hv")
  , ( 5043, "la")
  , ( 5044, "le")
  , ( 5045, "li")
  , ( 5046, "lo")
  , ( 5047, "lu")
  , ( 5048, "lv")
  , ( 5049, "ma")
  , ( 5050, "me")
  , ( 5051, "mi")
  , ( 5052, "mo")
  , ( 5053, "mu")
  , ( 5054, "na")
  , ( 5055, "hna")
  , ( 5056, "nah")
  , ( 5057, "ne")
  , ( 5058, "ni")
  , ( 5059, "no")
  , ( 5060, "nu")
  , ( 5061, "nv")
  , ( 5062, "qua")
  , ( 5063, "que")
  , ( 5064, "qui")
  , ( 5065, "quo")
  , ( 5066, "quu")
  , ( 5067, "quv")
  , ( 5068, "sa")
  , ( 5069, "s")
  , ( 5070, "se")
  , ( 5071, "si")
  , ( 5072, "so")
  , ( 5073, "su")
  , ( 5074, "sv")
  , ( 5075, "da")
  , ( 5076, "ta")
  , ( 5077, "de")
  , ( 5078, "te")
  , ( 5079, "di")
  , ( 5080, "ti")
  , ( 5081, "do")
  , ( 5082, "du")
  , ( 5083, "dv")
  , ( 5084, "dla")
  , ( 5085, "tla")
  , ( 5086, "tle")
  , ( 5087, "tli")
  , ( 5088, "tlo")
  , ( 5089, "tlu")
  , ( 5090, "tlv")
  , ( 5091, "tsa")
  , ( 5092, "tse")
  , ( 5093, "tsi")
  , ( 5094, "tso")
  , ( 5095, "tsu")
  , ( 5096, "tsv")
  , ( 5097, "wa")
  , ( 5098, "we")
  , ( 5099, "wi")
  , ( 5100, "wo")
  , ( 5101, "wu")
  , ( 5102, "wv")
  , ( 5103, "ya")
  , ( 5104, "ye")
  , ( 5105, "yi")
  , ( 5106, "yo")
  , ( 5107, "yu")
  , ( 5108, "yv")
  , ( 5109, "[?]")
  , ( 5110, "[?]")
  , ( 5111, "[?]")
  , ( 5112, "[?]")
  , ( 5113, "[?]")
  , ( 5114, "[?]")
  , ( 5115, "[?]")
  , ( 5116, "[?]")
  , ( 5117, "[?]")
  , ( 5118, "[?]")
  , ( 5120, "[?]")
  , ( 5121, "e")
  , ( 5122, "aai")
  , ( 5123, "i")
  , ( 5124, "ii")
  , ( 5125, "o")
  , ( 5126, "oo")
  , ( 5127, "oo")
  , ( 5128, "ee")
  , ( 5129, "i")
  , ( 5130, "a")
  , ( 5131, "aa")
  , ( 5132, "we")
  , ( 5133, "we")
  , ( 5134, "wi")
  , ( 5135, "wi")
  , ( 5136, "wii")
  , ( 5137, "wii")
  , ( 5138, "wo")
  , ( 5139, "wo")
  , ( 5140, "woo")
  , ( 5141, "woo")
  , ( 5142, "woo")
  , ( 5143, "wa")
  , ( 5144, "wa")
  , ( 5145, "waa")
  , ( 5146, "waa")
  , ( 5147, "waa")
  , ( 5148, "ai")
  , ( 5149, "w")
  , ( 5150, "'")
  , ( 5151, "t")
  , ( 5152, "k")
  , ( 5153, "sh")
  , ( 5154, "s")
  , ( 5155, "n")
  , ( 5156, "w")
  , ( 5157, "n")
  , ( 5158, "[?]")
  , ( 5159, "w")
  , ( 5160, "c")
  , ( 5161, "?")
  , ( 5162, "l")
  , ( 5163, "en")
  , ( 5164, "in")
  , ( 5165, "on")
  , ( 5166, "an")
  , ( 5167, "pe")
  , ( 5168, "paai")
  , ( 5169, "pi")
  , ( 5170, "pii")
  , ( 5171, "po")
  , ( 5172, "poo")
  , ( 5173, "poo")
  , ( 5174, "hee")
  , ( 5175, "hi")
  , ( 5176, "pa")
  , ( 5177, "paa")
  , ( 5178, "pwe")
  , ( 5179, "pwe")
  , ( 5180, "pwi")
  , ( 5181, "pwi")
  , ( 5182, "pwii")
  , ( 5183, "pwii")
  , ( 5184, "pwo")
  , ( 5185, "pwo")
  , ( 5186, "pwoo")
  , ( 5187, "pwoo")
  , ( 5188, "pwa")
  , ( 5189, "pwa")
  , ( 5190, "pwaa")
  , ( 5191, "pwaa")
  , ( 5192, "pwaa")
  , ( 5193, "p")
  , ( 5194, "p")
  , ( 5195, "h")
  , ( 5196, "te")
  , ( 5197, "taai")
  , ( 5198, "ti")
  , ( 5199, "tii")
  , ( 5200, "to")
  , ( 5201, "too")
  , ( 5202, "too")
  , ( 5203, "dee")
  , ( 5204, "di")
  , ( 5205, "ta")
  , ( 5206, "taa")
  , ( 5207, "twe")
  , ( 5208, "twe")
  , ( 5209, "twi")
  , ( 5210, "twi")
  , ( 5211, "twii")
  , ( 5212, "twii")
  , ( 5213, "two")
  , ( 5214, "two")
  , ( 5215, "twoo")
  , ( 5216, "twoo")
  , ( 5217, "twa")
  , ( 5218, "twa")
  , ( 5219, "twaa")
  , ( 5220, "twaa")
  , ( 5221, "twaa")
  , ( 5222, "t")
  , ( 5223, "tte")
  , ( 5224, "tti")
  , ( 5225, "tto")
  , ( 5226, "tta")
  , ( 5227, "ke")
  , ( 5228, "kaai")
  , ( 5229, "ki")
  , ( 5230, "kii")
  , ( 5231, "ko")
  , ( 5232, "koo")
  , ( 5233, "koo")
  , ( 5234, "ka")
  , ( 5235, "kaa")
  , ( 5236, "kwe")
  , ( 5237, "kwe")
  , ( 5238, "kwi")
  , ( 5239, "kwi")
  , ( 5240, "kwii")
  , ( 5241, "kwii")
  , ( 5242, "kwo")
  , ( 5243, "kwo")
  , ( 5244, "kwoo")
  , ( 5245, "kwoo")
  , ( 5246, "kwa")
  , ( 5247, "kwa")
  , ( 5248, "kwaa")
  , ( 5249, "kwaa")
  , ( 5250, "kwaa")
  , ( 5251, "k")
  , ( 5252, "kw")
  , ( 5253, "keh")
  , ( 5254, "kih")
  , ( 5255, "koh")
  , ( 5256, "kah")
  , ( 5257, "ce")
  , ( 5258, "caai")
  , ( 5259, "ci")
  , ( 5260, "cii")
  , ( 5261, "co")
  , ( 5262, "coo")
  , ( 5263, "coo")
  , ( 5264, "ca")
  , ( 5265, "caa")
  , ( 5266, "cwe")
  , ( 5267, "cwe")
  , ( 5268, "cwi")
  , ( 5269, "cwi")
  , ( 5270, "cwii")
  , ( 5271, "cwii")
  , ( 5272, "cwo")
  , ( 5273, "cwo")
  , ( 5274, "cwoo")
  , ( 5275, "cwoo")
  , ( 5276, "cwa")
  , ( 5277, "cwa")
  , ( 5278, "cwaa")
  , ( 5279, "cwaa")
  , ( 5280, "cwaa")
  , ( 5281, "c")
  , ( 5282, "th")
  , ( 5283, "me")
  , ( 5284, "maai")
  , ( 5285, "mi")
  , ( 5286, "mii")
  , ( 5287, "mo")
  , ( 5288, "moo")
  , ( 5289, "moo")
  , ( 5290, "ma")
  , ( 5291, "maa")
  , ( 5292, "mwe")
  , ( 5293, "mwe")
  , ( 5294, "mwi")
  , ( 5295, "mwi")
  , ( 5296, "mwii")
  , ( 5297, "mwii")
  , ( 5298, "mwo")
  , ( 5299, "mwo")
  , ( 5300, "mwoo")
  , ( 5301, "mwoo")
  , ( 5302, "mwa")
  , ( 5303, "mwa")
  , ( 5304, "mwaa")
  , ( 5305, "mwaa")
  , ( 5306, "mwaa")
  , ( 5307, "m")
  , ( 5308, "m")
  , ( 5309, "mh")
  , ( 5310, "m")
  , ( 5311, "m")
  , ( 5312, "ne")
  , ( 5313, "naai")
  , ( 5314, "ni")
  , ( 5315, "nii")
  , ( 5316, "no")
  , ( 5317, "noo")
  , ( 5318, "noo")
  , ( 5319, "na")
  , ( 5320, "naa")
  , ( 5321, "nwe")
  , ( 5322, "nwe")
  , ( 5323, "nwa")
  , ( 5324, "nwa")
  , ( 5325, "nwaa")
  , ( 5326, "nwaa")
  , ( 5327, "nwaa")
  , ( 5328, "n")
  , ( 5329, "ng")
  , ( 5330, "nh")
  , ( 5331, "le")
  , ( 5332, "laai")
  , ( 5333, "li")
  , ( 5334, "lii")
  , ( 5335, "lo")
  , ( 5336, "loo")
  , ( 5337, "loo")
  , ( 5338, "la")
  , ( 5339, "laa")
  , ( 5340, "lwe")
  , ( 5341, "lwe")
  , ( 5342, "lwi")
  , ( 5343, "lwi")
  , ( 5344, "lwii")
  , ( 5345, "lwii")
  , ( 5346, "lwo")
  , ( 5347, "lwo")
  , ( 5348, "lwoo")
  , ( 5349, "lwoo")
  , ( 5350, "lwa")
  , ( 5351, "lwa")
  , ( 5352, "lwaa")
  , ( 5353, "lwaa")
  , ( 5354, "l")
  , ( 5355, "l")
  , ( 5356, "l")
  , ( 5357, "se")
  , ( 5358, "saai")
  , ( 5359, "si")
  , ( 5360, "sii")
  , ( 5361, "so")
  , ( 5362, "soo")
  , ( 5363, "soo")
  , ( 5364, "sa")
  , ( 5365, "saa")
  , ( 5366, "swe")
  , ( 5367, "swe")
  , ( 5368, "swi")
  , ( 5369, "swi")
  , ( 5370, "swii")
  , ( 5371, "swii")
  , ( 5372, "swo")
  , ( 5373, "swo")
  , ( 5374, "swoo")
  , ( 5375, "swoo")
  , ( 5376, "swa")
  , ( 5377, "swa")
  , ( 5378, "swaa")
  , ( 5379, "swaa")
  , ( 5380, "swaa")
  , ( 5381, "s")
  , ( 5382, "s")
  , ( 5383, "sw")
  , ( 5384, "s")
  , ( 5385, "sk")
  , ( 5386, "skw")
  , ( 5387, "sW")
  , ( 5388, "spwa")
  , ( 5389, "stwa")
  , ( 5390, "skwa")
  , ( 5391, "scwa")
  , ( 5392, "she")
  , ( 5393, "shi")
  , ( 5394, "shii")
  , ( 5395, "sho")
  , ( 5396, "shoo")
  , ( 5397, "sha")
  , ( 5398, "shaa")
  , ( 5399, "shwe")
  , ( 5400, "shwe")
  , ( 5401, "shwi")
  , ( 5402, "shwi")
  , ( 5403, "shwii")
  , ( 5404, "shwii")
  , ( 5405, "shwo")
  , ( 5406, "shwo")
  , ( 5407, "shwoo")
  , ( 5408, "shwoo")
  , ( 5409, "shwa")
  , ( 5410, "shwa")
  , ( 5411, "shwaa")
  , ( 5412, "shwaa")
  , ( 5413, "sh")
  , ( 5414, "ye")
  , ( 5415, "yaai")
  , ( 5416, "yi")
  , ( 5417, "yii")
  , ( 5418, "yo")
  , ( 5419, "yoo")
  , ( 5420, "yoo")
  , ( 5421, "ya")
  , ( 5422, "yaa")
  , ( 5423, "ywe")
  , ( 5424, "ywe")
  , ( 5425, "ywi")
  , ( 5426, "ywi")
  , ( 5427, "ywii")
  , ( 5428, "ywii")
  , ( 5429, "ywo")
  , ( 5430, "ywo")
  , ( 5431, "ywoo")
  , ( 5432, "ywoo")
  , ( 5433, "ywa")
  , ( 5434, "ywa")
  , ( 5435, "ywaa")
  , ( 5436, "ywaa")
  , ( 5437, "ywaa")
  , ( 5438, "y")
  , ( 5439, "y")
  , ( 5440, "y")
  , ( 5441, "yi")
  , ( 5442, "re")
  , ( 5443, "re")
  , ( 5444, "le")
  , ( 5445, "raai")
  , ( 5446, "ri")
  , ( 5447, "rii")
  , ( 5448, "ro")
  , ( 5449, "roo")
  , ( 5450, "lo")
  , ( 5451, "ra")
  , ( 5452, "raa")
  , ( 5453, "la")
  , ( 5454, "rwaa")
  , ( 5455, "rwaa")
  , ( 5456, "r")
  , ( 5457, "r")
  , ( 5458, "r")
  , ( 5459, "fe")
  , ( 5460, "faai")
  , ( 5461, "fi")
  , ( 5462, "fii")
  , ( 5463, "fo")
  , ( 5464, "foo")
  , ( 5465, "fa")
  , ( 5466, "faa")
  , ( 5467, "fwaa")
  , ( 5468, "fwaa")
  , ( 5469, "f")
  , ( 5470, "the")
  , ( 5471, "the")
  , ( 5472, "thi")
  , ( 5473, "thi")
  , ( 5474, "thii")
  , ( 5475, "thii")
  , ( 5476, "tho")
  , ( 5477, "thoo")
  , ( 5478, "tha")
  , ( 5479, "thaa")
  , ( 5480, "thwaa")
  , ( 5481, "thwaa")
  , ( 5482, "th")
  , ( 5483, "tthe")
  , ( 5484, "tthi")
  , ( 5485, "ttho")
  , ( 5486, "ttha")
  , ( 5487, "tth")
  , ( 5488, "tye")
  , ( 5489, "tyi")
  , ( 5490, "tyo")
  , ( 5491, "tya")
  , ( 5492, "he")
  , ( 5493, "hi")
  , ( 5494, "hii")
  , ( 5495, "ho")
  , ( 5496, "hoo")
  , ( 5497, "ha")
  , ( 5498, "haa")
  , ( 5499, "h")
  , ( 5500, "h")
  , ( 5501, "hk")
  , ( 5502, "qaai")
  , ( 5503, "qi")
  , ( 5504, "qii")
  , ( 5505, "qo")
  , ( 5506, "qoo")
  , ( 5507, "qa")
  , ( 5508, "qaa")
  , ( 5509, "q")
  , ( 5510, "tlhe")
  , ( 5511, "tlhi")
  , ( 5512, "tlho")
  , ( 5513, "tlha")
  , ( 5514, "re")
  , ( 5515, "ri")
  , ( 5516, "ro")
  , ( 5517, "ra")
  , ( 5518, "ngaai")
  , ( 5519, "ngi")
  , ( 5520, "ngii")
  , ( 5521, "ngo")
  , ( 5522, "ngoo")
  , ( 5523, "nga")
  , ( 5524, "ngaa")
  , ( 5525, "ng")
  , ( 5526, "nng")
  , ( 5527, "she")
  , ( 5528, "shi")
  , ( 5529, "sho")
  , ( 5530, "sha")
  , ( 5531, "the")
  , ( 5532, "thi")
  , ( 5533, "tho")
  , ( 5534, "tha")
  , ( 5535, "th")
  , ( 5536, "lhi")
  , ( 5537, "lhii")
  , ( 5538, "lho")
  , ( 5539, "lhoo")
  , ( 5540, "lha")
  , ( 5541, "lhaa")
  , ( 5542, "lh")
  , ( 5543, "the")
  , ( 5544, "thi")
  , ( 5545, "thii")
  , ( 5546, "tho")
  , ( 5547, "thoo")
  , ( 5548, "tha")
  , ( 5549, "thaa")
  , ( 5550, "th")
  , ( 5551, "b")
  , ( 5552, "e")
  , ( 5553, "i")
  , ( 5554, "o")
  , ( 5555, "a")
  , ( 5556, "we")
  , ( 5557, "wi")
  , ( 5558, "wo")
  , ( 5559, "wa")
  , ( 5560, "ne")
  , ( 5561, "ni")
  , ( 5562, "no")
  , ( 5563, "na")
  , ( 5564, "ke")
  , ( 5565, "ki")
  , ( 5566, "ko")
  , ( 5567, "ka")
  , ( 5568, "he")
  , ( 5569, "hi")
  , ( 5570, "ho")
  , ( 5571, "ha")
  , ( 5572, "ghu")
  , ( 5573, "gho")
  , ( 5574, "ghe")
  , ( 5575, "ghee")
  , ( 5576, "ghi")
  , ( 5577, "gha")
  , ( 5578, "ru")
  , ( 5579, "ro")
  , ( 5580, "re")
  , ( 5581, "ree")
  , ( 5582, "ri")
  , ( 5583, "ra")
  , ( 5584, "wu")
  , ( 5585, "wo")
  , ( 5586, "we")
  , ( 5587, "wee")
  , ( 5588, "wi")
  , ( 5589, "wa")
  , ( 5590, "hwu")
  , ( 5591, "hwo")
  , ( 5592, "hwe")
  , ( 5593, "hwee")
  , ( 5594, "hwi")
  , ( 5595, "hwa")
  , ( 5596, "thu")
  , ( 5597, "tho")
  , ( 5598, "the")
  , ( 5599, "thee")
  , ( 5600, "thi")
  , ( 5601, "tha")
  , ( 5602, "ttu")
  , ( 5603, "tto")
  , ( 5604, "tte")
  , ( 5605, "ttee")
  , ( 5606, "tti")
  , ( 5607, "tta")
  , ( 5608, "pu")
  , ( 5609, "po")
  , ( 5610, "pe")
  , ( 5611, "pee")
  , ( 5612, "pi")
  , ( 5613, "pa")
  , ( 5614, "p")
  , ( 5615, "gu")
  , ( 5616, "go")
  , ( 5617, "ge")
  , ( 5618, "gee")
  , ( 5619, "gi")
  , ( 5620, "ga")
  , ( 5621, "khu")
  , ( 5622, "kho")
  , ( 5623, "khe")
  , ( 5624, "khee")
  , ( 5625, "khi")
  , ( 5626, "kha")
  , ( 5627, "kku")
  , ( 5628, "kko")
  , ( 5629, "kke")
  , ( 5630, "kkee")
  , ( 5631, "kki")
  , ( 5632, "kka")
  , ( 5633, "kk")
  , ( 5634, "nu")
  , ( 5635, "no")
  , ( 5636, "ne")
  , ( 5637, "nee")
  , ( 5638, "ni")
  , ( 5639, "na")
  , ( 5640, "mu")
  , ( 5641, "mo")
  , ( 5642, "me")
  , ( 5643, "mee")
  , ( 5644, "mi")
  , ( 5645, "ma")
  , ( 5646, "yu")
  , ( 5647, "yo")
  , ( 5648, "ye")
  , ( 5649, "yee")
  , ( 5650, "yi")
  , ( 5651, "ya")
  , ( 5652, "ju")
  , ( 5653, "ju")
  , ( 5654, "jo")
  , ( 5655, "je")
  , ( 5656, "jee")
  , ( 5657, "ji")
  , ( 5658, "ji")
  , ( 5659, "ja")
  , ( 5660, "jju")
  , ( 5661, "jjo")
  , ( 5662, "jje")
  , ( 5663, "jjee")
  , ( 5664, "jji")
  , ( 5665, "jja")
  , ( 5666, "lu")
  , ( 5667, "lo")
  , ( 5668, "le")
  , ( 5669, "lee")
  , ( 5670, "li")
  , ( 5671, "la")
  , ( 5672, "dlu")
  , ( 5673, "dlo")
  , ( 5674, "dle")
  , ( 5675, "dlee")
  , ( 5676, "dli")
  , ( 5677, "dla")
  , ( 5678, "lhu")
  , ( 5679, "lho")
  , ( 5680, "lhe")
  , ( 5681, "lhee")
  , ( 5682, "lhi")
  , ( 5683, "lha")
  , ( 5684, "tlhu")
  , ( 5685, "tlho")
  , ( 5686, "tlhe")
  , ( 5687, "tlhee")
  , ( 5688, "tlhi")
  , ( 5689, "tlha")
  , ( 5690, "tlu")
  , ( 5691, "tlo")
  , ( 5692, "tle")
  , ( 5693, "tlee")
  , ( 5694, "tli")
  , ( 5695, "tla")
  , ( 5696, "zu")
  , ( 5697, "zo")
  , ( 5698, "ze")
  , ( 5699, "zee")
  , ( 5700, "zi")
  , ( 5701, "za")
  , ( 5702, "z")
  , ( 5703, "z")
  , ( 5704, "dzu")
  , ( 5705, "dzo")
  , ( 5706, "dze")
  , ( 5707, "dzee")
  , ( 5708, "dzi")
  , ( 5709, "dza")
  , ( 5710, "su")
  , ( 5711, "so")
  , ( 5712, "se")
  , ( 5713, "see")
  , ( 5714, "si")
  , ( 5715, "sa")
  , ( 5716, "shu")
  , ( 5717, "sho")
  , ( 5718, "she")
  , ( 5719, "shee")
  , ( 5720, "shi")
  , ( 5721, "sha")
  , ( 5722, "sh")
  , ( 5723, "tsu")
  , ( 5724, "tso")
  , ( 5725, "tse")
  , ( 5726, "tsee")
  , ( 5727, "tsi")
  , ( 5728, "tsa")
  , ( 5729, "chu")
  , ( 5730, "cho")
  , ( 5731, "che")
  , ( 5732, "chee")
  , ( 5733, "chi")
  , ( 5734, "cha")
  , ( 5735, "ttsu")
  , ( 5736, "ttso")
  , ( 5737, "ttse")
  , ( 5738, "ttsee")
  , ( 5739, "ttsi")
  , ( 5740, "ttsa")
  , ( 5741, "X")
  , ( 5742, ".")
  , ( 5743, "qai")
  , ( 5744, "ngai")
  , ( 5745, "nngi")
  , ( 5746, "nngii")
  , ( 5747, "nngo")
  , ( 5748, "nngoo")
  , ( 5749, "nnga")
  , ( 5750, "nngaa")
  , ( 5751, "[?]")
  , ( 5752, "[?]")
  , ( 5753, "[?]")
  , ( 5754, "[?]")
  , ( 5755, "[?]")
  , ( 5756, "[?]")
  , ( 5757, "[?]")
  , ( 5758, "[?]")
  , ( 5759, "[?]")
  , ( 5760, " ")
  , ( 5761, "b")
  , ( 5762, "l")
  , ( 5763, "f")
  , ( 5764, "s")
  , ( 5765, "n")
  , ( 5766, "h")
  , ( 5767, "d")
  , ( 5768, "t")
  , ( 5769, "c")
  , ( 5770, "q")
  , ( 5771, "m")
  , ( 5772, "g")
  , ( 5773, "ng")
  , ( 5774, "z")
  , ( 5775, "r")
  , ( 5776, "a")
  , ( 5777, "o")
  , ( 5778, "u")
  , ( 5779, "e")
  , ( 5780, "i")
  , ( 5781, "ch")
  , ( 5782, "th")
  , ( 5783, "ph")
  , ( 5784, "p")
  , ( 5785, "x")
  , ( 5786, "p")
  , ( 5787, "<")
  , ( 5788, ">")
  , ( 5789, "[?]")
  , ( 5790, "[?]")
  , ( 5791, "[?]")
  , ( 5792, "f")
  , ( 5793, "v")
  , ( 5794, "u")
  , ( 5795, "yr")
  , ( 5796, "y")
  , ( 5797, "w")
  , ( 5798, "th")
  , ( 5799, "th")
  , ( 5800, "a")
  , ( 5801, "o")
  , ( 5802, "ac")
  , ( 5803, "ae")
  , ( 5804, "o")
  , ( 5805, "o")
  , ( 5806, "o")
  , ( 5807, "oe")
  , ( 5808, "on")
  , ( 5809, "r")
  , ( 5810, "k")
  , ( 5811, "c")
  , ( 5812, "k")
  , ( 5813, "g")
  , ( 5814, "ng")
  , ( 5815, "g")
  , ( 5816, "g")
  , ( 5817, "w")
  , ( 5818, "h")
  , ( 5819, "h")
  , ( 5820, "h")
  , ( 5821, "h")
  , ( 5822, "n")
  , ( 5823, "n")
  , ( 5824, "n")
  , ( 5825, "i")
  , ( 5826, "e")
  , ( 5827, "j")
  , ( 5828, "g")
  , ( 5829, "ae")
  , ( 5830, "a")
  , ( 5831, "eo")
  , ( 5832, "p")
  , ( 5833, "z")
  , ( 5834, "s")
  , ( 5835, "s")
  , ( 5836, "s")
  , ( 5837, "c")
  , ( 5838, "z")
  , ( 5839, "t")
  , ( 5840, "t")
  , ( 5841, "d")
  , ( 5842, "b")
  , ( 5843, "b")
  , ( 5844, "p")
  , ( 5845, "p")
  , ( 5846, "e")
  , ( 5847, "m")
  , ( 5848, "m")
  , ( 5849, "m")
  , ( 5850, "l")
  , ( 5851, "l")
  , ( 5852, "ng")
  , ( 5853, "ng")
  , ( 5854, "d")
  , ( 5855, "o")
  , ( 5856, "ear")
  , ( 5857, "ior")
  , ( 5858, "qu")
  , ( 5859, "qu")
  , ( 5860, "qu")
  , ( 5861, "s")
  , ( 5862, "yr")
  , ( 5863, "yr")
  , ( 5864, "yr")
  , ( 5865, "q")
  , ( 5866, "x")
  , ( 5867, ".")
  , ( 5868, ":")
  , ( 5869, "+")
  , ( 5870, "17")
  , ( 5871, "18")
  , ( 5872, "19")
  , ( 5873, "[?]")
  , ( 5874, "[?]")
  , ( 5875, "[?]")
  , ( 5876, "[?]")
  , ( 5877, "[?]")
  , ( 5878, "[?]")
  , ( 5879, "[?]")
  , ( 5880, "[?]")
  , ( 5881, "[?]")
  , ( 5882, "[?]")
  , ( 5883, "[?]")
  , ( 5884, "[?]")
  , ( 5885, "[?]")
  , ( 5886, "[?]")
  , ( 5888, "[?]")
  , ( 5889, "[?]")
  , ( 5890, "[?]")
  , ( 5891, "[?]")
  , ( 5892, "[?]")
  , ( 5893, "[?]")
  , ( 5894, "[?]")
  , ( 5895, "[?]")
  , ( 5896, "[?]")
  , ( 5897, "[?]")
  , ( 5898, "[?]")
  , ( 5899, "[?]")
  , ( 5900, "[?]")
  , ( 5901, "[?]")
  , ( 5902, "[?]")
  , ( 5903, "[?]")
  , ( 5904, "[?]")
  , ( 5905, "[?]")
  , ( 5906, "[?]")
  , ( 5907, "[?]")
  , ( 5908, "[?]")
  , ( 5909, "[?]")
  , ( 5910, "[?]")
  , ( 5911, "[?]")
  , ( 5912, "[?]")
  , ( 5913, "[?]")
  , ( 5914, "[?]")
  , ( 5915, "[?]")
  , ( 5916, "[?]")
  , ( 5917, "[?]")
  , ( 5918, "[?]")
  , ( 5919, "[?]")
  , ( 5920, "[?]")
  , ( 5921, "[?]")
  , ( 5922, "[?]")
  , ( 5923, "[?]")
  , ( 5924, "[?]")
  , ( 5925, "[?]")
  , ( 5926, "[?]")
  , ( 5927, "[?]")
  , ( 5928, "[?]")
  , ( 5929, "[?]")
  , ( 5930, "[?]")
  , ( 5931, "[?]")
  , ( 5932, "[?]")
  , ( 5933, "[?]")
  , ( 5934, "[?]")
  , ( 5935, "[?]")
  , ( 5936, "[?]")
  , ( 5937, "[?]")
  , ( 5938, "[?]")
  , ( 5939, "[?]")
  , ( 5940, "[?]")
  , ( 5941, "[?]")
  , ( 5942, "[?]")
  , ( 5943, "[?]")
  , ( 5944, "[?]")
  , ( 5945, "[?]")
  , ( 5946, "[?]")
  , ( 5947, "[?]")
  , ( 5948, "[?]")
  , ( 5949, "[?]")
  , ( 5950, "[?]")
  , ( 5951, "[?]")
  , ( 5952, "[?]")
  , ( 5953, "[?]")
  , ( 5954, "[?]")
  , ( 5955, "[?]")
  , ( 5956, "[?]")
  , ( 5957, "[?]")
  , ( 5958, "[?]")
  , ( 5959, "[?]")
  , ( 5960, "[?]")
  , ( 5961, "[?]")
  , ( 5962, "[?]")
  , ( 5963, "[?]")
  , ( 5964, "[?]")
  , ( 5965, "[?]")
  , ( 5966, "[?]")
  , ( 5967, "[?]")
  , ( 5968, "[?]")
  , ( 5969, "[?]")
  , ( 5970, "[?]")
  , ( 5971, "[?]")
  , ( 5972, "[?]")
  , ( 5973, "[?]")
  , ( 5974, "[?]")
  , ( 5975, "[?]")
  , ( 5976, "[?]")
  , ( 5977, "[?]")
  , ( 5978, "[?]")
  , ( 5979, "[?]")
  , ( 5980, "[?]")
  , ( 5981, "[?]")
  , ( 5982, "[?]")
  , ( 5983, "[?]")
  , ( 5984, "[?]")
  , ( 5985, "[?]")
  , ( 5986, "[?]")
  , ( 5987, "[?]")
  , ( 5988, "[?]")
  , ( 5989, "[?]")
  , ( 5990, "[?]")
  , ( 5991, "[?]")
  , ( 5992, "[?]")
  , ( 5993, "[?]")
  , ( 5994, "[?]")
  , ( 5995, "[?]")
  , ( 5996, "[?]")
  , ( 5997, "[?]")
  , ( 5998, "[?]")
  , ( 5999, "[?]")
  , ( 6000, "[?]")
  , ( 6001, "[?]")
  , ( 6002, "[?]")
  , ( 6003, "[?]")
  , ( 6004, "[?]")
  , ( 6005, "[?]")
  , ( 6006, "[?]")
  , ( 6007, "[?]")
  , ( 6008, "[?]")
  , ( 6009, "[?]")
  , ( 6010, "[?]")
  , ( 6011, "[?]")
  , ( 6012, "[?]")
  , ( 6013, "[?]")
  , ( 6014, "[?]")
  , ( 6015, "[?]")
  , ( 6016, "k")
  , ( 6017, "kh")
  , ( 6018, "g")
  , ( 6019, "gh")
  , ( 6020, "ng")
  , ( 6021, "c")
  , ( 6022, "ch")
  , ( 6023, "j")
  , ( 6024, "jh")
  , ( 6025, "ny")
  , ( 6026, "t")
  , ( 6027, "tth")
  , ( 6028, "d")
  , ( 6029, "ddh")
  , ( 6030, "nn")
  , ( 6031, "t")
  , ( 6032, "th")
  , ( 6033, "d")
  , ( 6034, "dh")
  , ( 6035, "n")
  , ( 6036, "p")
  , ( 6037, "ph")
  , ( 6038, "b")
  , ( 6039, "bh")
  , ( 6040, "m")
  , ( 6041, "y")
  , ( 6042, "r")
  , ( 6043, "l")
  , ( 6044, "v")
  , ( 6045, "sh")
  , ( 6046, "ss")
  , ( 6047, "s")
  , ( 6048, "h")
  , ( 6049, "l")
  , ( 6050, "q")
  , ( 6051, "a")
  , ( 6052, "aa")
  , ( 6053, "i")
  , ( 6054, "ii")
  , ( 6055, "u")
  , ( 6056, "uk")
  , ( 6057, "uu")
  , ( 6058, "uuv")
  , ( 6059, "ry")
  , ( 6060, "ryy")
  , ( 6061, "ly")
  , ( 6062, "lyy")
  , ( 6063, "e")
  , ( 6064, "ai")
  , ( 6065, "oo")
  , ( 6066, "oo")
  , ( 6067, "au")
  , ( 6068, "a")
  , ( 6069, "aa")
  , ( 6070, "aa")
  , ( 6071, "i")
  , ( 6072, "ii")
  , ( 6073, "y")
  , ( 6074, "yy")
  , ( 6075, "u")
  , ( 6076, "uu")
  , ( 6077, "ua")
  , ( 6078, "oe")
  , ( 6079, "ya")
  , ( 6080, "ie")
  , ( 6081, "e")
  , ( 6082, "ae")
  , ( 6083, "ai")
  , ( 6084, "oo")
  , ( 6085, "au")
  , ( 6086, "M")
  , ( 6087, "H")
  , ( 6088, "a`")
  , ( 6092, "r")
  , ( 6094, "!")
  , ( 6100, ".")
  , ( 6101, " // ")
  , ( 6102, ":")
  , ( 6103, "+")
  , ( 6104, "++")
  , ( 6105, " * ")
  , ( 6106, " /// ")
  , ( 6107, "KR")
  , ( 6108, "'")
  , ( 6109, "[?]")
  , ( 6110, "[?]")
  , ( 6111, "[?]")
  , ( 6112, "0")
  , ( 6113, "1")
  , ( 6114, "2")
  , ( 6115, "3")
  , ( 6116, "4")
  , ( 6117, "5")
  , ( 6118, "6")
  , ( 6119, "7")
  , ( 6120, "8")
  , ( 6121, "9")
  , ( 6122, "[?]")
  , ( 6123, "[?]")
  , ( 6124, "[?]")
  , ( 6125, "[?]")
  , ( 6126, "[?]")
  , ( 6127, "[?]")
  , ( 6128, "[?]")
  , ( 6129, "[?]")
  , ( 6130, "[?]")
  , ( 6131, "[?]")
  , ( 6132, "[?]")
  , ( 6133, "[?]")
  , ( 6134, "[?]")
  , ( 6135, "[?]")
  , ( 6136, "[?]")
  , ( 6137, "[?]")
  , ( 6138, "[?]")
  , ( 6139, "[?]")
  , ( 6140, "[?]")
  , ( 6141, "[?]")
  , ( 6142, "[?]")
  , ( 6144, " @ ")
  , ( 6145, " ... ")
  , ( 6146, ", ")
  , ( 6147, ". ")
  , ( 6148, ": ")
  , ( 6149, " // ")
  , ( 6151, "-")
  , ( 6152, ", ")
  , ( 6153, ". ")
  , ( 6159, "[?]")
  , ( 6160, "0")
  , ( 6161, "1")
  , ( 6162, "2")
  , ( 6163, "3")
  , ( 6164, "4")
  , ( 6165, "5")
  , ( 6166, "6")
  , ( 6167, "7")
  , ( 6168, "8")
  , ( 6169, "9")
  , ( 6170, "[?]")
  , ( 6171, "[?]")
  , ( 6172, "[?]")
  , ( 6173, "[?]")
  , ( 6174, "[?]")
  , ( 6175, "[?]")
  , ( 6176, "a")
  , ( 6177, "e")
  , ( 6178, "i")
  , ( 6179, "o")
  , ( 6180, "u")
  , ( 6181, "O")
  , ( 6182, "U")
  , ( 6183, "ee")
  , ( 6184, "n")
  , ( 6185, "ng")
  , ( 6186, "b")
  , ( 6187, "p")
  , ( 6188, "q")
  , ( 6189, "g")
  , ( 6190, "m")
  , ( 6191, "l")
  , ( 6192, "s")
  , ( 6193, "sh")
  , ( 6194, "t")
  , ( 6195, "d")
  , ( 6196, "ch")
  , ( 6197, "j")
  , ( 6198, "y")
  , ( 6199, "r")
  , ( 6200, "w")
  , ( 6201, "f")
  , ( 6202, "k")
  , ( 6203, "kha")
  , ( 6204, "ts")
  , ( 6205, "z")
  , ( 6206, "h")
  , ( 6207, "zr")
  , ( 6208, "lh")
  , ( 6209, "zh")
  , ( 6210, "ch")
  , ( 6211, "-")
  , ( 6212, "e")
  , ( 6213, "i")
  , ( 6214, "o")
  , ( 6215, "u")
  , ( 6216, "O")
  , ( 6217, "U")
  , ( 6218, "ng")
  , ( 6219, "b")
  , ( 6220, "p")
  , ( 6221, "q")
  , ( 6222, "g")
  , ( 6223, "m")
  , ( 6224, "t")
  , ( 6225, "d")
  , ( 6226, "ch")
  , ( 6227, "j")
  , ( 6228, "ts")
  , ( 6229, "y")
  , ( 6230, "w")
  , ( 6231, "k")
  , ( 6232, "g")
  , ( 6233, "h")
  , ( 6234, "jy")
  , ( 6235, "ny")
  , ( 6236, "dz")
  , ( 6237, "e")
  , ( 6238, "i")
  , ( 6239, "iy")
  , ( 6240, "U")
  , ( 6241, "u")
  , ( 6242, "ng")
  , ( 6243, "k")
  , ( 6244, "g")
  , ( 6245, "h")
  , ( 6246, "p")
  , ( 6247, "sh")
  , ( 6248, "t")
  , ( 6249, "d")
  , ( 6250, "j")
  , ( 6251, "f")
  , ( 6252, "g")
  , ( 6253, "h")
  , ( 6254, "ts")
  , ( 6255, "z")
  , ( 6256, "r")
  , ( 6257, "ch")
  , ( 6258, "zh")
  , ( 6259, "i")
  , ( 6260, "k")
  , ( 6261, "r")
  , ( 6262, "f")
  , ( 6263, "zh")
  , ( 6264, "[?]")
  , ( 6265, "[?]")
  , ( 6266, "[?]")
  , ( 6267, "[?]")
  , ( 6268, "[?]")
  , ( 6269, "[?]")
  , ( 6270, "[?]")
  , ( 6271, "[?]")
  , ( 6272, "[?]")
  , ( 6273, "H")
  , ( 6274, "X")
  , ( 6275, "W")
  , ( 6276, "M")
  , ( 6277, " 3 ")
  , ( 6278, " 333 ")
  , ( 6279, "a")
  , ( 6280, "i")
  , ( 6281, "k")
  , ( 6282, "ng")
  , ( 6283, "c")
  , ( 6284, "tt")
  , ( 6285, "tth")
  , ( 6286, "dd")
  , ( 6287, "nn")
  , ( 6288, "t")
  , ( 6289, "d")
  , ( 6290, "p")
  , ( 6291, "ph")
  , ( 6292, "ss")
  , ( 6293, "zh")
  , ( 6294, "z")
  , ( 6295, "a")
  , ( 6296, "t")
  , ( 6297, "zh")
  , ( 6298, "gh")
  , ( 6299, "ng")
  , ( 6300, "c")
  , ( 6301, "jh")
  , ( 6302, "tta")
  , ( 6303, "ddh")
  , ( 6304, "t")
  , ( 6305, "dh")
  , ( 6306, "ss")
  , ( 6307, "cy")
  , ( 6308, "zh")
  , ( 6309, "z")
  , ( 6310, "u")
  , ( 6311, "y")
  , ( 6312, "bh")
  , ( 6313, "'")
  , ( 6314, "[?]")
  , ( 6315, "[?]")
  , ( 6316, "[?]")
  , ( 6317, "[?]")
  , ( 6318, "[?]")
  , ( 6319, "[?]")
  , ( 6320, "[?]")
  , ( 6321, "[?]")
  , ( 6322, "[?]")
  , ( 6323, "[?]")
  , ( 6324, "[?]")
  , ( 6325, "[?]")
  , ( 6326, "[?]")
  , ( 6327, "[?]")
  , ( 6328, "[?]")
  , ( 6329, "[?]")
  , ( 6330, "[?]")
  , ( 6331, "[?]")
  , ( 6332, "[?]")
  , ( 6333, "[?]")
  , ( 6334, "[?]")
  , ( 6335, "[?]")
  , ( 6336, "[?]")
  , ( 6337, "[?]")
  , ( 6338, "[?]")
  , ( 6339, "[?]")
  , ( 6340, "[?]")
  , ( 6341, "[?]")
  , ( 6342, "[?]")
  , ( 6343, "[?]")
  , ( 6344, "[?]")
  , ( 6345, "[?]")
  , ( 6346, "[?]")
  , ( 6347, "[?]")
  , ( 6348, "[?]")
  , ( 6349, "[?]")
  , ( 6350, "[?]")
  , ( 6351, "[?]")
  , ( 6352, "[?]")
  , ( 6353, "[?]")
  , ( 6354, "[?]")
  , ( 6355, "[?]")
  , ( 6356, "[?]")
  , ( 6357, "[?]")
  , ( 6358, "[?]")
  , ( 6359, "[?]")
  , ( 6360, "[?]")
  , ( 6361, "[?]")
  , ( 6362, "[?]")
  , ( 6363, "[?]")
  , ( 6364, "[?]")
  , ( 6365, "[?]")
  , ( 6366, "[?]")
  , ( 6367, "[?]")
  , ( 6368, "[?]")
  , ( 6369, "[?]")
  , ( 6370, "[?]")
  , ( 6371, "[?]")
  , ( 6372, "[?]")
  , ( 6373, "[?]")
  , ( 6374, "[?]")
  , ( 6375, "[?]")
  , ( 6376, "[?]")
  , ( 6377, "[?]")
  , ( 6378, "[?]")
  , ( 6379, "[?]")
  , ( 6380, "[?]")
  , ( 6381, "[?]")
  , ( 6382, "[?]")
  , ( 6383, "[?]")
  , ( 6384, "[?]")
  , ( 6385, "[?]")
  , ( 6386, "[?]")
  , ( 6387, "[?]")
  , ( 6388, "[?]")
  , ( 6389, "[?]")
  , ( 6390, "[?]")
  , ( 6391, "[?]")
  , ( 6392, "[?]")
  , ( 6393, "[?]")
  , ( 6394, "[?]")
  , ( 6395, "[?]")
  , ( 6396, "[?]")
  , ( 6397, "[?]")
  , ( 6398, "[?]")
  , ( 7532, "b")
  , ( 7533, "d")
  , ( 7534, "f")
  , ( 7535, "m")
  , ( 7536, "n")
  , ( 7537, "p")
  , ( 7538, "r")
  , ( 7539, "r")
  , ( 7540, "s")
  , ( 7541, "t")
  , ( 7542, "z")
  , ( 7543, "g")
  , ( 7549, "p")
  , ( 7552, "b")
  , ( 7553, "d")
  , ( 7554, "f")
  , ( 7555, "g")
  , ( 7556, "k")
  , ( 7557, "l")
  , ( 7558, "m")
  , ( 7559, "n")
  , ( 7560, "p")
  , ( 7561, "r")
  , ( 7562, "s")
  , ( 7564, "v")
  , ( 7565, "x")
  , ( 7566, "z")
  , ( 7680, "A")
  , ( 7681, "a")
  , ( 7682, "B")
  , ( 7683, "b")
  , ( 7684, "B")
  , ( 7685, "b")
  , ( 7686, "B")
  , ( 7687, "b")
  , ( 7688, "C")
  , ( 7689, "c")
  , ( 7690, "D")
  , ( 7691, "d")
  , ( 7692, "D")
  , ( 7693, "d")
  , ( 7694, "D")
  , ( 7695, "d")
  , ( 7696, "D")
  , ( 7697, "d")
  , ( 7698, "D")
  , ( 7699, "d")
  , ( 7700, "E")
  , ( 7701, "e")
  , ( 7702, "E")
  , ( 7703, "e")
  , ( 7704, "E")
  , ( 7705, "e")
  , ( 7706, "E")
  , ( 7707, "e")
  , ( 7708, "E")
  , ( 7709, "e")
  , ( 7710, "F")
  , ( 7711, "f")
  , ( 7712, "G")
  , ( 7713, "g")
  , ( 7714, "H")
  , ( 7715, "h")
  , ( 7716, "H")
  , ( 7717, "h")
  , ( 7718, "H")
  , ( 7719, "h")
  , ( 7720, "H")
  , ( 7721, "h")
  , ( 7722, "H")
  , ( 7723, "h")
  , ( 7724, "I")
  , ( 7725, "i")
  , ( 7726, "I")
  , ( 7727, "i")
  , ( 7728, "K")
  , ( 7729, "k")
  , ( 7730, "K")
  , ( 7731, "k")
  , ( 7732, "K")
  , ( 7733, "k")
  , ( 7734, "L")
  , ( 7735, "l")
  , ( 7736, "L")
  , ( 7737, "l")
  , ( 7738, "L")
  , ( 7739, "l")
  , ( 7740, "L")
  , ( 7741, "l")
  , ( 7742, "M")
  , ( 7743, "m")
  , ( 7744, "M")
  , ( 7745, "m")
  , ( 7746, "M")
  , ( 7747, "m")
  , ( 7748, "N")
  , ( 7749, "n")
  , ( 7750, "N")
  , ( 7751, "n")
  , ( 7752, "N")
  , ( 7753, "n")
  , ( 7754, "N")
  , ( 7755, "n")
  , ( 7756, "O")
  , ( 7757, "o")
  , ( 7758, "O")
  , ( 7759, "o")
  , ( 7760, "O")
  , ( 7761, "o")
  , ( 7762, "O")
  , ( 7763, "o")
  , ( 7764, "P")
  , ( 7765, "p")
  , ( 7766, "P")
  , ( 7767, "p")
  , ( 7768, "R")
  , ( 7769, "r")
  , ( 7770, "R")
  , ( 7771, "r")
  , ( 7772, "R")
  , ( 7773, "r")
  , ( 7774, "R")
  , ( 7775, "r")
  , ( 7776, "S")
  , ( 7777, "s")
  , ( 7778, "S")
  , ( 7779, "s")
  , ( 7780, "S")
  , ( 7781, "s")
  , ( 7782, "S")
  , ( 7783, "s")
  , ( 7784, "S")
  , ( 7785, "s")
  , ( 7786, "T")
  , ( 7787, "t")
  , ( 7788, "T")
  , ( 7789, "t")
  , ( 7790, "T")
  , ( 7791, "t")
  , ( 7792, "T")
  , ( 7793, "t")
  , ( 7794, "U")
  , ( 7795, "u")
  , ( 7796, "U")
  , ( 7797, "u")
  , ( 7798, "U")
  , ( 7799, "u")
  , ( 7800, "U")
  , ( 7801, "u")
  , ( 7802, "U")
  , ( 7803, "u")
  , ( 7804, "V")
  , ( 7805, "v")
  , ( 7806, "V")
  , ( 7807, "v")
  , ( 7808, "W")
  , ( 7809, "w")
  , ( 7810, "W")
  , ( 7811, "w")
  , ( 7812, "W")
  , ( 7813, "w")
  , ( 7814, "W")
  , ( 7815, "w")
  , ( 7816, "W")
  , ( 7817, "w")
  , ( 7818, "X")
  , ( 7819, "x")
  , ( 7820, "X")
  , ( 7821, "x")
  , ( 7822, "Y")
  , ( 7823, "y")
  , ( 7824, "Z")
  , ( 7825, "z")
  , ( 7826, "Z")
  , ( 7827, "z")
  , ( 7828, "Z")
  , ( 7829, "z")
  , ( 7830, "h")
  , ( 7831, "t")
  , ( 7832, "w")
  , ( 7833, "y")
  , ( 7834, "a")
  , ( 7835, "S")
  , ( 7836, "[?]")
  , ( 7837, "[?]")
  , ( 7838, "Ss")
  , ( 7839, "[?]")
  , ( 7840, "A")
  , ( 7841, "a")
  , ( 7842, "A")
  , ( 7843, "a")
  , ( 7844, "A")
  , ( 7845, "a")
  , ( 7846, "A")
  , ( 7847, "a")
  , ( 7848, "A")
  , ( 7849, "a")
  , ( 7850, "A")
  , ( 7851, "a")
  , ( 7852, "A")
  , ( 7853, "a")
  , ( 7854, "A")
  , ( 7855, "a")
  , ( 7856, "A")
  , ( 7857, "a")
  , ( 7858, "A")
  , ( 7859, "a")
  , ( 7860, "A")
  , ( 7861, "a")
  , ( 7862, "A")
  , ( 7863, "a")
  , ( 7864, "E")
  , ( 7865, "e")
  , ( 7866, "E")
  , ( 7867, "e")
  , ( 7868, "E")
  , ( 7869, "e")
  , ( 7870, "E")
  , ( 7871, "e")
  , ( 7872, "E")
  , ( 7873, "e")
  , ( 7874, "E")
  , ( 7875, "e")
  , ( 7876, "E")
  , ( 7877, "e")
  , ( 7878, "E")
  , ( 7879, "e")
  , ( 7880, "I")
  , ( 7881, "i")
  , ( 7882, "I")
  , ( 7883, "i")
  , ( 7884, "O")
  , ( 7885, "o")
  , ( 7886, "O")
  , ( 7887, "o")
  , ( 7888, "O")
  , ( 7889, "o")
  , ( 7890, "O")
  , ( 7891, "o")
  , ( 7892, "O")
  , ( 7893, "o")
  , ( 7894, "O")
  , ( 7895, "o")
  , ( 7896, "O")
  , ( 7897, "o")
  , ( 7898, "O")
  , ( 7899, "o")
  , ( 7900, "O")
  , ( 7901, "o")
  , ( 7902, "O")
  , ( 7903, "o")
  , ( 7904, "O")
  , ( 7905, "o")
  , ( 7906, "O")
  , ( 7907, "o")
  , ( 7908, "U")
  , ( 7909, "u")
  , ( 7910, "U")
  , ( 7911, "u")
  , ( 7912, "U")
  , ( 7913, "u")
  , ( 7914, "U")
  , ( 7915, "u")
  , ( 7916, "U")
  , ( 7917, "u")
  , ( 7918, "U")
  , ( 7919, "u")
  , ( 7920, "U")
  , ( 7921, "u")
  , ( 7922, "Y")
  , ( 7923, "y")
  , ( 7924, "Y")
  , ( 7925, "y")
  , ( 7926, "Y")
  , ( 7927, "y")
  , ( 7928, "Y")
  , ( 7929, "y")
  , ( 7930, "[?]")
  , ( 7931, "[?]")
  , ( 7932, "[?]")
  , ( 7933, "[?]")
  , ( 7934, "[?]")
  , ( 7936, "a")
  , ( 7937, "a")
  , ( 7938, "a")
  , ( 7939, "a")
  , ( 7940, "a")
  , ( 7941, "a")
  , ( 7942, "a")
  , ( 7943, "a")
  , ( 7944, "A")
  , ( 7945, "A")
  , ( 7946, "A")
  , ( 7947, "A")
  , ( 7948, "A")
  , ( 7949, "A")
  , ( 7950, "A")
  , ( 7951, "A")
  , ( 7952, "e")
  , ( 7953, "e")
  , ( 7954, "e")
  , ( 7955, "e")
  , ( 7956, "e")
  , ( 7957, "e")
  , ( 7958, "[?]")
  , ( 7959, "[?]")
  , ( 7960, "E")
  , ( 7961, "E")
  , ( 7962, "E")
  , ( 7963, "E")
  , ( 7964, "E")
  , ( 7965, "E")
  , ( 7966, "[?]")
  , ( 7967, "[?]")
  , ( 7968, "e")
  , ( 7969, "e")
  , ( 7970, "e")
  , ( 7971, "e")
  , ( 7972, "e")
  , ( 7973, "e")
  , ( 7974, "e")
  , ( 7975, "e")
  , ( 7976, "E")
  , ( 7977, "E")
  , ( 7978, "E")
  , ( 7979, "E")
  , ( 7980, "E")
  , ( 7981, "E")
  , ( 7982, "E")
  , ( 7983, "E")
  , ( 7984, "i")
  , ( 7985, "i")
  , ( 7986, "i")
  , ( 7987, "i")
  , ( 7988, "i")
  , ( 7989, "i")
  , ( 7990, "i")
  , ( 7991, "i")
  , ( 7992, "I")
  , ( 7993, "I")
  , ( 7994, "I")
  , ( 7995, "I")
  , ( 7996, "I")
  , ( 7997, "I")
  , ( 7998, "I")
  , ( 7999, "I")
  , ( 8000, "o")
  , ( 8001, "o")
  , ( 8002, "o")
  , ( 8003, "o")
  , ( 8004, "o")
  , ( 8005, "o")
  , ( 8006, "[?]")
  , ( 8007, "[?]")
  , ( 8008, "O")
  , ( 8009, "O")
  , ( 8010, "O")
  , ( 8011, "O")
  , ( 8012, "O")
  , ( 8013, "O")
  , ( 8014, "[?]")
  , ( 8015, "[?]")
  , ( 8016, "u")
  , ( 8017, "u")
  , ( 8018, "u")
  , ( 8019, "u")
  , ( 8020, "u")
  , ( 8021, "u")
  , ( 8022, "u")
  , ( 8023, "u")
  , ( 8024, "[?]")
  , ( 8025, "U")
  , ( 8026, "[?]")
  , ( 8027, "U")
  , ( 8028, "[?]")
  , ( 8029, "U")
  , ( 8030, "[?]")
  , ( 8031, "U")
  , ( 8032, "o")
  , ( 8033, "o")
  , ( 8034, "o")
  , ( 8035, "o")
  , ( 8036, "o")
  , ( 8037, "o")
  , ( 8038, "o")
  , ( 8039, "o")
  , ( 8040, "O")
  , ( 8041, "O")
  , ( 8042, "O")
  , ( 8043, "O")
  , ( 8044, "O")
  , ( 8045, "O")
  , ( 8046, "O")
  , ( 8047, "O")
  , ( 8048, "a")
  , ( 8049, "a")
  , ( 8050, "e")
  , ( 8051, "e")
  , ( 8052, "e")
  , ( 8053, "e")
  , ( 8054, "i")
  , ( 8055, "i")
  , ( 8056, "o")
  , ( 8057, "o")
  , ( 8058, "u")
  , ( 8059, "u")
  , ( 8060, "o")
  , ( 8061, "o")
  , ( 8062, "[?]")
  , ( 8063, "[?]")
  , ( 8064, "a")
  , ( 8065, "a")
  , ( 8066, "a")
  , ( 8067, "a")
  , ( 8068, "a")
  , ( 8069, "a")
  , ( 8070, "a")
  , ( 8071, "a")
  , ( 8072, "A")
  , ( 8073, "A")
  , ( 8074, "A")
  , ( 8075, "A")
  , ( 8076, "A")
  , ( 8077, "A")
  , ( 8078, "A")
  , ( 8079, "A")
  , ( 8080, "e")
  , ( 8081, "e")
  , ( 8082, "e")
  , ( 8083, "e")
  , ( 8084, "e")
  , ( 8085, "e")
  , ( 8086, "e")
  , ( 8087, "e")
  , ( 8088, "E")
  , ( 8089, "E")
  , ( 8090, "E")
  , ( 8091, "E")
  , ( 8092, "E")
  , ( 8093, "E")
  , ( 8094, "E")
  , ( 8095, "E")
  , ( 8096, "o")
  , ( 8097, "o")
  , ( 8098, "o")
  , ( 8099, "o")
  , ( 8100, "o")
  , ( 8101, "o")
  , ( 8102, "o")
  , ( 8103, "o")
  , ( 8104, "O")
  , ( 8105, "O")
  , ( 8106, "O")
  , ( 8107, "O")
  , ( 8108, "O")
  , ( 8109, "O")
  , ( 8110, "O")
  , ( 8111, "O")
  , ( 8112, "a")
  , ( 8113, "a")
  , ( 8114, "a")
  , ( 8115, "a")
  , ( 8116, "a")
  , ( 8117, "[?]")
  , ( 8118, "a")
  , ( 8119, "a")
  , ( 8120, "A")
  , ( 8121, "A")
  , ( 8122, "A")
  , ( 8123, "A")
  , ( 8124, "A")
  , ( 8125, "'")
  , ( 8126, "i")
  , ( 8127, "'")
  , ( 8128, "~")
  , ( 8129, "\"~")
  , ( 8130, "e")
  , ( 8131, "e")
  , ( 8132, "e")
  , ( 8133, "[?]")
  , ( 8134, "e")
  , ( 8135, "e")
  , ( 8136, "E")
  , ( 8137, "E")
  , ( 8138, "E")
  , ( 8139, "E")
  , ( 8140, "E")
  , ( 8141, "'`")
  , ( 8142, "''")
  , ( 8143, "'~")
  , ( 8144, "i")
  , ( 8145, "i")
  , ( 8146, "i")
  , ( 8147, "i")
  , ( 8148, "[?]")
  , ( 8149, "[?]")
  , ( 8150, "i")
  , ( 8151, "i")
  , ( 8152, "I")
  , ( 8153, "I")
  , ( 8154, "I")
  , ( 8155, "I")
  , ( 8156, "[?]")
  , ( 8157, "`'")
  , ( 8158, "`'")
  , ( 8159, "`~")
  , ( 8160, "u")
  , ( 8161, "u")
  , ( 8162, "u")
  , ( 8163, "u")
  , ( 8164, "R")
  , ( 8165, "R")
  , ( 8166, "u")
  , ( 8167, "u")
  , ( 8168, "U")
  , ( 8169, "U")
  , ( 8170, "U")
  , ( 8171, "U")
  , ( 8172, "R")
  , ( 8173, "\"`")
  , ( 8174, "\"'")
  , ( 8175, "`")
  , ( 8176, "[?]")
  , ( 8177, "[?]")
  , ( 8178, "o")
  , ( 8179, "o")
  , ( 8180, "o")
  , ( 8181, "[?]")
  , ( 8182, "o")
  , ( 8183, "o")
  , ( 8184, "O")
  , ( 8185, "O")
  , ( 8186, "O")
  , ( 8187, "O")
  , ( 8188, "O")
  , ( 8189, "'")
  , ( 8190, "`")
  , ( 8192, " ")
  , ( 8193, " ")
  , ( 8194, " ")
  , ( 8195, " ")
  , ( 8196, " ")
  , ( 8197, " ")
  , ( 8198, " ")
  , ( 8199, " ")
  , ( 8200, " ")
  , ( 8201, " ")
  , ( 8202, " ")
  , ( 8203, " ")
  , ( 8208, "-")
  , ( 8209, "-")
  , ( 8210, "-")
  , ( 8211, "-")
  , ( 8212, "--")
  , ( 8213, "--")
  , ( 8214, "||")
  , ( 8215, "_")
  , ( 8216, "'")
  , ( 8217, "'")
  , ( 8218, ",")
  , ( 8219, "'")
  , ( 8220, "\"")
  , ( 8221, "\"")
  , ( 8222, ",,")
  , ( 8223, "\"")
  , ( 8224, "+")
  , ( 8225, "++")
  , ( 8226, "*")
  , ( 8227, "*>")
  , ( 8228, ".")
  , ( 8229, "..")
  , ( 8230, "...")
  , ( 8231, ".")
  , ( 8232, "\n")
  , ( 8233, "\n")
  , ( 8239, " ")
  , ( 8240, "%0")
  , ( 8241, "%00")
  , ( 8242, "'")
  , ( 8243, "''")
  , ( 8244, "'''")
  , ( 8245, "`")
  , ( 8246, "``")
  , ( 8247, "```")
  , ( 8248, "^")
  , ( 8249, "<")
  , ( 8250, ">")
  , ( 8251, "*")
  , ( 8252, "!!")
  , ( 8253, "!?")
  , ( 8254, "-")
  , ( 8255, "_")
  , ( 8256, "-")
  , ( 8257, "^")
  , ( 8258, "***")
  , ( 8259, "--")
  , ( 8260, "/")
  , ( 8261, "-[")
  , ( 8262, "]-")
  , ( 8263, "??")
  , ( 8264, "?!")
  , ( 8265, "!?")
  , ( 8266, "7")
  , ( 8267, "PP")
  , ( 8268, "(]")
  , ( 8269, "[)")
  , ( 8270, "*")
  , ( 8271, "[?]")
  , ( 8272, "[?]")
  , ( 8273, "[?]")
  , ( 8274, "%")
  , ( 8275, "~")
  , ( 8276, "[?]")
  , ( 8277, "[?]")
  , ( 8278, "[?]")
  , ( 8279, "''''")
  , ( 8280, "[?]")
  , ( 8281, "[?]")
  , ( 8282, "[?]")
  , ( 8283, "[?]")
  , ( 8284, "[?]")
  , ( 8285, "[?]")
  , ( 8286, "[?]")
  , ( 8287, "[?]")
  , ( 8289, "[?]")
  , ( 8290, "[?]")
  , ( 8291, "[?]")
  , ( 8292, "[?]")
  , ( 8293, "[?]")
  , ( 8294, "[?]")
  , ( 8295, "[?]")
  , ( 8296, "[?]")
  , ( 8297, "[?]")
  , ( 8304, "0")
  , ( 8308, "4")
  , ( 8309, "5")
  , ( 8310, "6")
  , ( 8311, "7")
  , ( 8312, "8")
  , ( 8313, "9")
  , ( 8314, "+")
  , ( 8315, "-")
  , ( 8316, "=")
  , ( 8317, "(")
  , ( 8318, ")")
  , ( 8319, "n")
  , ( 8320, "0")
  , ( 8321, "1")
  , ( 8322, "2")
  , ( 8323, "3")
  , ( 8324, "4")
  , ( 8325, "5")
  , ( 8326, "6")
  , ( 8327, "7")
  , ( 8328, "8")
  , ( 8329, "9")
  , ( 8330, "+")
  , ( 8331, "-")
  , ( 8332, "=")
  , ( 8333, "(")
  , ( 8334, ")")
  , ( 8335, "[?]")
  , ( 8336, "[?]")
  , ( 8337, "[?]")
  , ( 8338, "[?]")
  , ( 8339, "[?]")
  , ( 8340, "[?]")
  , ( 8341, "[?]")
  , ( 8342, "[?]")
  , ( 8343, "[?]")
  , ( 8344, "[?]")
  , ( 8345, "[?]")
  , ( 8346, "[?]")
  , ( 8347, "[?]")
  , ( 8348, "[?]")
  , ( 8349, "[?]")
  , ( 8350, "[?]")
  , ( 8351, "[?]")
  , ( 8352, "ECU")
  , ( 8353, "CL")
  , ( 8354, "Cr")
  , ( 8355, "FF")
  , ( 8356, "L")
  , ( 8357, "mil")
  , ( 8358, "N")
  , ( 8359, "Pts")
  , ( 8360, "Rs")
  , ( 8361, "W")
  , ( 8362, "NS")
  , ( 8363, "D")
  , ( 8364, "EUR")
  , ( 8365, "K")
  , ( 8366, "T")
  , ( 8367, "Dr")
  , ( 8368, "[?]")
  , ( 8369, "[?]")
  , ( 8370, "[?]")
  , ( 8371, "[?]")
  , ( 8372, "[?]")
  , ( 8373, "[?]")
  , ( 8374, "[?]")
  , ( 8375, "[?]")
  , ( 8376, "[?]")
  , ( 8377, "[?]")
  , ( 8378, "[?]")
  , ( 8379, "[?]")
  , ( 8380, "[?]")
  , ( 8381, "[?]")
  , ( 8382, "[?]")
  , ( 8383, "[?]")
  , ( 8384, "[?]")
  , ( 8385, "[?]")
  , ( 8386, "[?]")
  , ( 8387, "[?]")
  , ( 8388, "[?]")
  , ( 8389, "[?]")
  , ( 8390, "[?]")
  , ( 8391, "[?]")
  , ( 8392, "[?]")
  , ( 8393, "[?]")
  , ( 8394, "[?]")
  , ( 8395, "[?]")
  , ( 8396, "[?]")
  , ( 8397, "[?]")
  , ( 8398, "[?]")
  , ( 8399, "[?]")
  , ( 8420, "[?]")
  , ( 8422, "[?]")
  , ( 8423, "[?]")
  , ( 8519, "e")
  , ( 8520, "i")
  , ( 40961, "ix")
  , ( 40962, "i")
  , ( 40963, "ip")
  , ( 40964, "iet")
  , ( 40965, "iex")
  , ( 40966, "ie")
  , ( 40967, "iep")
  , ( 40968, "at")
  , ( 40969, "ax")
  , ( 40970, "a")
  , ( 40971, "ap")
  , ( 40972, "uox")
  , ( 40973, "uo")
  , ( 40974, "uop")
  , ( 40975, "ot")
  , ( 40976, "ox")
  , ( 40977, "o")
  , ( 40978, "op")
  , ( 40979, "ex")
  , ( 40980, "e")
  , ( 40981, "wu")
  , ( 40982, "bit")
  , ( 40983, "bix")
  , ( 40984, "bi")
  , ( 40985, "bip")
  , ( 40986, "biet")
  , ( 40987, "biex")
  , ( 40988, "bie")
  , ( 40989, "biep")
  , ( 40990, "bat")
  , ( 40991, "bax")
  , ( 40992, "ba")
  , ( 40993, "bap")
  , ( 40994, "buox")
  , ( 40995, "buo")
  , ( 40996, "buop")
  , ( 40997, "bot")
  , ( 40998, "box")
  , ( 40999, "bo")
  , ( 41000, "bop")
  , ( 41001, "bex")
  , ( 41002, "be")
  , ( 41003, "bep")
  , ( 41004, "but")
  , ( 41005, "bux")
  , ( 41006, "bu")
  , ( 41007, "bup")
  , ( 41008, "burx")
  , ( 41009, "bur")
  , ( 41010, "byt")
  , ( 41011, "byx")
  , ( 41012, "by")
  , ( 41013, "byp")
  , ( 41014, "byrx")
  , ( 41015, "byr")
  , ( 41016, "pit")
  , ( 41017, "pix")
  , ( 41018, "pi")
  , ( 41019, "pip")
  , ( 41020, "piex")
  , ( 41021, "pie")
  , ( 41022, "piep")
  , ( 41023, "pat")
  , ( 41024, "pax")
  , ( 41025, "pa")
  , ( 41026, "pap")
  , ( 41027, "puox")
  , ( 41028, "puo")
  , ( 41029, "puop")
  , ( 41030, "pot")
  , ( 41031, "pox")
  , ( 41032, "po")
  , ( 41033, "pop")
  , ( 41034, "put")
  , ( 41035, "pux")
  , ( 41036, "pu")
  , ( 41037, "pup")
  , ( 41038, "purx")
  , ( 41039, "pur")
  , ( 41040, "pyt")
  , ( 41041, "pyx")
  , ( 41042, "py")
  , ( 41043, "pyp")
  , ( 41044, "pyrx")
  , ( 41045, "pyr")
  , ( 41046, "bbit")
  , ( 41047, "bbix")
  , ( 41048, "bbi")
  , ( 41049, "bbip")
  , ( 41050, "bbiet")
  , ( 41051, "bbiex")
  , ( 41052, "bbie")
  , ( 41053, "bbiep")
  , ( 41054, "bbat")
  , ( 41055, "bbax")
  , ( 41056, "bba")
  , ( 41057, "bbap")
  , ( 41058, "bbuox")
  , ( 41059, "bbuo")
  , ( 41060, "bbuop")
  , ( 41061, "bbot")
  , ( 41062, "bbox")
  , ( 41063, "bbo")
  , ( 41064, "bbop")
  , ( 41065, "bbex")
  , ( 41066, "bbe")
  , ( 41067, "bbep")
  , ( 41068, "bbut")
  , ( 41069, "bbux")
  , ( 41070, "bbu")
  , ( 41071, "bbup")
  , ( 41072, "bburx")
  , ( 41073, "bbur")
  , ( 41074, "bbyt")
  , ( 41075, "bbyx")
  , ( 41076, "bby")
  , ( 41077, "bbyp")
  , ( 41078, "nbit")
  , ( 41079, "nbix")
  , ( 41080, "nbi")
  , ( 41081, "nbip")
  , ( 41082, "nbiex")
  , ( 41083, "nbie")
  , ( 41084, "nbiep")
  , ( 41085, "nbat")
  , ( 41086, "nbax")
  , ( 41087, "nba")
  , ( 41088, "nbap")
  , ( 41089, "nbot")
  , ( 41090, "nbox")
  , ( 41091, "nbo")
  , ( 41092, "nbop")
  , ( 41093, "nbut")
  , ( 41094, "nbux")
  , ( 41095, "nbu")
  , ( 41096, "nbup")
  , ( 41097, "nburx")
  , ( 41098, "nbur")
  , ( 41099, "nbyt")
  , ( 41100, "nbyx")
  , ( 41101, "nby")
  , ( 41102, "nbyp")
  , ( 41103, "nbyrx")
  , ( 41104, "nbyr")
  , ( 41105, "hmit")
  , ( 41106, "hmix")
  , ( 41107, "hmi")
  , ( 41108, "hmip")
  , ( 41109, "hmiex")
  , ( 41110, "hmie")
  , ( 41111, "hmiep")
  , ( 41112, "hmat")
  , ( 41113, "hmax")
  , ( 41114, "hma")
  , ( 41115, "hmap")
  , ( 41116, "hmuox")
  , ( 41117, "hmuo")
  , ( 41118, "hmuop")
  , ( 41119, "hmot")
  , ( 41120, "hmox")
  , ( 41121, "hmo")
  , ( 41122, "hmop")
  , ( 41123, "hmut")
  , ( 41124, "hmux")
  , ( 41125, "hmu")
  , ( 41126, "hmup")
  , ( 41127, "hmurx")
  , ( 41128, "hmur")
  , ( 41129, "hmyx")
  , ( 41130, "hmy")
  , ( 41131, "hmyp")
  , ( 41132, "hmyrx")
  , ( 41133, "hmyr")
  , ( 41134, "mit")
  , ( 41135, "mix")
  , ( 41136, "mi")
  , ( 41137, "mip")
  , ( 41138, "miex")
  , ( 41139, "mie")
  , ( 41140, "miep")
  , ( 41141, "mat")
  , ( 41142, "max")
  , ( 41143, "ma")
  , ( 41144, "map")
  , ( 41145, "muot")
  , ( 41146, "muox")
  , ( 41147, "muo")
  , ( 41148, "muop")
  , ( 41149, "mot")
  , ( 41150, "mox")
  , ( 41151, "mo")
  , ( 41152, "mop")
  , ( 41153, "mex")
  , ( 41154, "me")
  , ( 41155, "mut")
  , ( 41156, "mux")
  , ( 41157, "mu")
  , ( 41158, "mup")
  , ( 41159, "murx")
  , ( 41160, "mur")
  , ( 41161, "myt")
  , ( 41162, "myx")
  , ( 41163, "my")
  , ( 41164, "myp")
  , ( 41165, "fit")
  , ( 41166, "fix")
  , ( 41167, "fi")
  , ( 41168, "fip")
  , ( 41169, "fat")
  , ( 41170, "fax")
  , ( 41171, "fa")
  , ( 41172, "fap")
  , ( 41173, "fox")
  , ( 41174, "fo")
  , ( 41175, "fop")
  , ( 41176, "fut")
  , ( 41177, "fux")
  , ( 41178, "fu")
  , ( 41179, "fup")
  , ( 41180, "furx")
  , ( 41181, "fur")
  , ( 41182, "fyt")
  , ( 41183, "fyx")
  , ( 41184, "fy")
  , ( 41185, "fyp")
  , ( 41186, "vit")
  , ( 41187, "vix")
  , ( 41188, "vi")
  , ( 41189, "vip")
  , ( 41190, "viet")
  , ( 41191, "viex")
  , ( 41192, "vie")
  , ( 41193, "viep")
  , ( 41194, "vat")
  , ( 41195, "vax")
  , ( 41196, "va")
  , ( 41197, "vap")
  , ( 41198, "vot")
  , ( 41199, "vox")
  , ( 41200, "vo")
  , ( 41201, "vop")
  , ( 41202, "vex")
  , ( 41203, "vep")
  , ( 41204, "vut")
  , ( 41205, "vux")
  , ( 41206, "vu")
  , ( 41207, "vup")
  , ( 41208, "vurx")
  , ( 41209, "vur")
  , ( 41210, "vyt")
  , ( 41211, "vyx")
  , ( 41212, "vy")
  , ( 41213, "vyp")
  , ( 41214, "vyrx")
  , ( 41215, "vyr")
  , ( 41216, "dit")
  , ( 41217, "dix")
  , ( 41218, "di")
  , ( 41219, "dip")
  , ( 41220, "diex")
  , ( 41221, "die")
  , ( 41222, "diep")
  , ( 41223, "dat")
  , ( 41224, "dax")
  , ( 41225, "da")
  , ( 41226, "dap")
  , ( 41227, "duox")
  , ( 41228, "duo")
  , ( 41229, "dot")
  , ( 41230, "dox")
  , ( 41231, "do")
  , ( 41232, "dop")
  , ( 41233, "dex")
  , ( 41234, "de")
  , ( 41235, "dep")
  , ( 41236, "dut")
  , ( 41237, "dux")
  , ( 41238, "du")
  , ( 41239, "dup")
  , ( 41240, "durx")
  , ( 41241, "dur")
  , ( 41242, "tit")
  , ( 41243, "tix")
  , ( 41244, "ti")
  , ( 41245, "tip")
  , ( 41246, "tiex")
  , ( 41247, "tie")
  , ( 41248, "tiep")
  , ( 41249, "tat")
  , ( 41250, "tax")
  , ( 41251, "ta")
  , ( 41252, "tap")
  , ( 41253, "tuot")
  , ( 41254, "tuox")
  , ( 41255, "tuo")
  , ( 41256, "tuop")
  , ( 41257, "tot")
  , ( 41258, "tox")
  , ( 41259, "to")
  , ( 41260, "top")
  , ( 41261, "tex")
  , ( 41262, "te")
  , ( 41263, "tep")
  , ( 41264, "tut")
  , ( 41265, "tux")
  , ( 41266, "tu")
  , ( 41267, "tup")
  , ( 41268, "turx")
  , ( 41269, "tur")
  , ( 41270, "ddit")
  , ( 41271, "ddix")
  , ( 41272, "ddi")
  , ( 41273, "ddip")
  , ( 41274, "ddiex")
  , ( 41275, "ddie")
  , ( 41276, "ddiep")
  , ( 41277, "ddat")
  , ( 41278, "ddax")
  , ( 41279, "dda")
  , ( 41280, "ddap")
  , ( 41281, "dduox")
  , ( 41282, "dduo")
  , ( 41283, "dduop")
  , ( 41284, "ddot")
  , ( 41285, "ddox")
  , ( 41286, "ddo")
  , ( 41287, "ddop")
  , ( 41288, "ddex")
  , ( 41289, "dde")
  , ( 41290, "ddep")
  , ( 41291, "ddut")
  , ( 41292, "ddux")
  , ( 41293, "ddu")
  , ( 41294, "ddup")
  , ( 41295, "ddurx")
  , ( 41296, "ddur")
  , ( 41297, "ndit")
  , ( 41298, "ndix")
  , ( 41299, "ndi")
  , ( 41300, "ndip")
  , ( 41301, "ndiex")
  , ( 41302, "ndie")
  , ( 41303, "ndat")
  , ( 41304, "ndax")
  , ( 41305, "nda")
  , ( 41306, "ndap")
  , ( 41307, "ndot")
  , ( 41308, "ndox")
  , ( 41309, "ndo")
  , ( 41310, "ndop")
  , ( 41311, "ndex")
  , ( 41312, "nde")
  , ( 41313, "ndep")
  , ( 41314, "ndut")
  , ( 41315, "ndux")
  , ( 41316, "ndu")
  , ( 41317, "ndup")
  , ( 41318, "ndurx")
  , ( 41319, "ndur")
  , ( 41320, "hnit")
  , ( 41321, "hnix")
  , ( 41322, "hni")
  , ( 41323, "hnip")
  , ( 41324, "hniet")
  , ( 41325, "hniex")
  , ( 41326, "hnie")
  , ( 41327, "hniep")
  , ( 41328, "hnat")
  , ( 41329, "hnax")
  , ( 41330, "hna")
  , ( 41331, "hnap")
  , ( 41332, "hnuox")
  , ( 41333, "hnuo")
  , ( 41334, "hnot")
  , ( 41335, "hnox")
  , ( 41336, "hnop")
  , ( 41337, "hnex")
  , ( 41338, "hne")
  , ( 41339, "hnep")
  , ( 41340, "hnut")
  , ( 41341, "nit")
  , ( 41342, "nix")
  , ( 41343, "ni")
  , ( 41344, "nip")
  , ( 41345, "niex")
  , ( 41346, "nie")
  , ( 41347, "niep")
  , ( 41348, "nax")
  , ( 41349, "na")
  , ( 41350, "nap")
  , ( 41351, "nuox")
  , ( 41352, "nuo")
  , ( 41353, "nuop")
  , ( 41354, "not")
  , ( 41355, "nox")
  , ( 41356, "no")
  , ( 41357, "nop")
  , ( 41358, "nex")
  , ( 41359, "ne")
  , ( 41360, "nep")
  , ( 41361, "nut")
  , ( 41362, "nux")
  , ( 41363, "nu")
  , ( 41364, "nup")
  , ( 41365, "nurx")
  , ( 41366, "nur")
  , ( 41367, "hlit")
  , ( 41368, "hlix")
  , ( 41369, "hli")
  , ( 41370, "hlip")
  , ( 41371, "hliex")
  , ( 41372, "hlie")
  , ( 41373, "hliep")
  , ( 41374, "hlat")
  , ( 41375, "hlax")
  , ( 41376, "hla")
  , ( 41377, "hlap")
  , ( 41378, "hluox")
  , ( 41379, "hluo")
  , ( 41380, "hluop")
  , ( 41381, "hlox")
  , ( 41382, "hlo")
  , ( 41383, "hlop")
  , ( 41384, "hlex")
  , ( 41385, "hle")
  , ( 41386, "hlep")
  , ( 41387, "hlut")
  , ( 41388, "hlux")
  , ( 41389, "hlu")
  , ( 41390, "hlup")
  , ( 41391, "hlurx")
  , ( 41392, "hlur")
  , ( 41393, "hlyt")
  , ( 41394, "hlyx")
  , ( 41395, "hly")
  , ( 41396, "hlyp")
  , ( 41397, "hlyrx")
  , ( 41398, "hlyr")
  , ( 41399, "lit")
  , ( 41400, "lix")
  , ( 41401, "li")
  , ( 41402, "lip")
  , ( 41403, "liet")
  , ( 41404, "liex")
  , ( 41405, "lie")
  , ( 41406, "liep")
  , ( 41407, "lat")
  , ( 41408, "lax")
  , ( 41409, "la")
  , ( 41410, "lap")
  , ( 41411, "luot")
  , ( 41412, "luox")
  , ( 41413, "luo")
  , ( 41414, "luop")
  , ( 41415, "lot")
  , ( 41416, "lox")
  , ( 41417, "lo")
  , ( 41418, "lop")
  , ( 41419, "lex")
  , ( 41420, "le")
  , ( 41421, "lep")
  , ( 41422, "lut")
  , ( 41423, "lux")
  , ( 41424, "lu")
  , ( 41425, "lup")
  , ( 41426, "lurx")
  , ( 41427, "lur")
  , ( 41428, "lyt")
  , ( 41429, "lyx")
  , ( 41430, "ly")
  , ( 41431, "lyp")
  , ( 41432, "lyrx")
  , ( 41433, "lyr")
  , ( 41434, "git")
  , ( 41435, "gix")
  , ( 41436, "gi")
  , ( 41437, "gip")
  , ( 41438, "giet")
  , ( 41439, "giex")
  , ( 41440, "gie")
  , ( 41441, "giep")
  , ( 41442, "gat")
  , ( 41443, "gax")
  , ( 41444, "ga")
  , ( 41445, "gap")
  , ( 41446, "guot")
  , ( 41447, "guox")
  , ( 41448, "guo")
  , ( 41449, "guop")
  , ( 41450, "got")
  , ( 41451, "gox")
  , ( 41452, "go")
  , ( 41453, "gop")
  , ( 41454, "get")
  , ( 41455, "gex")
  , ( 41456, "ge")
  , ( 41457, "gep")
  , ( 41458, "gut")
  , ( 41459, "gux")
  , ( 41460, "gu")
  , ( 41461, "gup")
  , ( 41462, "gurx")
  , ( 41463, "gur")
  , ( 41464, "kit")
  , ( 41465, "kix")
  , ( 41466, "ki")
  , ( 41467, "kip")
  , ( 41468, "kiex")
  , ( 41469, "kie")
  , ( 41470, "kiep")
  , ( 41471, "kat")
  , ( 41472, "kax")
  , ( 41473, "ka")
  , ( 41474, "kap")
  , ( 41475, "kuox")
  , ( 41476, "kuo")
  , ( 41477, "kuop")
  , ( 41478, "kot")
  , ( 41479, "kox")
  , ( 41480, "ko")
  , ( 41481, "kop")
  , ( 41482, "ket")
  , ( 41483, "kex")
  , ( 41484, "ke")
  , ( 41485, "kep")
  , ( 41486, "kut")
  , ( 41487, "kux")
  , ( 41488, "ku")
  , ( 41489, "kup")
  , ( 41490, "kurx")
  , ( 41491, "kur")
  , ( 41492, "ggit")
  , ( 41493, "ggix")
  , ( 41494, "ggi")
  , ( 41495, "ggiex")
  , ( 41496, "ggie")
  , ( 41497, "ggiep")
  , ( 41498, "ggat")
  , ( 41499, "ggax")
  , ( 41500, "gga")
  , ( 41501, "ggap")
  , ( 41502, "gguot")
  , ( 41503, "gguox")
  , ( 41504, "gguo")
  , ( 41505, "gguop")
  , ( 41506, "ggot")
  , ( 41507, "ggox")
  , ( 41508, "ggo")
  , ( 41509, "ggop")
  , ( 41510, "gget")
  , ( 41511, "ggex")
  , ( 41512, "gge")
  , ( 41513, "ggep")
  , ( 41514, "ggut")
  , ( 41515, "ggux")
  , ( 41516, "ggu")
  , ( 41517, "ggup")
  , ( 41518, "ggurx")
  , ( 41519, "ggur")
  , ( 41520, "mgiex")
  , ( 41521, "mgie")
  , ( 41522, "mgat")
  , ( 41523, "mgax")
  , ( 41524, "mga")
  , ( 41525, "mgap")
  , ( 41526, "mguox")
  , ( 41527, "mguo")
  , ( 41528, "mguop")
  , ( 41529, "mgot")
  , ( 41530, "mgox")
  , ( 41531, "mgo")
  , ( 41532, "mgop")
  , ( 41533, "mgex")
  , ( 41534, "mge")
  , ( 41535, "mgep")
  , ( 41536, "mgut")
  , ( 41537, "mgux")
  , ( 41538, "mgu")
  , ( 41539, "mgup")
  , ( 41540, "mgurx")
  , ( 41541, "mgur")
  , ( 41542, "hxit")
  , ( 41543, "hxix")
  , ( 41544, "hxi")
  , ( 41545, "hxip")
  , ( 41546, "hxiet")
  , ( 41547, "hxiex")
  , ( 41548, "hxie")
  , ( 41549, "hxiep")
  , ( 41550, "hxat")
  , ( 41551, "hxax")
  , ( 41552, "hxa")
  , ( 41553, "hxap")
  , ( 41554, "hxuot")
  , ( 41555, "hxuox")
  , ( 41556, "hxuo")
  , ( 41557, "hxuop")
  , ( 41558, "hxot")
  , ( 41559, "hxox")
  , ( 41560, "hxo")
  , ( 41561, "hxop")
  , ( 41562, "hxex")
  , ( 41563, "hxe")
  , ( 41564, "hxep")
  , ( 41565, "ngiex")
  , ( 41566, "ngie")
  , ( 41567, "ngiep")
  , ( 41568, "ngat")
  , ( 41569, "ngax")
  , ( 41570, "nga")
  , ( 41571, "ngap")
  , ( 41572, "nguot")
  , ( 41573, "nguox")
  , ( 41574, "nguo")
  , ( 41575, "ngot")
  , ( 41576, "ngox")
  , ( 41577, "ngo")
  , ( 41578, "ngop")
  , ( 41579, "ngex")
  , ( 41580, "nge")
  , ( 41581, "ngep")
  , ( 41582, "hit")
  , ( 41583, "hiex")
  , ( 41584, "hie")
  , ( 41585, "hat")
  , ( 41586, "hax")
  , ( 41587, "ha")
  , ( 41588, "hap")
  , ( 41589, "huot")
  , ( 41590, "huox")
  , ( 41591, "huo")
  , ( 41592, "huop")
  , ( 41593, "hot")
  , ( 41594, "hox")
  , ( 41595, "ho")
  , ( 41596, "hop")
  , ( 41597, "hex")
  , ( 41598, "he")
  , ( 41599, "hep")
  , ( 41600, "wat")
  , ( 41601, "wax")
  , ( 41602, "wa")
  , ( 41603, "wap")
  , ( 41604, "wuox")
  , ( 41605, "wuo")
  , ( 41606, "wuop")
  , ( 41607, "wox")
  , ( 41608, "wo")
  , ( 41609, "wop")
  , ( 41610, "wex")
  , ( 41611, "we")
  , ( 41612, "wep")
  , ( 41613, "zit")
  , ( 41614, "zix")
  , ( 41615, "zi")
  , ( 41616, "zip")
  , ( 41617, "ziex")
  , ( 41618, "zie")
  , ( 41619, "ziep")
  , ( 41620, "zat")
  , ( 41621, "zax")
  , ( 41622, "za")
  , ( 41623, "zap")
  , ( 41624, "zuox")
  , ( 41625, "zuo")
  , ( 41626, "zuop")
  , ( 41627, "zot")
  , ( 41628, "zox")
  , ( 41629, "zo")
  , ( 41630, "zop")
  , ( 41631, "zex")
  , ( 41632, "ze")
  , ( 41633, "zep")
  , ( 41634, "zut")
  , ( 41635, "zux")
  , ( 41636, "zu")
  , ( 41637, "zup")
  , ( 41638, "zurx")
  , ( 41639, "zur")
  , ( 41640, "zyt")
  , ( 41641, "zyx")
  , ( 41642, "zy")
  , ( 41643, "zyp")
  , ( 41644, "zyrx")
  , ( 41645, "zyr")
  , ( 41646, "cit")
  , ( 41647, "cix")
  , ( 41648, "ci")
  , ( 41649, "cip")
  , ( 41650, "ciet")
  , ( 41651, "ciex")
  , ( 41652, "cie")
  , ( 41653, "ciep")
  , ( 41654, "cat")
  , ( 41655, "cax")
  , ( 41656, "ca")
  , ( 41657, "cap")
  , ( 41658, "cuox")
  , ( 41659, "cuo")
  , ( 41660, "cuop")
  , ( 41661, "cot")
  , ( 41662, "cox")
  , ( 41663, "co")
  , ( 41664, "cop")
  , ( 41665, "cex")
  , ( 41666, "ce")
  , ( 41667, "cep")
  , ( 41668, "cut")
  , ( 41669, "cux")
  , ( 41670, "cu")
  , ( 41671, "cup")
  , ( 41672, "curx")
  , ( 41673, "cur")
  , ( 41674, "cyt")
  , ( 41675, "cyx")
  , ( 41676, "cy")
  , ( 41677, "cyp")
  , ( 41678, "cyrx")
  , ( 41679, "cyr")
  , ( 41680, "zzit")
  , ( 41681, "zzix")
  , ( 41682, "zzi")
  , ( 41683, "zzip")
  , ( 41684, "zziet")
  , ( 41685, "zziex")
  , ( 41686, "zzie")
  , ( 41687, "zziep")
  , ( 41688, "zzat")
  , ( 41689, "zzax")
  , ( 41690, "zza")
  , ( 41691, "zzap")
  , ( 41692, "zzox")
  , ( 41693, "zzo")
  , ( 41694, "zzop")
  , ( 41695, "zzex")
  , ( 41696, "zze")
  , ( 41697, "zzep")
  , ( 41698, "zzux")
  , ( 41699, "zzu")
  , ( 41700, "zzup")
  , ( 41701, "zzurx")
  , ( 41702, "zzur")
  , ( 41703, "zzyt")
  , ( 41704, "zzyx")
  , ( 41705, "zzy")
  , ( 41706, "zzyp")
  , ( 41707, "zzyrx")
  , ( 41708, "zzyr")
  , ( 41709, "nzit")
  , ( 41710, "nzix")
  , ( 41711, "nzi")
  , ( 41712, "nzip")
  , ( 41713, "nziex")
  , ( 41714, "nzie")
  , ( 41715, "nziep")
  , ( 41716, "nzat")
  , ( 41717, "nzax")
  , ( 41718, "nza")
  , ( 41719, "nzap")
  , ( 41720, "nzuox")
  , ( 41721, "nzuo")
  , ( 41722, "nzox")
  , ( 41723, "nzop")
  , ( 41724, "nzex")
  , ( 41725, "nze")
  , ( 41726, "nzux")
  , ( 41727, "nzu")
  , ( 41728, "nzup")
  , ( 41729, "nzurx")
  , ( 41730, "nzur")
  , ( 41731, "nzyt")
  , ( 41732, "nzyx")
  , ( 41733, "nzy")
  , ( 41734, "nzyp")
  , ( 41735, "nzyrx")
  , ( 41736, "nzyr")
  , ( 41737, "sit")
  , ( 41738, "six")
  , ( 41739, "si")
  , ( 41740, "sip")
  , ( 41741, "siex")
  , ( 41742, "sie")
  , ( 41743, "siep")
  , ( 41744, "sat")
  , ( 41745, "sax")
  , ( 41746, "sa")
  , ( 41747, "sap")
  , ( 41748, "suox")
  , ( 41749, "suo")
  , ( 41750, "suop")
  , ( 41751, "sot")
  , ( 41752, "sox")
  , ( 41753, "so")
  , ( 41754, "sop")
  , ( 41755, "sex")
  , ( 41756, "se")
  , ( 41757, "sep")
  , ( 41758, "sut")
  , ( 41759, "sux")
  , ( 41760, "su")
  , ( 41761, "sup")
  , ( 41762, "surx")
  , ( 41763, "sur")
  , ( 41764, "syt")
  , ( 41765, "syx")
  , ( 41766, "sy")
  , ( 41767, "syp")
  , ( 41768, "syrx")
  , ( 41769, "syr")
  , ( 41770, "ssit")
  , ( 41771, "ssix")
  , ( 41772, "ssi")
  , ( 41773, "ssip")
  , ( 41774, "ssiex")
  , ( 41775, "ssie")
  , ( 41776, "ssiep")
  , ( 41777, "ssat")
  , ( 41778, "ssax")
  , ( 41779, "ssa")
  , ( 41780, "ssap")
  , ( 41781, "ssot")
  , ( 41782, "ssox")
  , ( 41783, "sso")
  , ( 41784, "ssop")
  , ( 41785, "ssex")
  , ( 41786, "sse")
  , ( 41787, "ssep")
  , ( 41788, "ssut")
  , ( 41789, "ssux")
  , ( 41790, "ssu")
  , ( 41791, "ssup")
  , ( 41792, "ssyt")
  , ( 41793, "ssyx")
  , ( 41794, "ssy")
  , ( 41795, "ssyp")
  , ( 41796, "ssyrx")
  , ( 41797, "ssyr")
  , ( 41798, "zhat")
  , ( 41799, "zhax")
  , ( 41800, "zha")
  , ( 41801, "zhap")
  , ( 41802, "zhuox")
  , ( 41803, "zhuo")
  , ( 41804, "zhuop")
  , ( 41805, "zhot")
  , ( 41806, "zhox")
  , ( 41807, "zho")
  , ( 41808, "zhop")
  , ( 41809, "zhet")
  , ( 41810, "zhex")
  , ( 41811, "zhe")
  , ( 41812, "zhep")
  , ( 41813, "zhut")
  , ( 41814, "zhux")
  , ( 41815, "zhu")
  , ( 41816, "zhup")
  , ( 41817, "zhurx")
  , ( 41818, "zhur")
  , ( 41819, "zhyt")
  , ( 41820, "zhyx")
  , ( 41821, "zhy")
  , ( 41822, "zhyp")
  , ( 41823, "zhyrx")
  , ( 41824, "zhyr")
  , ( 41825, "chat")
  , ( 41826, "chax")
  , ( 41827, "cha")
  , ( 41828, "chap")
  , ( 41829, "chuot")
  , ( 41830, "chuox")
  , ( 41831, "chuo")
  , ( 41832, "chuop")
  , ( 41833, "chot")
  , ( 41834, "chox")
  , ( 41835, "cho")
  , ( 41836, "chop")
  , ( 41837, "chet")
  , ( 41838, "chex")
  , ( 41839, "che")
  , ( 41840, "chep")
  , ( 41841, "chux")
  , ( 41842, "chu")
  , ( 41843, "chup")
  , ( 41844, "churx")
  , ( 41845, "chur")
  , ( 41846, "chyt")
  , ( 41847, "chyx")
  , ( 41848, "chy")
  , ( 41849, "chyp")
  , ( 41850, "chyrx")
  , ( 41851, "chyr")
  , ( 41852, "rrax")
  , ( 41853, "rra")
  , ( 41854, "rruox")
  , ( 41855, "rruo")
  , ( 41856, "rrot")
  , ( 41857, "rrox")
  , ( 41858, "rro")
  , ( 41859, "rrop")
  , ( 41860, "rret")
  , ( 41861, "rrex")
  , ( 41862, "rre")
  , ( 41863, "rrep")
  , ( 41864, "rrut")
  , ( 41865, "rrux")
  , ( 41866, "rru")
  , ( 41867, "rrup")
  , ( 41868, "rrurx")
  , ( 41869, "rrur")
  , ( 41870, "rryt")
  , ( 41871, "rryx")
  , ( 41872, "rry")
  , ( 41873, "rryp")
  , ( 41874, "rryrx")
  , ( 41875, "rryr")
  , ( 41876, "nrat")
  , ( 41877, "nrax")
  , ( 41878, "nra")
  , ( 41879, "nrap")
  , ( 41880, "nrox")
  , ( 41881, "nro")
  , ( 41882, "nrop")
  , ( 41883, "nret")
  , ( 41884, "nrex")
  , ( 41885, "nre")
  , ( 41886, "nrep")
  , ( 41887, "nrut")
  , ( 41888, "nrux")
  , ( 41889, "nru")
  , ( 41890, "nrup")
  , ( 41891, "nrurx")
  , ( 41892, "nrur")
  , ( 41893, "nryt")
  , ( 41894, "nryx")
  , ( 41895, "nry")
  , ( 41896, "nryp")
  , ( 41897, "nryrx")
  , ( 41898, "nryr")
  , ( 41899, "shat")
  , ( 41900, "shax")
  , ( 41901, "sha")
  , ( 41902, "shap")
  , ( 41903, "shuox")
  , ( 41904, "shuo")
  , ( 41905, "shuop")
  , ( 41906, "shot")
  , ( 41907, "shox")
  , ( 41908, "sho")
  , ( 41909, "shop")
  , ( 41910, "shet")
  , ( 41911, "shex")
  , ( 41912, "she")
  , ( 41913, "shep")
  , ( 41914, "shut")
  , ( 41915, "shux")
  , ( 41916, "shu")
  , ( 41917, "shup")
  , ( 41918, "shurx")
  , ( 41919, "shur")
  , ( 41920, "shyt")
  , ( 41921, "shyx")
  , ( 41922, "shy")
  , ( 41923, "shyp")
  , ( 41924, "shyrx")
  , ( 41925, "shyr")
  , ( 41926, "rat")
  , ( 41927, "rax")
  , ( 41928, "ra")
  , ( 41929, "rap")
  , ( 41930, "ruox")
  , ( 41931, "ruo")
  , ( 41932, "ruop")
  , ( 41933, "rot")
  , ( 41934, "rox")
  , ( 41935, "ro")
  , ( 41936, "rop")
  , ( 41937, "rex")
  , ( 41938, "re")
  , ( 41939, "rep")
  , ( 41940, "rut")
  , ( 41941, "rux")
  , ( 41942, "ru")
  , ( 41943, "rup")
  , ( 41944, "rurx")
  , ( 41945, "rur")
  , ( 41946, "ryt")
  , ( 41947, "ryx")
  , ( 41948, "ry")
  , ( 41949, "ryp")
  , ( 41950, "ryrx")
  , ( 41951, "ryr")
  , ( 41952, "jit")
  , ( 41953, "jix")
  , ( 41954, "ji")
  , ( 41955, "jip")
  , ( 41956, "jiet")
  , ( 41957, "jiex")
  , ( 41958, "jie")
  , ( 41959, "jiep")
  , ( 41960, "juot")
  , ( 41961, "juox")
  , ( 41962, "juo")
  , ( 41963, "juop")
  , ( 41964, "jot")
  , ( 41965, "jox")
  , ( 41966, "jo")
  , ( 41967, "jop")
  , ( 41968, "jut")
  , ( 41969, "jux")
  , ( 41970, "ju")
  , ( 41971, "jup")
  , ( 41972, "jurx")
  , ( 41973, "jur")
  , ( 41974, "jyt")
  , ( 41975, "jyx")
  , ( 41976, "jy")
  , ( 41977, "jyp")
  , ( 41978, "jyrx")
  , ( 41979, "jyr")
  , ( 41980, "qit")
  , ( 41981, "qix")
  , ( 41982, "qi")
  , ( 41983, "qip")
  , ( 41984, "qiet")
  , ( 41985, "qiex")
  , ( 41986, "qie")
  , ( 41987, "qiep")
  , ( 41988, "quot")
  , ( 41989, "quox")
  , ( 41990, "quo")
  , ( 41991, "quop")
  , ( 41992, "qot")
  , ( 41993, "qox")
  , ( 41994, "qo")
  , ( 41995, "qop")
  , ( 41996, "qut")
  , ( 41997, "qux")
  , ( 41998, "qu")
  , ( 41999, "qup")
  , ( 42000, "qurx")
  , ( 42001, "qur")
  , ( 42002, "qyt")
  , ( 42003, "qyx")
  , ( 42004, "qy")
  , ( 42005, "qyp")
  , ( 42006, "qyrx")
  , ( 42007, "qyr")
  , ( 42008, "jjit")
  , ( 42009, "jjix")
  , ( 42010, "jji")
  , ( 42011, "jjip")
  , ( 42012, "jjiet")
  , ( 42013, "jjiex")
  , ( 42014, "jjie")
  , ( 42015, "jjiep")
  , ( 42016, "jjuox")
  , ( 42017, "jjuo")
  , ( 42018, "jjuop")
  , ( 42019, "jjot")
  , ( 42020, "jjox")
  , ( 42021, "jjo")
  , ( 42022, "jjop")
  , ( 42023, "jjut")
  , ( 42024, "jjux")
  , ( 42025, "jju")
  , ( 42026, "jjup")
  , ( 42027, "jjurx")
  , ( 42028, "jjur")
  , ( 42029, "jjyt")
  , ( 42030, "jjyx")
  , ( 42031, "jjy")
  , ( 42032, "jjyp")
  , ( 42033, "njit")
  , ( 42034, "njix")
  , ( 42035, "nji")
  , ( 42036, "njip")
  , ( 42037, "njiet")
  , ( 42038, "njiex")
  , ( 42039, "njie")
  , ( 42040, "njiep")
  , ( 42041, "njuox")
  , ( 42042, "njuo")
  , ( 42043, "njot")
  , ( 42044, "njox")
  , ( 42045, "njo")
  , ( 42046, "njop")
  , ( 42047, "njux")
  , ( 42048, "nju")
  , ( 42049, "njup")
  , ( 42050, "njurx")
  , ( 42051, "njur")
  , ( 42052, "njyt")
  , ( 42053, "njyx")
  , ( 42054, "njy")
  , ( 42055, "njyp")
  , ( 42056, "njyrx")
  , ( 42057, "njyr")
  , ( 42058, "nyit")
  , ( 42059, "nyix")
  , ( 42060, "nyi")
  , ( 42061, "nyip")
  , ( 42062, "nyiet")
  , ( 42063, "nyiex")
  , ( 42064, "nyie")
  , ( 42065, "nyiep")
  , ( 42066, "nyuox")
  , ( 42067, "nyuo")
  , ( 42068, "nyuop")
  , ( 42069, "nyot")
  , ( 42070, "nyox")
  , ( 42071, "nyo")
  , ( 42072, "nyop")
  , ( 42073, "nyut")
  , ( 42074, "nyux")
  , ( 42075, "nyu")
  , ( 42076, "nyup")
  , ( 42077, "xit")
  , ( 42078, "xix")
  , ( 42079, "xi")
  , ( 42080, "xip")
  , ( 42081, "xiet")
  , ( 42082, "xiex")
  , ( 42083, "xie")
  , ( 42084, "xiep")
  , ( 42085, "xuox")
  , ( 42086, "xuo")
  , ( 42087, "xot")
  , ( 42088, "xox")
  , ( 42089, "xo")
  , ( 42090, "xop")
  , ( 42091, "xyt")
  , ( 42092, "xyx")
  , ( 42093, "xy")
  , ( 42094, "xyp")
  , ( 42095, "xyrx")
  , ( 42096, "xyr")
  , ( 42097, "yit")
  , ( 42098, "yix")
  , ( 42099, "yi")
  , ( 42100, "yip")
  , ( 42101, "yiet")
  , ( 42102, "yiex")
  , ( 42103, "yie")
  , ( 42104, "yiep")
  , ( 42105, "yuot")
  , ( 42106, "yuox")
  , ( 42107, "yuo")
  , ( 42108, "yuop")
  , ( 42109, "yot")
  , ( 42110, "yox")
  , ( 42111, "yo")
  , ( 42112, "yop")
  , ( 42113, "yut")
  , ( 42114, "yux")
  , ( 42115, "yu")
  , ( 42116, "yup")
  , ( 42117, "yurx")
  , ( 42118, "yur")
  , ( 42119, "yyt")
  , ( 42120, "yyx")
  , ( 42121, "yy")
  , ( 42122, "yyp")
  , ( 42123, "yyrx")
  , ( 42124, "yyr")
  , ( 42125, "[?]")
  , ( 42126, "[?]")
  , ( 42127, "[?]")
  , ( 42128, "Qot")
  , ( 42129, "Li")
  , ( 42130, "Kit")
  , ( 42131, "Nyip")
  , ( 42132, "Cyp")
  , ( 42133, "Ssi")
  , ( 42134, "Ggop")
  , ( 42135, "Gep")
  , ( 42136, "Mi")
  , ( 42137, "Hxit")
  , ( 42138, "Lyr")
  , ( 42139, "Bbut")
  , ( 42140, "Mop")
  , ( 42141, "Yo")
  , ( 42142, "Put")
  , ( 42143, "Hxuo")
  , ( 42144, "Tat")
  , ( 42145, "Ga")
  , ( 42146, "[?]")
  , ( 42147, "[?]")
  , ( 42148, "Ddur")
  , ( 42149, "Bur")
  , ( 42150, "Gguo")
  , ( 42151, "Nyop")
  , ( 42152, "Tu")
  , ( 42153, "Op")
  , ( 42154, "Jjut")
  , ( 42155, "Zot")
  , ( 42156, "Pyt")
  , ( 42157, "Hmo")
  , ( 42158, "Yit")
  , ( 42159, "Vur")
  , ( 42160, "Shy")
  , ( 42161, "Vep")
  , ( 42162, "Za")
  , ( 42163, "Jo")
  , ( 42164, "[?]")
  , ( 42165, "Jjy")
  , ( 42166, "Got")
  , ( 42167, "Jjie")
  , ( 42168, "Wo")
  , ( 42169, "Du")
  , ( 42170, "Shur")
  , ( 42171, "Lie")
  , ( 42172, "Cy")
  , ( 42173, "Cuop")
  , ( 42174, "Cip")
  , ( 42175, "Hxop")
  , ( 42176, "Shat")
  , ( 42177, "[?]")
  , ( 42178, "Shop")
  , ( 42179, "Che")
  , ( 42180, "Zziet")
  , ( 42181, "[?]")
  , ( 42182, "Ke")
  , ( 42183, "[?]")
  , ( 42184, "[?]")
  , ( 42185, "[?]")
  , ( 42186, "[?]")
  , ( 42187, "[?]")
  , ( 42188, "[?]")
  , ( 42189, "[?]")
  , ( 42190, "[?]")
  , ( 42191, "[?]")
  , ( 42192, "[?]")
  , ( 42193, "[?]")
  , ( 42194, "[?]")
  , ( 42195, "[?]")
  , ( 42196, "[?]")
  , ( 42197, "[?]")
  , ( 42198, "[?]")
  , ( 42199, "[?]")
  , ( 42200, "[?]")
  , ( 42201, "[?]")
  , ( 42202, "[?]")
  , ( 42203, "[?]")
  , ( 42204, "[?]")
  , ( 42205, "[?]")
  , ( 42206, "[?]")
  , ( 42207, "[?]")
  , ( 42208, "[?]")
  , ( 42209, "[?]")
  , ( 42210, "[?]")
  , ( 42211, "[?]")
  , ( 42212, "[?]")
  , ( 42213, "[?]")
  , ( 42214, "[?]")
  , ( 42215, "[?]")
  , ( 42216, "[?]")
  , ( 42217, "[?]")
  , ( 42218, "[?]")
  , ( 42219, "[?]")
  , ( 42220, "[?]")
  , ( 42221, "[?]")
  , ( 42222, "[?]")
  , ( 42223, "[?]")
  , ( 42224, "[?]")
  , ( 42225, "[?]")
  , ( 42226, "[?]")
  , ( 42227, "[?]")
  , ( 42228, "[?]")
  , ( 42229, "[?]")
  , ( 42230, "[?]")
  , ( 42231, "[?]")
  , ( 42232, "[?]")
  , ( 42233, "[?]")
  , ( 42234, "[?]")
  , ( 42235, "[?]")
  , ( 42236, "[?]")
  , ( 42237, "[?]")
  , ( 42238, "[?]")
  , ( 55204, "[?]")
  , ( 55205, "[?]")
  , ( 55206, "[?]")
  , ( 55207, "[?]")
  , ( 55208, "[?]")
  , ( 55209, "[?]")
  , ( 55210, "[?]")
  , ( 55211, "[?]")
  , ( 55212, "[?]")
  , ( 55213, "[?]")
  , ( 55214, "[?]")
  , ( 55215, "[?]")
  , ( 55216, "[?]")
  , ( 55217, "[?]")
  , ( 55218, "[?]")
  , ( 55219, "[?]")
  , ( 55220, "[?]")
  , ( 55221, "[?]")
  , ( 55222, "[?]")
  , ( 55223, "[?]")
  , ( 55224, "[?]")
  , ( 55225, "[?]")
  , ( 55226, "[?]")
  , ( 55227, "[?]")
  , ( 55228, "[?]")
  , ( 55229, "[?]")
  , ( 55230, "[?]")
  , ( 55231, "[?]")
  , ( 55232, "[?]")
  , ( 55233, "[?]")
  , ( 55234, "[?]")
  , ( 55235, "[?]")
  , ( 55236, "[?]")
  , ( 55237, "[?]")
  , ( 55238, "[?]")
  , ( 55239, "[?]")
  , ( 55240, "[?]")
  , ( 55241, "[?]")
  , ( 55242, "[?]")
  , ( 55243, "[?]")
  , ( 55244, "[?]")
  , ( 55245, "[?]")
  , ( 55246, "[?]")
  , ( 55247, "[?]")
  , ( 55248, "[?]")
  , ( 55249, "[?]")
  , ( 55250, "[?]")
  , ( 55251, "[?]")
  , ( 55252, "[?]")
  , ( 55253, "[?]")
  , ( 55254, "[?]")
  , ( 55255, "[?]")
  , ( 55256, "[?]")
  , ( 55257, "[?]")
  , ( 55258, "[?]")
  , ( 55259, "[?]")
  , ( 55260, "[?]")
  , ( 55261, "[?]")
  , ( 55262, "[?]")
  , ( 55263, "[?]")
  , ( 55264, "[?]")
  , ( 55265, "[?]")
  , ( 55266, "[?]")
  , ( 55267, "[?]")
  , ( 55268, "[?]")
  , ( 55269, "[?]")
  , ( 55270, "[?]")
  , ( 55271, "[?]")
  , ( 55272, "[?]")
  , ( 55273, "[?]")
  , ( 55274, "[?]")
  , ( 55275, "[?]")
  , ( 55276, "[?]")
  , ( 55277, "[?]")
  , ( 55278, "[?]")
  , ( 55279, "[?]")
  , ( 55280, "[?]")
  , ( 55281, "[?]")
  , ( 55282, "[?]")
  , ( 55283, "[?]")
  , ( 55284, "[?]")
  , ( 55285, "[?]")
  , ( 55286, "[?]")
  , ( 55287, "[?]")
  , ( 55288, "[?]")
  , ( 55289, "[?]")
  , ( 55290, "[?]")
  , ( 55291, "[?]")
  , ( 55292, "[?]")
  , ( 55293, "[?]")
  , ( 55294, "[?]")
  , ( 63744, "Kay ")
  , ( 63745, "Kayng ")
  , ( 63746, "Ke ")
  , ( 63747, "Ko ")
  , ( 63748, "Kol ")
  , ( 63749, "Koc ")
  , ( 63750, "Kwi ")
  , ( 63751, "Kwi ")
  , ( 63752, "Kyun ")
  , ( 63753, "Kul ")
  , ( 63754, "Kum ")
  , ( 63755, "Na ")
  , ( 63756, "Na ")
  , ( 63757, "Na ")
  , ( 63758, "La ")
  , ( 63759, "Na ")
  , ( 63760, "Na ")
  , ( 63761, "Na ")
  , ( 63762, "Na ")
  , ( 63763, "Na ")
  , ( 63764, "Nak ")
  , ( 63765, "Nak ")
  , ( 63766, "Nak ")
  , ( 63767, "Nak ")
  , ( 63768, "Nak ")
  , ( 63769, "Nak ")
  , ( 63770, "Nak ")
  , ( 63771, "Nan ")
  , ( 63772, "Nan ")
  , ( 63773, "Nan ")
  , ( 63774, "Nan ")
  , ( 63775, "Nan ")
  , ( 63776, "Nan ")
  , ( 63777, "Nam ")
  , ( 63778, "Nam ")
  , ( 63779, "Nam ")
  , ( 63780, "Nam ")
  , ( 63781, "Nap ")
  , ( 63782, "Nap ")
  , ( 63783, "Nap ")
  , ( 63784, "Nang ")
  , ( 63785, "Nang ")
  , ( 63786, "Nang ")
  , ( 63787, "Nang ")
  , ( 63788, "Nang ")
  , ( 63789, "Nay ")
  , ( 63790, "Nayng ")
  , ( 63791, "No ")
  , ( 63792, "No ")
  , ( 63793, "No ")
  , ( 63794, "No ")
  , ( 63795, "No ")
  , ( 63796, "No ")
  , ( 63797, "No ")
  , ( 63798, "No ")
  , ( 63799, "No ")
  , ( 63800, "No ")
  , ( 63801, "No ")
  , ( 63802, "No ")
  , ( 63803, "Nok ")
  , ( 63804, "Nok ")
  , ( 63805, "Nok ")
  , ( 63806, "Nok ")
  , ( 63807, "Nok ")
  , ( 63808, "Nok ")
  , ( 63809, "Non ")
  , ( 63810, "Nong ")
  , ( 63811, "Nong ")
  , ( 63812, "Nong ")
  , ( 63813, "Nong ")
  , ( 63814, "Noy ")
  , ( 63815, "Noy ")
  , ( 63816, "Noy ")
  , ( 63817, "Noy ")
  , ( 63818, "Nwu ")
  , ( 63819, "Nwu ")
  , ( 63820, "Nwu ")
  , ( 63821, "Nwu ")
  , ( 63822, "Nwu ")
  , ( 63823, "Nwu ")
  , ( 63824, "Nwu ")
  , ( 63825, "Nwu ")
  , ( 63826, "Nuk ")
  , ( 63827, "Nuk ")
  , ( 63828, "Num ")
  , ( 63829, "Nung ")
  , ( 63830, "Nung ")
  , ( 63831, "Nung ")
  , ( 63832, "Nung ")
  , ( 63833, "Nung ")
  , ( 63834, "Twu ")
  , ( 63835, "La ")
  , ( 63836, "Lak ")
  , ( 63837, "Lak ")
  , ( 63838, "Lan ")
  , ( 63839, "Lyeng ")
  , ( 63840, "Lo ")
  , ( 63841, "Lyul ")
  , ( 63842, "Li ")
  , ( 63843, "Pey ")
  , ( 63844, "Pen ")
  , ( 63845, "Pyen ")
  , ( 63846, "Pwu ")
  , ( 63847, "Pwul ")
  , ( 63848, "Pi ")
  , ( 63849, "Sak ")
  , ( 63850, "Sak ")
  , ( 63851, "Sam ")
  , ( 63852, "Sayk ")
  , ( 63853, "Sayng ")
  , ( 63854, "Sep ")
  , ( 63855, "Sey ")
  , ( 63856, "Sway ")
  , ( 63857, "Sin ")
  , ( 63858, "Sim ")
  , ( 63859, "Sip ")
  , ( 63860, "Ya ")
  , ( 63861, "Yak ")
  , ( 63862, "Yak ")
  , ( 63863, "Yang ")
  , ( 63864, "Yang ")
  , ( 63865, "Yang ")
  , ( 63866, "Yang ")
  , ( 63867, "Yang ")
  , ( 63868, "Yang ")
  , ( 63869, "Yang ")
  , ( 63870, "Yang ")
  , ( 63871, "Ye ")
  , ( 63872, "Ye ")
  , ( 63873, "Ye ")
  , ( 63874, "Ye ")
  , ( 63875, "Ye ")
  , ( 63876, "Ye ")
  , ( 63877, "Ye ")
  , ( 63878, "Ye ")
  , ( 63879, "Ye ")
  , ( 63880, "Ye ")
  , ( 63881, "Ye ")
  , ( 63882, "Yek ")
  , ( 63883, "Yek ")
  , ( 63884, "Yek ")
  , ( 63885, "Yek ")
  , ( 63886, "Yen ")
  , ( 63887, "Yen ")
  , ( 63888, "Yen ")
  , ( 63889, "Yen ")
  , ( 63890, "Yen ")
  , ( 63891, "Yen ")
  , ( 63892, "Yen ")
  , ( 63893, "Yen ")
  , ( 63894, "Yen ")
  , ( 63895, "Yen ")
  , ( 63896, "Yen ")
  , ( 63897, "Yen ")
  , ( 63898, "Yen ")
  , ( 63899, "Yen ")
  , ( 63900, "Yel ")
  , ( 63901, "Yel ")
  , ( 63902, "Yel ")
  , ( 63903, "Yel ")
  , ( 63904, "Yel ")
  , ( 63905, "Yel ")
  , ( 63906, "Yem ")
  , ( 63907, "Yem ")
  , ( 63908, "Yem ")
  , ( 63909, "Yem ")
  , ( 63910, "Yem ")
  , ( 63911, "Yep ")
  , ( 63912, "Yeng ")
  , ( 63913, "Yeng ")
  , ( 63914, "Yeng ")
  , ( 63915, "Yeng ")
  , ( 63916, "Yeng ")
  , ( 63917, "Yeng ")
  , ( 63918, "Yeng ")
  , ( 63919, "Yeng ")
  , ( 63920, "Yeng ")
  , ( 63921, "Yeng ")
  , ( 63922, "Yeng ")
  , ( 63923, "Yeng ")
  , ( 63924, "Yeng ")
  , ( 63925, "Yey ")
  , ( 63926, "Yey ")
  , ( 63927, "Yey ")
  , ( 63928, "Yey ")
  , ( 63929, "O ")
  , ( 63930, "Yo ")
  , ( 63931, "Yo ")
  , ( 63932, "Yo ")
  , ( 63933, "Yo ")
  , ( 63934, "Yo ")
  , ( 63935, "Yo ")
  , ( 63936, "Yo ")
  , ( 63937, "Yo ")
  , ( 63938, "Yo ")
  , ( 63939, "Yo ")
  , ( 63940, "Yong ")
  , ( 63941, "Wun ")
  , ( 63942, "Wen ")
  , ( 63943, "Yu ")
  , ( 63944, "Yu ")
  , ( 63945, "Yu ")
  , ( 63946, "Yu ")
  , ( 63947, "Yu ")
  , ( 63948, "Yu ")
  , ( 63949, "Yu ")
  , ( 63950, "Yu ")
  , ( 63951, "Yu ")
  , ( 63952, "Yu ")
  , ( 63953, "Yuk ")
  , ( 63954, "Yuk ")
  , ( 63955, "Yuk ")
  , ( 63956, "Yun ")
  , ( 63957, "Yun ")
  , ( 63958, "Yun ")
  , ( 63959, "Yun ")
  , ( 63960, "Yul ")
  , ( 63961, "Yul ")
  , ( 63962, "Yul ")
  , ( 63963, "Yul ")
  , ( 63964, "Yung ")
  , ( 63965, "I ")
  , ( 63966, "I ")
  , ( 63967, "I ")
  , ( 63968, "I ")
  , ( 63969, "I ")
  , ( 63970, "I ")
  , ( 63971, "I ")
  , ( 63972, "I ")
  , ( 63973, "I ")
  , ( 63974, "I ")
  , ( 63975, "I ")
  , ( 63976, "I ")
  , ( 63977, "I ")
  , ( 63978, "I ")
  , ( 63979, "Ik ")
  , ( 63980, "Ik ")
  , ( 63981, "In ")
  , ( 63982, "In ")
  , ( 63983, "In ")
  , ( 63984, "In ")
  , ( 63985, "In ")
  , ( 63986, "In ")
  , ( 63987, "In ")
  , ( 63988, "Im ")
  , ( 63989, "Im ")
  , ( 63990, "Im ")
  , ( 63991, "Ip ")
  , ( 63992, "Ip ")
  , ( 63993, "Ip ")
  , ( 63994, "Cang ")
  , ( 63995, "Cek ")
  , ( 63996, "Ci ")
  , ( 63997, "Cip ")
  , ( 63998, "Cha ")
  , ( 63999, "Chek ")
  , ( 64000, "Chey ")
  , ( 64001, "Thak ")
  , ( 64002, "Thak ")
  , ( 64003, "Thang ")
  , ( 64004, "Thayk ")
  , ( 64005, "Thong ")
  , ( 64006, "Pho ")
  , ( 64007, "Phok ")
  , ( 64008, "Hang ")
  , ( 64009, "Hang ")
  , ( 64010, "Hyen ")
  , ( 64011, "Hwak ")
  , ( 64012, "Wu ")
  , ( 64013, "Huo ")
  , ( 64014, "[?] ")
  , ( 64015, "[?] ")
  , ( 64016, "Zhong ")
  , ( 64017, "[?] ")
  , ( 64018, "Qing ")
  , ( 64019, "[?] ")
  , ( 64020, "[?] ")
  , ( 64021, "Xi ")
  , ( 64022, "Zhu ")
  , ( 64023, "Yi ")
  , ( 64024, "Li ")
  , ( 64025, "Shen ")
  , ( 64026, "Xiang ")
  , ( 64027, "Fu ")
  , ( 64028, "Jing ")
  , ( 64029, "Jing ")
  , ( 64030, "Yu ")
  , ( 64031, "[?] ")
  , ( 64032, "Hagi ")
  , ( 64033, "[?] ")
  , ( 64034, "Zhu ")
  , ( 64035, "[?] ")
  , ( 64036, "[?] ")
  , ( 64037, "Yi ")
  , ( 64038, "Du ")
  , ( 64039, "[?] ")
  , ( 64040, "[?] ")
  , ( 64041, "[?] ")
  , ( 64042, "Fan ")
  , ( 64043, "Si ")
  , ( 64044, "Guan ")
  , ( 64045, "[?]")
  , ( 64046, "[?]")
  , ( 64047, "[?]")
  , ( 64048, "[?]")
  , ( 64049, "[?]")
  , ( 64050, "[?]")
  , ( 64051, "[?]")
  , ( 64052, "[?]")
  , ( 64053, "[?]")
  , ( 64054, "[?]")
  , ( 64055, "[?]")
  , ( 64056, "[?]")
  , ( 64057, "[?]")
  , ( 64058, "[?]")
  , ( 64059, "[?]")
  , ( 64060, "[?]")
  , ( 64061, "[?]")
  , ( 64062, "[?]")
  , ( 64063, "[?]")
  , ( 64064, "[?]")
  , ( 64065, "[?]")
  , ( 64066, "[?]")
  , ( 64067, "[?]")
  , ( 64068, "[?]")
  , ( 64069, "[?]")
  , ( 64070, "[?]")
  , ( 64071, "[?]")
  , ( 64072, "[?]")
  , ( 64073, "[?]")
  , ( 64074, "[?]")
  , ( 64075, "[?]")
  , ( 64076, "[?]")
  , ( 64077, "[?]")
  , ( 64078, "[?]")
  , ( 64079, "[?]")
  , ( 64080, "[?]")
  , ( 64081, "[?]")
  , ( 64082, "[?]")
  , ( 64083, "[?]")
  , ( 64084, "[?]")
  , ( 64085, "[?]")
  , ( 64086, "[?]")
  , ( 64087, "[?]")
  , ( 64088, "[?]")
  , ( 64089, "[?]")
  , ( 64090, "[?]")
  , ( 64091, "[?]")
  , ( 64092, "[?]")
  , ( 64093, "[?]")
  , ( 64094, "[?]")
  , ( 64095, "[?]")
  , ( 64096, "[?]")
  , ( 64097, "[?]")
  , ( 64098, "[?]")
  , ( 64099, "[?]")
  , ( 64100, "[?]")
  , ( 64101, "[?]")
  , ( 64102, "[?]")
  , ( 64103, "[?]")
  , ( 64104, "[?]")
  , ( 64105, "[?]")
  , ( 64106, "[?]")
  , ( 64107, "[?]")
  , ( 64108, "[?]")
  , ( 64109, "[?]")
  , ( 64110, "[?]")
  , ( 64111, "[?]")
  , ( 64112, "[?]")
  , ( 64113, "[?]")
  , ( 64114, "[?]")
  , ( 64115, "[?]")
  , ( 64116, "[?]")
  , ( 64117, "[?]")
  , ( 64118, "[?]")
  , ( 64119, "[?]")
  , ( 64120, "[?]")
  , ( 64121, "[?]")
  , ( 64122, "[?]")
  , ( 64123, "[?]")
  , ( 64124, "[?]")
  , ( 64125, "[?]")
  , ( 64126, "[?]")
  , ( 64127, "[?]")
  , ( 64128, "[?]")
  , ( 64129, "[?]")
  , ( 64130, "[?]")
  , ( 64131, "[?]")
  , ( 64132, "[?]")
  , ( 64133, "[?]")
  , ( 64134, "[?]")
  , ( 64135, "[?]")
  , ( 64136, "[?]")
  , ( 64137, "[?]")
  , ( 64138, "[?]")
  , ( 64139, "[?]")
  , ( 64140, "[?]")
  , ( 64141, "[?]")
  , ( 64142, "[?]")
  , ( 64143, "[?]")
  , ( 64144, "[?]")
  , ( 64145, "[?]")
  , ( 64146, "[?]")
  , ( 64147, "[?]")
  , ( 64148, "[?]")
  , ( 64149, "[?]")
  , ( 64150, "[?]")
  , ( 64151, "[?]")
  , ( 64152, "[?]")
  , ( 64153, "[?]")
  , ( 64154, "[?]")
  , ( 64155, "[?]")
  , ( 64156, "[?]")
  , ( 64157, "[?]")
  , ( 64158, "[?]")
  , ( 64159, "[?]")
  , ( 64160, "[?]")
  , ( 64161, "[?]")
  , ( 64162, "[?]")
  , ( 64163, "[?]")
  , ( 64164, "[?]")
  , ( 64165, "[?]")
  , ( 64166, "[?]")
  , ( 64167, "[?]")
  , ( 64168, "[?]")
  , ( 64169, "[?]")
  , ( 64170, "[?]")
  , ( 64171, "[?]")
  , ( 64172, "[?]")
  , ( 64173, "[?]")
  , ( 64174, "[?]")
  , ( 64175, "[?]")
  , ( 64176, "[?]")
  , ( 64177, "[?]")
  , ( 64178, "[?]")
  , ( 64179, "[?]")
  , ( 64180, "[?]")
  , ( 64181, "[?]")
  , ( 64182, "[?]")
  , ( 64183, "[?]")
  , ( 64184, "[?]")
  , ( 64185, "[?]")
  , ( 64186, "[?]")
  , ( 64187, "[?]")
  , ( 64188, "[?]")
  , ( 64189, "[?]")
  , ( 64190, "[?]")
  , ( 64191, "[?]")
  , ( 64192, "[?]")
  , ( 64193, "[?]")
  , ( 64194, "[?]")
  , ( 64195, "[?]")
  , ( 64196, "[?]")
  , ( 64197, "[?]")
  , ( 64198, "[?]")
  , ( 64199, "[?]")
  , ( 64200, "[?]")
  , ( 64201, "[?]")
  , ( 64202, "[?]")
  , ( 64203, "[?]")
  , ( 64204, "[?]")
  , ( 64205, "[?]")
  , ( 64206, "[?]")
  , ( 64207, "[?]")
  , ( 64208, "[?]")
  , ( 64209, "[?]")
  , ( 64210, "[?]")
  , ( 64211, "[?]")
  , ( 64212, "[?]")
  , ( 64213, "[?]")
  , ( 64214, "[?]")
  , ( 64215, "[?]")
  , ( 64216, "[?]")
  , ( 64217, "[?]")
  , ( 64218, "[?]")
  , ( 64219, "[?]")
  , ( 64220, "[?]")
  , ( 64221, "[?]")
  , ( 64222, "[?]")
  , ( 64223, "[?]")
  , ( 64224, "[?]")
  , ( 64225, "[?]")
  , ( 64226, "[?]")
  , ( 64227, "[?]")
  , ( 64228, "[?]")
  , ( 64229, "[?]")
  , ( 64230, "[?]")
  , ( 64231, "[?]")
  , ( 64232, "[?]")
  , ( 64233, "[?]")
  , ( 64234, "[?]")
  , ( 64235, "[?]")
  , ( 64236, "[?]")
  , ( 64237, "[?]")
  , ( 64238, "[?]")
  , ( 64239, "[?]")
  , ( 64240, "[?]")
  , ( 64241, "[?]")
  , ( 64242, "[?]")
  , ( 64243, "[?]")
  , ( 64244, "[?]")
  , ( 64245, "[?]")
  , ( 64246, "[?]")
  , ( 64247, "[?]")
  , ( 64248, "[?]")
  , ( 64249, "[?]")
  , ( 64250, "[?]")
  , ( 64251, "[?]")
  , ( 64252, "[?]")
  , ( 64253, "[?]")
  , ( 64254, "[?]")
  , ( 64256, "ff")
  , ( 64257, "fi")
  , ( 64258, "fl")
  , ( 64259, "ffi")
  , ( 64260, "ffl")
  , ( 64261, "st")
  , ( 64262, "st")
  , ( 64263, "[?]")
  , ( 64264, "[?]")
  , ( 64265, "[?]")
  , ( 64266, "[?]")
  , ( 64267, "[?]")
  , ( 64268, "[?]")
  , ( 64269, "[?]")
  , ( 64270, "[?]")
  , ( 64271, "[?]")
  , ( 64272, "[?]")
  , ( 64273, "[?]")
  , ( 64274, "[?]")
  , ( 64275, "mn")
  , ( 64276, "me")
  , ( 64277, "mi")
  , ( 64278, "vn")
  , ( 64279, "mkh")
  , ( 64280, "[?]")
  , ( 64281, "[?]")
  , ( 64282, "[?]")
  , ( 64283, "[?]")
  , ( 64284, "[?]")
  , ( 64285, "yi")
  , ( 64287, "ay")
  , ( 64288, "`")
  , ( 64290, "d")
  , ( 64291, "h")
  , ( 64292, "k")
  , ( 64293, "l")
  , ( 64294, "m")
  , ( 64295, "m")
  , ( 64296, "t")
  , ( 64297, "+")
  , ( 64298, "sh")
  , ( 64299, "s")
  , ( 64300, "sh")
  , ( 64301, "s")
  , ( 64302, "a")
  , ( 64303, "a")
  , ( 64305, "b")
  , ( 64306, "g")
  , ( 64307, "d")
  , ( 64308, "h")
  , ( 64309, "v")
  , ( 64310, "z")
  , ( 64311, "[?]")
  , ( 64312, "t")
  , ( 64313, "y")
  , ( 64314, "k")
  , ( 64315, "k")
  , ( 64316, "l")
  , ( 64317, "[?]")
  , ( 64318, "l")
  , ( 64319, "[?]")
  , ( 64320, "n")
  , ( 64321, "n")
  , ( 64322, "[?]")
  , ( 64323, "p")
  , ( 64324, "p")
  , ( 64325, "[?]")
  , ( 64326, "ts")
  , ( 64327, "ts")
  , ( 64328, "r")
  , ( 64329, "sh")
  , ( 64330, "t")
  , ( 64331, "vo")
  , ( 64332, "b")
  , ( 64333, "k")
  , ( 64334, "p")
  , ( 64335, "l")
  , ( 64434, "[?]")
  , ( 64435, "[?]")
  , ( 64436, "[?]")
  , ( 64437, "[?]")
  , ( 64438, "[?]")
  , ( 64439, "[?]")
  , ( 64440, "[?]")
  , ( 64441, "[?]")
  , ( 64442, "[?]")
  , ( 64443, "[?]")
  , ( 64444, "[?]")
  , ( 64445, "[?]")
  , ( 64446, "[?]")
  , ( 64447, "[?]")
  , ( 64448, "[?]")
  , ( 64449, "[?]")
  , ( 64450, "[?]")
  , ( 64451, "[?]")
  , ( 64452, "[?]")
  , ( 64453, "[?]")
  , ( 64454, "[?]")
  , ( 64455, "[?]")
  , ( 64456, "[?]")
  , ( 64457, "[?]")
  , ( 64458, "[?]")
  , ( 64459, "[?]")
  , ( 64460, "[?]")
  , ( 64461, "[?]")
  , ( 64462, "[?]")
  , ( 64463, "[?]")
  , ( 64464, "[?]")
  , ( 64465, "[?]")
  , ( 64466, "[?]")
  , ( 64832, "[?]")
  , ( 64833, "[?]")
  , ( 64834, "[?]")
  , ( 64835, "[?]")
  , ( 64836, "[?]")
  , ( 64837, "[?]")
  , ( 64838, "[?]")
  , ( 64839, "[?]")
  , ( 64840, "[?]")
  , ( 64841, "[?]")
  , ( 64842, "[?]")
  , ( 64843, "[?]")
  , ( 64844, "[?]")
  , ( 64845, "[?]")
  , ( 64846, "[?]")
  , ( 64847, "[?]")
  , ( 64912, "[?]")
  , ( 64913, "[?]")
  , ( 64968, "[?]")
  , ( 64969, "[?]")
  , ( 64970, "[?]")
  , ( 64971, "[?]")
  , ( 64972, "[?]")
  , ( 64973, "[?]")
  , ( 64974, "[?]")
  , ( 64975, "[?]")
  , ( 64976, "[?]")
  , ( 64977, "[?]")
  , ( 64978, "[?]")
  , ( 64979, "[?]")
  , ( 64980, "[?]")
  , ( 64981, "[?]")
  , ( 64982, "[?]")
  , ( 64983, "[?]")
  , ( 64984, "[?]")
  , ( 64985, "[?]")
  , ( 64986, "[?]")
  , ( 64987, "[?]")
  , ( 64988, "[?]")
  , ( 64989, "[?]")
  , ( 64990, "[?]")
  , ( 64991, "[?]")
  , ( 64992, "[?]")
  , ( 64993, "[?]")
  , ( 64994, "[?]")
  , ( 64995, "[?]")
  , ( 64996, "[?]")
  , ( 64997, "[?]")
  , ( 64998, "[?]")
  , ( 64999, "[?]")
  , ( 65000, "[?]")
  , ( 65001, "[?]")
  , ( 65002, "[?]")
  , ( 65003, "[?]")
  , ( 65004, "[?]")
  , ( 65005, "[?]")
  , ( 65006, "[?]")
  , ( 65007, "[?]")
  , ( 65020, "[?]")
  , ( 65021, "[?]")
  , ( 65022, "[?]")
  , ( 65024, "[?]")
  , ( 65025, "[?]")
  , ( 65026, "[?]")
  , ( 65027, "[?]")
  , ( 65028, "[?]")
  , ( 65029, "[?]")
  , ( 65030, "[?]")
  , ( 65031, "[?]")
  , ( 65032, "[?]")
  , ( 65033, "[?]")
  , ( 65034, "[?]")
  , ( 65035, "[?]")
  , ( 65036, "[?]")
  , ( 65037, "[?]")
  , ( 65038, "[?]")
  , ( 65039, "[?]")
  , ( 65040, "[?]")
  , ( 65041, "[?]")
  , ( 65042, "[?]")
  , ( 65043, "[?]")
  , ( 65044, "[?]")
  , ( 65045, "[?]")
  , ( 65046, "[?]")
  , ( 65047, "[?]")
  , ( 65048, "[?]")
  , ( 65049, "[?]")
  , ( 65050, "[?]")
  , ( 65051, "[?]")
  , ( 65052, "[?]")
  , ( 65053, "[?]")
  , ( 65054, "[?]")
  , ( 65055, "[?]")
  , ( 65059, "~")
  , ( 65060, "[?]")
  , ( 65061, "[?]")
  , ( 65062, "[?]")
  , ( 65063, "[?]")
  , ( 65064, "[?]")
  , ( 65065, "[?]")
  , ( 65066, "[?]")
  , ( 65067, "[?]")
  , ( 65068, "[?]")
  , ( 65069, "[?]")
  , ( 65070, "[?]")
  , ( 65071, "[?]")
  , ( 65072, "..")
  , ( 65073, "--")
  , ( 65074, "-")
  , ( 65075, "_")
  , ( 65076, "_")
  , ( 65077, "(")
  , ( 65078, ") ")
  , ( 65079, "{")
  , ( 65080, "} ")
  , ( 65081, "[")
  , ( 65082, "] ")
  , ( 65083, "[(")
  , ( 65084, ")] ")
  , ( 65085, "<<")
  , ( 65086, ">> ")
  , ( 65087, "<")
  , ( 65088, "> ")
  , ( 65089, "[")
  , ( 65090, "] ")
  , ( 65091, "{")
  , ( 65092, "}")
  , ( 65093, "[?]")
  , ( 65094, "[?]")
  , ( 65095, "[?]")
  , ( 65096, "[?]")
  , ( 65104, ",")
  , ( 65105, ",")
  , ( 65106, ".")
  , ( 65108, ";")
  , ( 65109, ":")
  , ( 65110, "?")
  , ( 65111, "!")
  , ( 65112, "-")
  , ( 65113, "(")
  , ( 65114, ")")
  , ( 65115, "{")
  , ( 65116, "}")
  , ( 65117, "{")
  , ( 65118, "}")
  , ( 65119, "#")
  , ( 65120, "&")
  , ( 65121, "*")
  , ( 65122, "+")
  , ( 65123, "-")
  , ( 65124, "<")
  , ( 65125, ">")
  , ( 65126, "=")
  , ( 65128, "\\")
  , ( 65129, "$")
  , ( 65130, "%")
  , ( 65131, "@")
  , ( 65132, "[?]")
  , ( 65133, "[?]")
  , ( 65134, "[?]")
  , ( 65135, "[?]")
  , ( 65139, "[?]")
  , ( 65141, "[?]")
  , ( 65277, "[?]")
  , ( 65278, "[?]")
  , ( 65280, "[?]")
  , ( 65281, "!")
  , ( 65282, "\"")
  , ( 65283, "#")
  , ( 65284, "$")
  , ( 65285, "%")
  , ( 65286, "&")
  , ( 65287, "'")
  , ( 65288, "(")
  , ( 65289, ")")
  , ( 65290, "*")
  , ( 65291, "+")
  , ( 65292, ",")
  , ( 65293, "-")
  , ( 65294, ".")
  , ( 65295, "/")
  , ( 65296, "0")
  , ( 65297, "1")
  , ( 65298, "2")
  , ( 65299, "3")
  , ( 65300, "4")
  , ( 65301, "5")
  , ( 65302, "6")
  , ( 65303, "7")
  , ( 65304, "8")
  , ( 65305, "9")
  , ( 65306, ":")
  , ( 65307, ";")
  , ( 65308, "<")
  , ( 65309, "=")
  , ( 65310, ">")
  , ( 65311, "?")
  , ( 65312, "@")
  , ( 65313, "A")
  , ( 65314, "B")
  , ( 65315, "C")
  , ( 65316, "D")
  , ( 65317, "E")
  , ( 65318, "F")
  , ( 65319, "G")
  , ( 65320, "H")
  , ( 65321, "I")
  , ( 65322, "J")
  , ( 65323, "K")
  , ( 65324, "L")
  , ( 65325, "M")
  , ( 65326, "N")
  , ( 65327, "O")
  , ( 65328, "P")
  , ( 65329, "Q")
  , ( 65330, "R")
  , ( 65331, "S")
  , ( 65332, "T")
  , ( 65333, "U")
  , ( 65334, "V")
  , ( 65335, "W")
  , ( 65336, "X")
  , ( 65337, "Y")
  , ( 65338, "Z")
  , ( 65339, "[")
  , ( 65340, "\\")
  , ( 65341, "]")
  , ( 65342, "^")
  , ( 65343, "_")
  , ( 65344, "`")
  , ( 65345, "a")
  , ( 65346, "b")
  , ( 65347, "c")
  , ( 65348, "d")
  , ( 65349, "e")
  , ( 65350, "f")
  , ( 65351, "g")
  , ( 65352, "h")
  , ( 65353, "i")
  , ( 65354, "j")
  , ( 65355, "k")
  , ( 65356, "l")
  , ( 65357, "m")
  , ( 65358, "n")
  , ( 65359, "o")
  , ( 65360, "p")
  , ( 65361, "q")
  , ( 65362, "r")
  , ( 65363, "s")
  , ( 65364, "t")
  , ( 65365, "u")
  , ( 65366, "v")
  , ( 65367, "w")
  , ( 65368, "x")
  , ( 65369, "y")
  , ( 65370, "z")
  , ( 65371, "{")
  , ( 65372, "|")
  , ( 65373, "}")
  , ( 65374, "~")
  , ( 65375, "[?]")
  , ( 65376, "[?]")
  , ( 65377, ".")
  , ( 65378, "[")
  , ( 65379, "]")
  , ( 65380, ",")
  , ( 65381, "*")
  , ( 65382, "wo")
  , ( 65383, "a")
  , ( 65384, "i")
  , ( 65385, "u")
  , ( 65386, "e")
  , ( 65387, "o")
  , ( 65388, "ya")
  , ( 65389, "yu")
  , ( 65390, "yo")
  , ( 65391, "tu")
  , ( 65392, "+")
  , ( 65393, "a")
  , ( 65394, "i")
  , ( 65395, "u")
  , ( 65396, "e")
  , ( 65397, "o")
  , ( 65398, "ka")
  , ( 65399, "ki")
  , ( 65400, "ku")
  , ( 65401, "ke")
  , ( 65402, "ko")
  , ( 65403, "sa")
  , ( 65404, "si")
  , ( 65405, "su")
  , ( 65406, "se")
  , ( 65407, "so")
  , ( 65408, "ta")
  , ( 65409, "ti")
  , ( 65410, "tu")
  , ( 65411, "te")
  , ( 65412, "to")
  , ( 65413, "na")
  , ( 65414, "ni")
  , ( 65415, "nu")
  , ( 65416, "ne")
  , ( 65417, "no")
  , ( 65418, "ha")
  , ( 65419, "hi")
  , ( 65420, "hu")
  , ( 65421, "he")
  , ( 65422, "ho")
  , ( 65423, "ma")
  , ( 65424, "mi")
  , ( 65425, "mu")
  , ( 65426, "me")
  , ( 65427, "mo")
  , ( 65428, "ya")
  , ( 65429, "yu")
  , ( 65430, "yo")
  , ( 65431, "ra")
  , ( 65432, "ri")
  , ( 65433, "ru")
  , ( 65434, "re")
  , ( 65435, "ro")
  , ( 65436, "wa")
  , ( 65437, "n")
  , ( 65438, ":")
  , ( 65439, ";")
  , ( 65441, "g")
  , ( 65442, "gg")
  , ( 65443, "gs")
  , ( 65444, "n")
  , ( 65445, "nj")
  , ( 65446, "nh")
  , ( 65447, "d")
  , ( 65448, "dd")
  , ( 65449, "r")
  , ( 65450, "lg")
  , ( 65451, "lm")
  , ( 65452, "lb")
  , ( 65453, "ls")
  , ( 65454, "lt")
  , ( 65455, "lp")
  , ( 65456, "rh")
  , ( 65457, "m")
  , ( 65458, "b")
  , ( 65459, "bb")
  , ( 65460, "bs")
  , ( 65461, "s")
  , ( 65462, "ss")
  , ( 65464, "j")
  , ( 65465, "jj")
  , ( 65466, "c")
  , ( 65467, "k")
  , ( 65468, "t")
  , ( 65469, "p")
  , ( 65470, "h")
  , ( 65471, "[?]")
  , ( 65472, "[?]")
  , ( 65473, "[?]")
  , ( 65474, "a")
  , ( 65475, "ae")
  , ( 65476, "ya")
  , ( 65477, "yae")
  , ( 65478, "eo")
  , ( 65479, "e")
  , ( 65480, "[?]")
  , ( 65481, "[?]")
  , ( 65482, "yeo")
  , ( 65483, "ye")
  , ( 65484, "o")
  , ( 65485, "wa")
  , ( 65486, "wae")
  , ( 65487, "oe")
  , ( 65488, "[?]")
  , ( 65489, "[?]")
  , ( 65490, "yo")
  , ( 65491, "u")
  , ( 65492, "weo")
  , ( 65493, "we")
  , ( 65494, "wi")
  , ( 65495, "yu")
  , ( 65496, "[?]")
  , ( 65497, "[?]")
  , ( 65498, "eu")
  , ( 65499, "yi")
  , ( 65500, "i")
  , ( 65501, "[?]")
  , ( 65502, "[?]")
  , ( 65503, "[?]")
  , ( 65504, "/C")
  , ( 65505, "PS")
  , ( 65506, "!")
  , ( 65507, "-")
  , ( 65508, "|")
  , ( 65509, "Y=")
  , ( 65510, "W=")
  , ( 65511, "[?]")
  , ( 65512, "|")
  , ( 65513, "-")
  , ( 65514, "|")
  , ( 65515, "-")
  , ( 65516, "|")
  , ( 65517, "#")
  , ( 65518, "O")
  , ( 65519, "[?]")
  , ( 65520, "[?]")
  , ( 65521, "[?]")
  , ( 65522, "[?]")
  , ( 65523, "[?]")
  , ( 65524, "[?]")
  , ( 65525, "[?]")
  , ( 65526, "[?]")
  , ( 65527, "[?]")
  , ( 65528, "[?]")
  , ( 65529, "{")
  , ( 65530, "|")
  , ( 65531, "}") ]
